@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: dc61d390fa2e0be36138e167dbaac390e550dccc $
+// $Id: 15e69cbabfcf2da9c6f8ab4b90cbd369915d7e1a $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -53,7 +53,7 @@ EXTERN_CVAR(waddirs);
 // ---------------
 
 typedef std::vector<scannedIWAD_t> scannedIWADs_t;
-typedef std::vector<scannedPWAD_t> scannedPWADs_t;
+typedef std::vector<std::pair<scannedPWAD_t, bool>> scannedPWADs_t;
 typedef std::vector<scannedPWAD_t*> scannedPWADPtrs_t;
 
 // display strings for options tab and their corresponding command line arguments
@@ -68,16 +68,27 @@ const std::vector<std::pair<std::string, std::string> > OPTIONS_LIST = {
 /**
  * @brief Find the PWAD pointer in the scanned WAD array.
  */
-static scannedPWADs_t::iterator FindScanned(scannedPWADs_t& mut, scannedPWAD_t* pwad)
+static auto FindScanned(const std::vector<std::pair<std::string, int>>& filterIndices, const scannedPWADs_t& pwads, const scannedPWAD_t* pwad)
 {
-	for (scannedPWADs_t::iterator it = mut.begin(); it != mut.end(); ++it)
+	int i = 0;
+	for (const auto& [name, index] : filterIndices)
 	{
-		if (&*it == pwad)
+		if (name == pwad->filename)
 		{
-			return it;
+			return std::make_pair(i, index);
 		}
+		i++;
 	}
-	return mut.end();
+	i = 0;
+	for (const auto& [scannedPWAD, _] : pwads)
+	{
+		if (&scannedPWAD == pwad)
+		{
+			return std::make_pair(-1, i);
+		}
+		i++;
+	}
+	return std::make_pair(-1, -1);
 }
 
 /**
@@ -114,7 +125,7 @@ class BootWindow : public Fl_Window
 {
 	Fl_Group* m_tabIWAD;
 	Fl_Group* m_tabPWADs;
-	std::string m_genWaddirs;
+	std::string m_genWADDirs;
 	scannedIWADs_t m_IWADs;
 	scannedPWADs_t m_PWADs;
 	scannedPWADPtrs_t m_selectedPWADs;
@@ -124,10 +135,12 @@ class BootWindow : public Fl_Window
 	Fl_Check_Browser* m_gameOptionsBrowser;
 	StringTokens m_WADDirs;
 	Fl_Hold_Browser* m_WADDirList;
+	Fl_Input* m_searchPWADs;
+	std::vector<std::pair<std::string, int>> m_filterIndices;
 
   public:
 	BootWindow(int X, int Y, int W, int H, const char* L)
-	    : Fl_Window(X, Y, W, H, L), m_IWADs()
+	    : Fl_Window(X, Y, W, H, L), m_genWADDirs(), m_IWADs(), m_PWADs(), m_selectedPWADs(), m_WADDirs(), m_filterIndices()
 	{
 		{
 			Fl_Tabs* tabs = new Fl_Tabs(0, 0, 425, 200);
@@ -150,7 +163,13 @@ class BootWindow : public Fl_Window
 			{
 				m_tabPWADs = new Fl_Group(0, 25, 425, 175, "PWAD Select");
 				{
-					m_PWADSelectBrowser = new Fl_Check_Browser(10, 35, 183, 155);
+					m_searchPWADs = new Fl_Input(36, 35, 154, 20);
+					m_searchPWADs->label("@search");
+					m_searchPWADs->callback(BootWindow::doSearchCB, static_cast<void*>(this));
+					m_searchPWADs->when(FL_WHEN_CHANGED);
+				} // Fl_Input* m_searchPWADs
+				{
+					m_PWADSelectBrowser = new Fl_Check_Browser(10, 65, 183, 135);
 					m_PWADSelectBrowser->callback(BootWindow::scanCheckedPWADsCB,
 					                              static_cast<void*>(this));
 					m_PWADSelectBrowser->when(FL_WHEN_CHANGED);
@@ -260,7 +279,7 @@ class BootWindow : public Fl_Window
 		Fl_Group* clicked = static_cast<Fl_Group*>(tabs->value());
 
 		// Have waddirs changed?
-		bool waddirsChanged = boot->m_genWaddirs != ::waddirs;
+		bool waddirsChanged = boot->m_genWADDirs != ::waddirs;
 
 		// User clicked on the first tab, regenerate the
 		// list of IWADs if waddirs changed.
@@ -273,7 +292,7 @@ class BootWindow : public Fl_Window
 		bool pwadsIsEmpty = boot->m_PWADSelectBrowser->nitems() == 0;
 
 		// User clicked on the second tab, regenerate the
-		// list of IWADs if waddirs changed or browser is empty.
+		// list of PWADs if waddirs changed or browser is empty.
 		if ((clicked == boot->m_tabPWADs) && (pwadsIsEmpty || waddirsChanged))
 		{
 			boot->rescanPWADs();
@@ -309,6 +328,13 @@ class BootWindow : public Fl_Window
 
 	// -- PWAD Boot Order --
 
+	static void doSearchCB(Fl_Widget*, void* data)
+	{
+		BootWindow* boot = static_cast<BootWindow*>(data);
+
+		boot->filterPWADs();
+	}
+
 	static void doWADUpCB(Fl_Widget*, void* data)
 	{
 		BootWindow* boot = static_cast<BootWindow*>(data);
@@ -353,13 +379,12 @@ class BootWindow : public Fl_Window
 		scannedPWAD_t* selected = boot->m_selectedPWADs[removeIDX];
 
 		// Uncheck the selected PWAD from the selection array.
-		scannedPWADs_t::iterator it = FindScanned(boot->m_PWADs, selected);
-		if (it == boot->m_PWADs.end())
-		{
+		auto [selectIndex, pwadIndex] = FindScanned(boot->m_filterIndices, boot->m_PWADs, selected);
+		if (pwadIndex == -1)
 			return;
-		}
-		ptrdiff_t index = it - boot->m_PWADs.begin();
-		boot->m_PWADSelectBrowser->checked(index + 1, 0);
+		boot->m_PWADs[pwadIndex].second = false;
+		if (selectIndex != -1)
+			boot->m_PWADSelectBrowser->checked(selectIndex + 1, 0);
 
 		// Erase the selected PWAD from the order array.
 		EraseSelected(boot->m_selectedPWADs, boot->m_selectedPWADs[removeIDX]);
@@ -443,24 +468,45 @@ class BootWindow : public Fl_Window
 		{
 			m_IWADBrowser->add(iwad.id->mNiceName.c_str(), (void*)iwad.id);
 		}
-		m_genWaddirs = ::waddirs.str();
+		m_genWADDirs = ::waddirs.str();
 	}
 
 	void rescanPWADs()
 	{
 		m_PWADSelectBrowser->clear();
-		m_PWADs = M_ScanPWADs();
-		for (const auto& pwad : m_PWADs)
+		int i = 0;
+		for (const auto& pwad : M_ScanPWADs())
 		{
+			m_PWADs.emplace_back(pwad, false);
 			m_PWADSelectBrowser->add(pwad.filename.c_str());
+			m_filterIndices.emplace_back(pwad.filename, i);
+			i++;
 		}
-		m_genWaddirs = ::waddirs.str();
+		m_genWADDirs = ::waddirs.str();
 
 		// clear order browser since selection browser is being reset
 		m_PWADOrderBrowser->clear();
 		m_selectedPWADs.clear();
 	}
 
+	void filterPWADs()
+	{
+		m_filterIndices.clear();
+		m_PWADSelectBrowser->clear();
+		int i = 0;
+		for (const auto& [pwad, checked] : m_PWADs)
+		{
+			if (m_searchPWADs->value()[0] == 0 ||
+				StdStringFind(pwad.filename, m_searchPWADs->value(), 0, m_searchPWADs->size(), true) != std::string::npos)
+			{
+				m_PWADSelectBrowser->add(pwad.filename.c_str(), checked);
+				m_filterIndices.emplace_back(pwad.filename, i);
+			}
+			i++;
+		}
+		m_PWADSelectBrowser->redraw();
+	}
+
 	/**
 	 * @brief Places selected PWADs into the order browser for load order selection.
 	 */
@@ -469,16 +515,18 @@ class BootWindow : public Fl_Window
 		BootWindow* boot = static_cast<BootWindow*>(data);
 
 		// Scan all PWADs in the selection browser to see if they're checked.
-		for (int i = 1; i <= boot->m_PWADSelectBrowser->nitems(); i++)
+		for (size_t i = 1; i <= boot->m_PWADSelectBrowser->nitems(); i++)
 		{
-			scannedPWAD_t* selected = &boot->m_PWADs[size_t(i) - 1];
-			if (boot->m_PWADSelectBrowser->checked(i))
+			auto& [pwad, selected] = boot->m_PWADs[boot->m_filterIndices[i - 1].second];
+			if (boot->m_PWADSelectBrowser->checked(static_cast<int>(i)))
 			{
-				AddSelected(boot->m_selectedPWADs, selected);
+				selected = true;
+				AddSelected(boot->m_selectedPWADs, &pwad);
 			}
 			else
 			{
-				EraseSelected(boot->m_selectedPWADs, selected);
+				selected = false;
+				EraseSelected(boot->m_selectedPWADs, &pwad);
 			}
 		}
 
@@ -585,7 +633,7 @@ static BootWindow* MakeBootWindow()
 scannedWADs_t GUI_BootWindow()
 {
 	// Scale according to 1600x900.
-	Fl::screen_scale(0, MAX(Fl::h() / 900.0f, 1.0f));
+	Fl::screen_scale(0, MAX(Fl::h() / 900.0f, Fl::screen_scale(0)));
 
 	// This feature is too clever by half, and in my experience just
 	// deforms the window.
