@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: ba58f20210f40a7297b7931bb4b7ce9ad102e5c6 $
+// $Id: 37eeb85369f789e5e544df2f30521719cf3facd1 $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -268,10 +268,10 @@ int I_GetKeyFromName(const std::string& name)
 		return atoi(name.c_str() + 1);
 
 	// Otherwise, we scan the KeyNames[] array for a matching name
-	for (KeyNameTable::const_iterator it = key_names.begin(); it != key_names.end(); ++it)
+	for (const auto& [key, key_name] : key_names)
 	{
-		if (iequals(name, it->second))
-			return it->first;
+		if (iequals(name, key_name))
+			return key;
 	}
 	return 0;
 }
@@ -291,9 +291,7 @@ std::string I_GetKeyName(int key)
 	if (it != key_names.end() && !it->second.empty())
 		return it->second;
 
-	static char name[11];
-	snprintf(name, 11, "#%d", key);
-	return std::string(name);
+	return fmt::format("#{}", key);
 }
 
 
@@ -434,7 +432,7 @@ static void I_UpdateGrab()
 	// force I_ResumeMouse or I_PauseMouse if toggling between fullscreen/windowed
 	bool fullscreen = I_GetWindow()->isFullScreen();
 	static bool prev_fullscreen = fullscreen;
-	if (fullscreen != prev_fullscreen) 
+	if (fullscreen != prev_fullscreen)
 		I_ForceUpdateGrab();
 	prev_fullscreen = fullscreen;
 
@@ -469,16 +467,16 @@ CVAR_FUNC_IMPL(use_joystick)
 CVAR_FUNC_IMPL(joy_active)
 {
 	const std::vector<IInputDeviceInfo> devices = input_subsystem->getJoystickDevices();
-	for (std::vector<IInputDeviceInfo>::const_iterator it = devices.begin(); it != devices.end(); ++it)
+	for (const auto& device : devices)
 	{
-		if (it->mId == (int)var)
+		if (device.mId == var.asInt())
 		{
 			I_OpenJoystick();
 			return;
 		}
 	}
 
-#ifdef GCONSOLE	
+#ifdef GCONSOLE
 	// Don't let console users choose an invalid joystick because
 	// they won't have any way to reenable through the menu.
 	if (!devices.empty())
@@ -490,7 +488,7 @@ CVAR_FUNC_IMPL(joy_active)
 //
 // I_GetJoystickCount
 //
-int I_GetJoystickCount()
+size_t I_GetJoystickCount()
 {
 	const std::vector<IInputDeviceInfo> devices = input_subsystem->getJoystickDevices();
 	return devices.size();
@@ -502,10 +500,10 @@ int I_GetJoystickCount()
 std::string I_GetJoystickNameFromIndex(int index)
 {
 	const std::vector<IInputDeviceInfo> devices = input_subsystem->getJoystickDevices();
-	for (std::vector<IInputDeviceInfo>::const_iterator it = devices.begin(); it != devices.end(); ++it)
+	for (const auto& device : devices)
 	{
-		if (it->mId == index)
-			return it->mDeviceName;
+		if (device.mId == index)
+			return device.mDeviceName;
 	}
 	return "";
 }
@@ -517,17 +515,17 @@ std::string I_GetJoystickNameFromIndex(int index)
 bool I_OpenJoystick()
 {
 	I_CloseJoystick();		// just in case it was left open...
-	
+
 	if (use_joystick != 0)
 	{
 		// Verify that the joystick ID indicated by the joy_active CVAR
 		// is valid and if so, initialize that joystick
 		const std::vector<IInputDeviceInfo> devices = input_subsystem->getJoystickDevices();
-		for (std::vector<IInputDeviceInfo>::const_iterator it = devices.begin(); it != devices.end(); ++it)
+		for (const auto& device : devices)
 		{
-			if (it->mId == joy_active.asInt())
+			if (device.mId == joy_active.asInt())
 			{
-				input_subsystem->initJoystick(it->mId);
+				input_subsystem->initJoystick(device.mId);
 				return true;
 			}
 		}
@@ -543,10 +541,10 @@ void I_CloseJoystick()
 	// Verify that the joystick ID indicated by the joy_active CVAR
 	// is valid and if so, shutdown that joystick
 	const std::vector<IInputDeviceInfo> devices = input_subsystem->getJoystickDevices();
-	for (std::vector<IInputDeviceInfo>::const_iterator it = devices.begin(); it != devices.end(); ++it)
+	for (const auto& device : devices)
 	{
-		if (it->mId == joy_active.asInt())
-			input_subsystem->shutdownJoystick(it->mId);
+		if (device.mId == joy_active.asInt())
+			input_subsystem->shutdownJoystick(device.mId);
 	}
 
 	// Reset joy position values. Wouldn't want to get stuck in a turn or something. -- Hyper_Eye
@@ -794,7 +792,7 @@ void IInputSubsystem::disableTextEntry()
 // Joystick hat events also repeat but each directional trigger repeats
 // concurrently as long as they are held down. Thus a unique value is returned
 // for each of them.
-// 
+//
 static int I_GetEventRepeaterKey(const event_t* ev)
 {
 	if (ev->type != ev_keydown && ev->type != ev_keyup)
@@ -821,7 +819,7 @@ static int I_GetEventRepeaterKey(const event_t* ev)
 void IInputSubsystem::addToEventRepeaters(event_t& ev)
 {
 	// Check if the event needs to be added/removed from the list of repeatable events
-	int key = I_GetEventRepeaterKey(&ev);
+	const int key = I_GetEventRepeaterKey(&ev);
 	if (ev.type == ev_keydown && key)
 	{
 		// If there is an existing repeater event for "key",
@@ -835,7 +833,7 @@ void IInputSubsystem::addToEventRepeaters(event_t& ev)
 		repeater.event = ev;
 		repeater.repeating = false;		// start off waiting for mRepeatDelay before repeating
 		repeater.last_time = I_GetTime();
-		mEventRepeaters.insert(std::make_pair(key, repeater));
+		mEventRepeaters.emplace(key, repeater);
 	}
 	else if (ev.type == ev_keyup && key)
 	{
@@ -854,9 +852,8 @@ void IInputSubsystem::addToEventRepeaters(event_t& ev)
 //
 void IInputSubsystem::repeatEvents()
 {
-	for (EventRepeaterTable::iterator it = mEventRepeaters.begin(); it != mEventRepeaters.end(); ++it)
+	for (auto& [_, repeater] : mEventRepeaters)
 	{
-		EventRepeater& repeater = it->second;
 		uint64_t current_time = I_GetTime();
 
 		if (!repeater.repeating && current_time - repeater.last_time >= mRepeatDelay)
@@ -881,9 +878,8 @@ void IInputSubsystem::repeatEvents()
 void IInputSubsystem::gatherEvents()
 {
 	event_t ev;
-	for (InputDeviceList::iterator it = mInputDevices.begin(); it != mInputDevices.end(); ++it)
+	for (const auto& device : mInputDevices)
 	{
-		IInputDevice* device = *it;
 		device->gatherEvents();
 		while (device->hasEvent())
 		{
@@ -904,13 +900,15 @@ void IInputSubsystem::gatherEvents()
 void IInputSubsystem::gatherMouseEvents()
 {
 	event_t mouseEvent;
-	if (mMouseInputDevice != NULL)
+	if (mMouseInputDevice != nullptr)
+	{
 		mMouseInputDevice->gatherEvents();
 
-	while (mMouseInputDevice->hasEvent())
-	{
-		mMouseInputDevice->getEvent(&mouseEvent);
-		mEvents.push(mouseEvent);
+		while (mMouseInputDevice->hasEvent())
+		{
+			mMouseInputDevice->getEvent(&mouseEvent);
+			mEvents.push(mouseEvent);
+		}
 	}
 }
 
@@ -926,4 +924,4 @@ void IInputSubsystem::getEvent(event_t* ev)
 }
 
 
-VERSION_CONTROL (i_input_cpp, "$Id: ba58f20210f40a7297b7931bb4b7ce9ad102e5c6 $")
+VERSION_CONTROL (i_input_cpp, "$Id: 37eeb85369f789e5e544df2f30521719cf3facd1 $")
