@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 73b778d32e7b4921401dd703e3bb5b9c9c5f5bc6 $
+// $Id: fe1ec65db9481a748165e236f008cee8bd2418bb $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -207,7 +207,7 @@ void ISDL20KeyboardInputDevice::disableTextEntry()
 //
 int ISDL20KeyboardInputDevice::getTextEventValue()
 {
-	constexpr size_t max_events = 32;
+	static constexpr size_t max_events = 32;
 	SDL_Event sdl_events[max_events];
 
 	SDL_PumpEvents();
@@ -858,8 +858,7 @@ ISDL20InputSubsystem::~ISDL20InputSubsystem()
 std::vector<IInputDeviceInfo> ISDL20InputSubsystem::getKeyboardDevices() const
 {
 	std::vector<IInputDeviceInfo> devices;
-	devices.push_back(IInputDeviceInfo());
-	IInputDeviceInfo& device_info = devices.back();
+	IInputDeviceInfo& device_info = devices.emplace_back();
 	device_info.mId = 0;
 	device_info.mDeviceName = "SDL 2.0 keyboard";
 	return devices;
@@ -875,13 +874,13 @@ void ISDL20InputSubsystem::initKeyboard(int id)
 
 	const std::vector<IInputDeviceInfo> devices = getKeyboardDevices();
 	std::string device_name;
-	for (std::vector<IInputDeviceInfo>::const_iterator it = devices.begin(); it != devices.end(); ++it)
+	for (const auto& device : devices)
 	{
-		if (it->mId == id)
-			device_name = it->mDeviceName;
+		if (device.mId == id)
+			device_name = device.mDeviceName;
 	}
 
-	Printf(PRINT_HIGH, "I_InitInput: intializing %s\n", device_name.c_str());
+	PrintFmt(PRINT_HIGH, "I_InitInput: intializing {:s}\n", device_name);
 
 	setKeyboardInputDevice(new ISDL20KeyboardInputDevice(id));
 	registerInputDevice(getKeyboardInputDevice());
@@ -930,13 +929,13 @@ void ISDL20InputSubsystem::initMouse(int id)
 
 	const std::vector<IInputDeviceInfo> devices = getMouseDevices();
 	std::string device_name;
-	for (std::vector<IInputDeviceInfo>::const_iterator it = devices.begin(); it != devices.end(); ++it)
+	for (const auto& device : devices)
 	{
-		if (it->mId == id)
-			device_name = it->mDeviceName;
+		if (device.mId == id)
+			device_name = device.mDeviceName;
 	}
 
-	Printf(PRINT_HIGH, "I_InitInput: intializing %s\n", device_name.c_str());
+	PrintFmt(PRINT_HIGH, "I_InitInput: intializing {:s}\n", device_name);
 
 	setMouseInputDevice(new ISDL20MouseInputDevice(id));
 	assert(getMouseInputDevice() != NULL);
@@ -990,13 +989,13 @@ void ISDL20InputSubsystem::initJoystick(int id)
 
 	const std::vector<IInputDeviceInfo> devices = getJoystickDevices();
 	std::string device_name;
-	for (std::vector<IInputDeviceInfo>::const_iterator it = devices.begin(); it != devices.end(); ++it)
+	for (const auto& device : devices)
 	{
-		if (it->mId == id)
-			device_name = it->mDeviceName;
+		if (device.mId == id)
+			device_name = device.mDeviceName;
 	}
 
-	Printf(PRINT_HIGH, "I_InitInput: intializing %s\n", device_name.c_str());
+	PrintFmt(PRINT_HIGH, "I_InitInput: intializing {:s}\n", device_name);
 
 	setJoystickInputDevice(new ISDL20JoystickInputDevice(id));
 	registerInputDevice(getJoystickInputDevice());
@@ -1044,4 +1043,4 @@ void ISDL20InputSubsystem::releaseInput()
 
 #endif	// SDL20
 
-VERSION_CONTROL(i_input_sdl20_cpp, "$Id: 73b778d32e7b4921401dd703e3bb5b9c9c5f5bc6 $")
+VERSION_CONTROL(i_input_sdl20_cpp, "$Id: fe1ec65db9481a748165e236f008cee8bd2418bb $")
