@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 6f7597d09e8a79de3c7a8e31cae77da4b392145d $
+// $Id: f1fa83c11b89b180501ed967549e44d061ae502b $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
@@ -76,7 +76,7 @@
 
 #define TURN180_TICKS	9				// [RH] # of ticks to complete a turn180
 
-BOOL	G_CheckDemoStatus (void);
+bool	G_CheckDemoStatus (void);
 void	G_ReadDemoTiccmd ();
 void	G_WriteDemoTiccmd ();
 void	G_PlayerReborn (player_t &player);
@@ -111,23 +111,23 @@ EXTERN_CVAR (chasedemo)
 gameaction_t	gameaction;
 gamestate_t 	gamestate = GS_STARTUP;
 
-BOOL 			paused;
-BOOL 			sendpause;				// send a pause event next tic
-BOOL			sendsave;				// send a save event next tic
-BOOL 			usergame;				// ok to save / end game
-BOOL			sendcenterview;			// send a center view event next tic
+bool 			paused;
+bool 			sendpause;				// send a pause event next tic
+bool			sendsave;				// send a save event next tic
+bool 			usergame;				// ok to save / end game
+bool			sendcenterview;			// send a center view event next tic
 
 bool			timingdemo; 			// if true, exit with report on completion
 bool			longtics;				// don't quantize yaw for classic vanilla demos
 bool 			nodrawers;				// for comparative timing purposes
 bool 			noblit; 				// for comparative timing purposes
 
-BOOL	 		viewactive;
+bool	 		viewactive;
 
 // Describes if a network game is being played
-BOOL			network_game;
+bool			network_game;
 // Describes if this is a multiplayer game or not
-BOOL			multiplayer;
+bool			multiplayer;
 // The player vector, contains all player information
 Players			players;
 
@@ -198,18 +198,18 @@ CVAR_FUNC_IMPL(cl_mouselook)
 }
 
 char			demoname[256];
-BOOL 			demoplayback;
+bool 			demoplayback;
 
 extern bool		simulated_connection;
 
 int				iffdemover;
 byte*			demobuffer;
 byte			*demo_p, *demo_e;
-BOOL 			singledemo; 			// quit after playing a demo from cmdline
+bool 			singledemo; 			// quit after playing a demo from cmdline
 int				demostartgametic;
 FILE*			recorddemo_fp;
 
-BOOL 			precache = true;		// if true, load all graphics at start
+bool 			precache = true;		// if true, load all graphics at start
 
 wbstartstruct_t wminfo; 				// parms for world map / intermission
 
@@ -253,7 +253,7 @@ EXTERN_CVAR (joy_invert)
 EXTERN_CVAR (joy_freelook)
 
 int 			savegameslot;
-char			savedescription[32];
+std::string		savedescription;
 
 player_t		&consoleplayer()
 {
@@ -720,7 +720,7 @@ bool G_ShouldIgnoreMouseInput()
 // G_Responder
 // Get info needed to make ticcmd_ts for the players.
 //
-BOOL G_Responder (event_t *ev)
+bool G_Responder (event_t *ev)
 {
 	// any other key pops up menu if in demos
 	// [RH] But only if the key isn't bound to a "special" command
@@ -746,7 +746,6 @@ BOOL G_Responder (event_t *ev)
                 stricmp (cmd, "stepmode") &&
                 stricmp (cmd, "step")))
 			{
-				S_Sound (CHAN_INTERFACE, "switches/normbutn", 1, ATTN_NONE);
 				M_StartControlPanel ();
 				return true;
 			}
@@ -893,22 +892,22 @@ void G_Ticker (void)
 	//      through every mobj every tic would be incredibly time-consuming.
 	if (!serverside)
 	{
-		for (Players::iterator it = players.begin();it != players.end();++it)
+		for (auto& player : players)
 		{
-			if (it->mo)
-				it->mo->oflags &= ~MFO_NOSNAPZ;
+			if (player.mo)
+				player.mo->oflags &= ~MFO_NOSNAPZ;
 		}
 	}
 
 	// do player reborns if needed
 	if(serverside)
-		for (Players::iterator it = players.begin();it != players.end();++it)
+		for (auto& player : players)
 		{
-			if (it->ingame() && (it->playerstate == PST_REBORN || it->playerstate == PST_ENTER))
+			if (player.ingame() && (player.playerstate == PST_REBORN || player.playerstate == PST_ENTER))
 			{
-				if (it->playerstate == PST_REBORN)
-					it->doreborn = true;			// State only our will to lose the whole inventory in case of a reborn.
-				G_DoReborn(*it);
+				if (player.playerstate == PST_REBORN)
+					player.doreborn = true;			// State only our will to lose the whole inventory in case of a reborn.
+				G_DoReborn(player);
 			}
 		}
 
@@ -955,7 +954,7 @@ void G_Ticker (void)
 			if (demoplayback)
 				G_CheckDemoStatus();
 
-			extern BOOL advancedemo;
+			extern bool advancedemo;
 			advancedemo = false;
 
 			if (gamestate != GS_STARTUP)
@@ -983,9 +982,9 @@ void G_Ticker (void)
 	// [Blair] From all players in a demo playback.
 	if (demoplayback)
 	{
-		for (Players::iterator it = ::players.begin(); it != players.end(); ++it)
+		for (auto& player : players)
 		{
-			memcpy(&it->cmd, &it->netcmds[buf], sizeof(ticcmd_t));
+			memcpy(&player.cmd, &player.netcmds[buf], sizeof(ticcmd_t));
 		}
 	}
 	else
@@ -1090,18 +1089,24 @@ void G_Ticker (void)
 		// Otherwise we might miss a pause and desync!
 		if (demoplayback)
 		{
-			for (Players::iterator it = ::players.begin(); it != players.end(); ++it)
+			for (const auto& player : players)
 			{
-				if (it->cmd.buttons & BT_SPECIAL)
+				if (player.cmd.buttons & BT_SPECIAL)
 				{
-					switch (it->cmd.buttons & BT_SPECIALMASK)
+					switch (player.cmd.buttons & BT_SPECIALMASK)
 					{
 					case BTS_PAUSE:
 						paused ^= 1;
 						if (paused)
+						{
 							S_PauseSound();
+							S_PauseMusic();
+						}
 						else
+						{
 							S_ResumeSound();
+							S_ResumeMusic();
+						}
 						break;
 					}
 				}
@@ -1118,14 +1123,20 @@ void G_Ticker (void)
 				case BTS_PAUSE:
 					paused ^= 1;
 					if (paused)
+					{
 						S_PauseSound();
+						S_PauseMusic();
+					}
 					else
+					{
 						S_ResumeSound();
+						S_ResumeMusic();
+					}
 					break;
 
 				case BTS_SAVEGAME:
-					if (!savedescription[0])
-						strcpy(savedescription, "NET GAME");
+					if (savedescription.empty())
+						savedescription = "NET GAME";
 					savegameslot = (player.cmd.buttons & BTS_SAVEMASK) >> BTS_SAVESHIFT;
 					gameaction = ga_savegame;
 					break;
@@ -1150,7 +1161,7 @@ void G_Ticker (void)
 				consoleplayer().mo = consoleplayer().camera = mobj->ptr();
 				consoleplayer().mo->player = &consoleplayer();
 				G_PlayerReborn(consoleplayer());
-				DPrintf("Did not receive spawn for consoleplayer.\n");
+				DPrintFmt("Did not receive spawn for consoleplayer.\n");
 			}
 
 			CL_SimulateWorld();
@@ -1511,11 +1522,11 @@ void G_DoReborn (player_t &player)
 	}
 
 	// try to spawn at one of the other players' spots
-	for (size_t i = 0; i < playerstarts.size(); i++)
+	for (auto& playerstart : playerstarts)
 	{
-		if (G_CheckSpot (player, &playerstarts[i]) )
+		if (G_CheckSpot (player, &playerstart) )
 		{
-			P_SpawnPlayer (player, &playerstarts[i]);
+			P_SpawnPlayer (player, &playerstart);
 			return;
 		}
 	}
@@ -1542,11 +1553,11 @@ void G_ScreenShot(const char* filename)
 // G_InitFromSavegame
 // Can be called by the startup code or the menu task.
 //
-char savename[256];
+std::string savename;
 
-void G_LoadGame (char* name)
+void G_LoadGame (const std::string& name)
 {
-	strcpy (savename, name);
+	savename = name;
 	gameaction = ga_loadgame;
 }
 
@@ -1558,7 +1569,7 @@ void G_DoLoadGame (void)
 
 	gameaction = ga_nothing;
 
-	FILE *stdfile = fopen (savename, "rb");
+	FILE *stdfile = fopen (savename.c_str(), "rb");
 	if (stdfile == NULL)
 	{
 		Printf (PRINT_HIGH, "Could not read savegame '%s'\n", savename);
@@ -1595,7 +1606,7 @@ void G_DoLoadGame (void)
 	FLZOFile savefile (stdfile, FFile::EReading);
 
 	if (!savefile.IsOpen ())
-		I_Error ("Savegame '%s' is corrupt\n", savename);
+		I_Error ("Savegame '{}' is corrupt\n", savename);
 
 	Printf (PRINT_HIGH, "Loading savegame '%s'...\n", savename);
 
@@ -1672,10 +1683,10 @@ void G_DoLoadGame (void)
 // Called by the menu task.
 // Description is a 24 byte text string
 //
-void G_SaveGame (int slot, char *description)
+void G_SaveGame (int slot, std::string_view description)
 {
 	savegameslot = slot;
-	strcpy (savedescription, description);
+	savedescription = description;
 	sendsave = true;
 }
 
@@ -1690,16 +1701,14 @@ void G_BuildSaveName(std::string &name, int slot)
 #ifdef _XBOX
 	std::string path = xbox_GetSavePath(name, slot);
 #else
-	std::string path = M_GetUserFileName(name.c_str());
+	std::string path = M_GetUserFileName(name);
 #endif
-	name = fmt::sprintf("%s" PATHSEP "odasv%d.ods", path.c_str(), slot);
+	name = fmt::sprintf("%s" PATHSEP "odasv%d.ods", path, slot);
 }
 
 void G_DoSaveGame()
 {
-	std::string name;
-	char *description;
-	int i;
+	std::string name, description;
 
 	G_SnapshotLevel ();
 
@@ -1714,12 +1723,12 @@ void G_DoSaveGame()
 	}
 
 #ifdef _XBOX
-	xbox_WriteSaveMeta(name.substr(0, name.rfind(PATHSEPCHAR)), description);
+	xbox_WriteSaveMeta(name.substr(0, name.rfind(PATHSEPCHAR)), description.c_str());
 #endif
 
-	Printf (PRINT_HIGH, "Saving game to '%s'...\n", name.c_str());
+	Printf (PRINT_HIGH, "Saving game to '%s'...\n", name);
 
-	fwrite (description, SAVESTRINGSIZE, 1, stdfile);
+	fwrite (description.c_str(), SAVESTRINGSIZE, 1, stdfile);
 	fwrite (SAVESIG, 16, 1, stdfile);
 	fwrite (level.mapname.c_str(), 8, 1, stdfile);
 
@@ -1742,27 +1751,27 @@ void G_DoSaveGame()
 
 	arc << level.time;
 
-	for (i = 0; i < NUM_WORLDVARS; i++)
+	for (int i = 0; i < NUM_WORLDVARS; i++)
 	{
 		arc << ACS_WorldVars[i];
 		ACSWorldGlobalArray worldarr = ACS_WorldArrays[i];
 		arc << worldarr.size();
-		for (ACSWorldGlobalArray::iterator it = worldarr.begin(); it != worldarr.end(); it++)
+		for (const auto [key, val] : worldarr)
 		{
-			arc << it->first;
-			arc << it->second;
+			arc << key;
+			arc << val;
 		}
 	}
 
-	for (i = 0; i < NUM_GLOBALVARS; i++)
+	for (int i = 0; i < NUM_GLOBALVARS; i++)
 	{
 		arc << ACS_GlobalVars[i];
 		ACSWorldGlobalArray globalarr = ACS_GlobalArrays[i];
 		arc << globalarr.size();
-		for (ACSWorldGlobalArray::iterator it = globalarr.begin(); it != globalarr.end(); it++)
+		for (const auto [key, val] : globalarr)
 		{
-			arc << it->first;
-			arc << it->second;
+			arc << key;
+			arc << val;
 		}
 	}
 
@@ -1797,7 +1806,7 @@ void G_ReadDemoTiccmd()
 	{
 		int demostep = (demoversion == LMP_DOOM_1_9_1) ? 5 : 4;
 
-		for (Players::iterator it = players.begin(); it != players.end(); ++it)
+		for (auto& player : players)
 		{
 			if ((demo_e - demo_p < demostep) || (*demo_p == DEMOMARKER))
 			{
@@ -1806,19 +1815,19 @@ void G_ReadDemoTiccmd()
 				return;
 			}
 
-			it->cmd.forwardmove = ((signed char)*demo_p++) << 8;
-			it->cmd.sidemove = ((signed char)*demo_p++) << 8;
+			player.cmd.forwardmove = ((signed char)*demo_p++) << 8;
+			player.cmd.sidemove = ((signed char)*demo_p++) << 8;
 
 			if (demoversion == LMP_DOOM_1_9)
 			{
-				it->cmd.yaw = ((unsigned char)*demo_p++) << 8;
+				player.cmd.yaw = ((unsigned char)*demo_p++) << 8;
 			}
 			else
 			{
-				it->cmd.yaw = ((unsigned short)*demo_p++);
-				it->cmd.yaw |= ((unsigned short)*demo_p++) << 8;
+				player.cmd.yaw = ((unsigned short)*demo_p++);
+				player.cmd.yaw |= ((unsigned short)*demo_p++) << 8;
 			}
-			it->cmd.buttons = (unsigned char)*demo_p++;
+			player.cmd.buttons = (unsigned char)*demo_p++;
 		}
 	}
 }
@@ -1898,7 +1907,7 @@ void G_DoPlayDemo(bool justStreamInput)
 	gameaction = ga_nothing;
 	int bytelen;
 
-	int demolump = W_CheckNumForName(defdemoname.c_str());
+	int demolump = W_CheckNumForName(defdemoname);
 	if (demolump != -1)
 	{
 		demobuffer = demo_p = (byte*)W_CacheLumpNum(demolump, PU_STATIC);
@@ -1910,7 +1919,7 @@ void G_DoPlayDemo(bool justStreamInput)
 		std::string found = M_FindUserFileName(::defdemoname, ".lmp");
 		if (found.empty())
 		{
-			Printf(PRINT_WARNING, "Could not find demo %s\n", ::defdemoname.c_str());
+			Printf(PRINT_WARNING, "Could not find demo %s\n", ::defdemoname);
 			gameaction = ga_fullconsole;
 			return;
 		}
@@ -1941,7 +1950,7 @@ void G_DoPlayDemo(bool justStreamInput)
 		demo_p[0] == DOOM_1_9p_DEMO ||
 		demo_p[0] == DOOM_1_9_1_DEMO)
 	{
-		Printf(PRINT_HIGH, "Playing DOOM demo %s\n", defdemoname.c_str());
+		Printf(PRINT_HIGH, "Playing DOOM demo %s\n", defdemoname);
 
 		demostartgametic = gametic;
 		demoversion = *demo_p++ == DOOM_1_9_1_DEMO ? LMP_DOOM_1_9_1 : LMP_DOOM_1_9;
@@ -1950,11 +1959,9 @@ void G_DoPlayDemo(bool justStreamInput)
 
 		byte episode = *demo_p++;
 		byte map = *demo_p++;
-		char mapname[32];
-		if (gameinfo.flags & GI_MAPxx)
-			snprintf(mapname, 32, "MAP%02d", map);
-		else
-			snprintf(mapname, 32, "E%dM%d", episode, map);
+		const OLumpName mapname = gameinfo.flags & GI_MAPxx ?
+			fmt::format("MAP{:02d}", map) :
+			fmt::format("E{}M{}", episode, map);
 
 		int deathmatch = *demo_p++;
 		bool monstersrespawn = *demo_p++;
@@ -1969,8 +1976,7 @@ void G_DoPlayDemo(bool justStreamInput)
 		{
 			if (*demo_p++ && !justStreamInput)
 			{
-				players.push_back(player_t());
-				player_t* player = &players.back();
+				player_t* player = &players.emplace_back();
 				player->playerstate = PST_REBORN;
 				player->id = (byte)i + 1;
 			}
@@ -2038,19 +2044,17 @@ void G_DoPlayDemo(bool justStreamInput)
 		}
 
 		// Set up the colors and names for the demo players
-		for (Players::iterator it = players.begin(); it != players.end(); ++it)
+		for (auto& player : players)
 		{
-			R_BuildClassicPlayerTranslation(it->id, it->id - 1);
-			argb_t color(translationRGB[it->id][0]);
+			R_BuildClassicPlayerTranslation(player.id, player.id - 1);
+			argb_t color(translationRGB[player.id][0]);
 
-			it->userinfo.color[0] = color.geta();
-			it->userinfo.color[1] = color.getr();
-			it->userinfo.color[2] = color.getg();
-			it->userinfo.color[3] = color.getb();
+			player.userinfo.color[0] = color.geta();
+			player.userinfo.color[1] = color.getr();
+			player.userinfo.color[2] = color.getg();
+			player.userinfo.color[3] = color.getb();
 
-			char tmpname[16];
-			snprintf(tmpname, 16, "Player %i", it->id);
-			it->userinfo.netname = tmpname;
+			player.userinfo.netname = fmt::format("Players {}", player.id);
 		}
 
 		if (!justStreamInput)
@@ -2128,7 +2132,7 @@ void G_CleanupDemo()
 ===================
 */
 
-BOOL G_CheckDemoStatus (void)
+bool G_CheckDemoStatus (void)
 {
 	if (demoplayback)
 	{
@@ -2185,4 +2189,4 @@ BOOL G_CheckDemoStatus (void)
 }
 
 
-VERSION_CONTROL (g_game_cpp, "$Id: 6f7597d09e8a79de3c7a8e31cae77da4b392145d $")
+VERSION_CONTROL (g_game_cpp, "$Id: f1fa83c11b89b180501ed967549e44d061ae502b $")
