@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: adcd3cb35f06a2799f86b7eb3343f0fd789892b0 $
+// $Id: e75b14a81e8f27561a544f6026893d17435e39e8 $
 //
 // Copyright (C) 2012 by Alex Mayfield.
 //
@@ -115,20 +115,20 @@ static bool cmpQueue(const player_t* arg1, const player_t* arg2)
 }
 
 // Returns true if a player is ingame.
-bool ingamePlayer(player_t* player)
+bool ingamePlayer(const player_t* player)
 {
 	return (player->ingame() && player->spectator == false);
 }
 
 // Returns true if a player is ingame and on a specific team
-bool inTeamPlayer(player_t* player, const byte team)
+bool inTeamPlayer(const player_t* player, const byte team)
 {
 	return (player->ingame() && player->userinfo.team == team &&
 	        player->spectator == false);
 }
 
 // Returns true if a player is a spectator
-bool spectatingPlayer(player_t* player)
+bool spectatingPlayer(const player_t* player)
 {
 	return (!player->ingame() || player->spectator == true);
 }
@@ -150,25 +150,25 @@ const PlayersView& sortedPlayers()
 	specInQueue.clear();
 	specNormal.clear();
 
-	for (Players::iterator it = ::players.begin(); it != ::players.end(); ++it)
+	for (auto& player : players)
 	{
-		if (!it->ingame())
+		if (!player.ingame())
 			continue;
 
-		if (it->spectator)
+		if (player.spectator)
 		{
-			if (it->QueuePosition > 0)
+			if (player.QueuePosition > 0)
 			{
-				specInQueue.push_back(&(*it));
+				specInQueue.push_back(&player);
 			}
 			else
 			{
-				specNormal.push_back(&(*it));
+				specNormal.push_back(&player);
 			}
 		}
 		else
 		{
-			inGame.push_back(&(*it));
+			inGame.push_back(&player);
 		}
 	}
 
@@ -205,16 +205,14 @@ const PlayersView& sortedPlayers()
 
 	std::sort(specInQueue.begin(), specInQueue.end(), cmpQueue);
 
-	for (std::vector<player_t*>::iterator it = inGame.begin(); it != inGame.end(); it++)
-		sortedplayers.push_back(*it);
+	for (auto& player : inGame)
+		sortedplayers.push_back(player);
 
-	for (std::vector<player_t*>::iterator it = specInQueue.begin();
-	     it != specInQueue.end(); it++)
-		sortedplayers.push_back(*it);
+	for (auto& player : specInQueue)
+		sortedplayers.push_back(player);
 
-	for (std::vector<player_t*>::iterator it = specNormal.begin(); it != specNormal.end();
-	     it++)
-		sortedplayers.push_back(*it);
+	for (auto& player : specNormal)
+		sortedplayers.push_back(player);
 
 	sp_tic = gametic;
 	return sortedplayers;
@@ -278,11 +276,11 @@ std::string HelpText()
 		if (queuePos > 0)
 		{
 			return fmt::sprintf("%s - " TEXTCOLOR_GREEN "%d%s" TEXTCOLOR_NORMAL " in line",
-			                    joinmsg.c_str(), queuePos, ordinal(queuePos));
+			                    joinmsg, queuePos, ordinal(queuePos));
 		}
 
 		return fmt::sprintf("%s - Press " TEXTCOLOR_GOLD "%s" TEXTCOLOR_NORMAL " to queue",
-		                    joinmsg.c_str(), ::Bindings.GetKeynameFromCommand("+use").c_str());
+		                    joinmsg, ::Bindings.GetKeynameFromCommand("+use"));
 	}
 
 	if (G_CanShowJoinTimer())
@@ -290,12 +288,12 @@ std::string HelpText()
 		return fmt::sprintf(
 		          "Press " TEXTCOLOR_GOLD "%s" TEXTCOLOR_NORMAL
 		          " to join - " TEXTCOLOR_GREEN "%d" TEXTCOLOR_NORMAL " secs left",
-		          ::Bindings.GetKeynameFromCommand("+use").c_str(),
+		          ::Bindings.GetKeynameFromCommand("+use"),
 		          ::levelstate.getJoinTimeLeft());
 	}
 
 	return fmt::sprintf("Press " TEXTCOLOR_GOLD "%s" TEXTCOLOR_NORMAL " to join",
-	                    ::Bindings.GetKeynameFromCommand("+use").c_str());
+	                    ::Bindings.GetKeynameFromCommand("+use"));
 }
 
 /**
@@ -316,7 +314,7 @@ std::string SpyPlayerName()
 		color = GetTeamInfo(plyr.userinfo.team)->TextColor.c_str();
 	}
 
-	return fmt::sprintf("%s%s", color, plyr.userinfo.netname.c_str());
+	return fmt::sprintf("%s%s", color, plyr.userinfo.netname);
 }
 
 /**
@@ -562,29 +560,29 @@ std::string PersonalScore()
 		{
 			if (g_winlimit)
 			{
-				str = fmt::sprintf("%s%d/%d", plyr_team.TextColor.c_str(),
+				str = fmt::sprintf("%s%d/%d", plyr_team.TextColor,
 				                   plyr_team.RoundWins, g_winlimit.asInt());
 			}
 			else
 			{
-				str = fmt::sprintf("%s%d", plyr_team.TextColor.c_str(), plyr.roundwins);
+				str = fmt::sprintf("%s%d", plyr_team.TextColor, plyr.roundwins);
 			}
 		}
 		else
 		{
 			if (G_UsesFraglimit() && sv_fraglimit > 0)
 			{
-				str = fmt::sprintf("%s%d/%d", plyr_team.TextColor.c_str(), plyr_team.Points,
+				str = fmt::sprintf("%s%d/%d", plyr_team.TextColor, plyr_team.Points,
 				                   sv_fraglimit.asInt());
 			}
 			else if (!G_UsesFraglimit() && sv_scorelimit > 0)
 			{
-				str = fmt::sprintf("%s%d/%d", plyr_team.TextColor.c_str(), plyr_team.Points,
+				str = fmt::sprintf("%s%d/%d", plyr_team.TextColor, plyr_team.Points,
 				                   sv_scorelimit.asInt());
 			}
 			else
 			{
-				str = fmt::sprintf("%s%d", plyr_team.TextColor.c_str(), plyr.fragcount);
+				str = fmt::sprintf("%s%d", plyr_team.TextColor, plyr.fragcount);
 			}
 		}
 	}
@@ -658,14 +656,11 @@ std::string NetdemoElapsed() {
 	timeelapsed -= minutes * 60;
 	uint8_t seconds = timeelapsed;
 
-	char str[12];
 	if (hours) {
-		snprintf(str, 12, "%02d:%02d:%02d", hours, minutes, seconds);
+		return fmt::format("{:02d}:{:02d}:{:02d}", hours, minutes, seconds);
 	} else {
-		snprintf(str, 12, "%02d:%02d", minutes, seconds);
+		return fmt::format("{:02d}:{:02d}", minutes, seconds);
 	}
-
-	return str;
 }
 
 // Return current map number/total maps in demo
@@ -710,27 +705,15 @@ std::string PlayersSplit() {
 // Returns the number of players on a team
 int CountTeamPlayers(byte team)
 {
-	int count = 0;
-	std::vector<player_t*> sortPlayers = sortedPlayers();
-	for (size_t i = 0; i < sortPlayers.size(); i++)
-	{
-		if (inTeamPlayer(sortPlayers[i], team))
-			count++;
-	}
-	return count;
+	const PlayersView& sortPlayers = sortedPlayers();
+	return std::count_if(sortPlayers.cbegin(), sortPlayers.cend(), [team](const auto& player) { return inTeamPlayer(player, team); });
 }
 
 // Returns the number of spectators on a team
 int CountSpectators()
 {
-	int count = 0;
-	std::vector<player_t*> sortPlayers = sortedPlayers();
-	for (size_t i = 0; i < sortPlayers.size(); i++)
-	{
-		if (spectatingPlayer(sortPlayers[i]))
-			count++;
-	}
-	return count;
+	const PlayersView& sortPlayers = sortedPlayers();
+	return std::count_if(sortPlayers.cbegin(), sortPlayers.cend(), [](const auto& player) { return spectatingPlayer(player); });
 }
 
 std::string TeamPlayers(int& color, byte team)
@@ -760,8 +743,7 @@ std::string TeamFrags(int& color, byte team)
 	color = V_GetTextColor(GetTeamInfo((team_t)team)->TextColor.c_str());
 
 	int fragcount = 0;
-	for (size_t i = 0;i < sortedPlayers().size();i++) {
-		player_t* player = sortedPlayers()[i];
+	for (const auto& player : sortedPlayers()) {
 		if (inTeamPlayer(player, team)) {
 			fragcount += player->fragcount;
 		}
@@ -807,11 +789,10 @@ void TeamLives(std::string& str, int& color, byte team)
 
 	PlayerResults results = PlayerQuery().hasLives().onTeam(static_cast<team_t>(team)).execute();
 	int lives = 0;
-	PlayersView::const_iterator it = results.players.begin();
-	for (; it != results.players.end(); ++it)
-		lives += (*it)->lives;
+	for (const auto& player : results.players)
+		lives += player->lives;
 
-	str = fmt::sprintf("%d", lives);
+	str = fmt::format("{}", lives);
 }
 
 std::string TeamKD(int& color, byte team) {
@@ -824,8 +805,7 @@ std::string TeamKD(int& color, byte team) {
 
 	int killcount = 0;
 	unsigned int deathcount = 0;
-	for (size_t i = 0;i < sortedPlayers().size();i++) {
-		player_t* player = sortedPlayers()[i];
+	for (const auto& player : sortedPlayers()) {
 		if (inTeamPlayer(player, team)) {
 			killcount += player->fragcount;
 			deathcount += player->deathcount;
@@ -852,8 +832,7 @@ std::string TeamPing(int& color, byte team) {
 	}
 
 	unsigned int ping = 0;
-	for (size_t i = 0;i < sortedPlayers().size();i++) {
-		player_t* player = sortedPlayers()[i];
+	for (const auto& player : sortedPlayers()) {
 		if (inTeamPlayer(player, team)) {
 			ping += player->ping;
 		}
@@ -967,9 +946,8 @@ void EleBar(const int x, const int y, const int w, const float scale,
 		drawX = x;
 	}
 
-	for (size_t i = 0; i < lineHandles.size(); i++)
+	for (const auto& patch : lineHandles)
 	{
-		patch_t* patch = lineHandles.at(i);
 		hud::DrawTranslatedPatch(drawX, y, scale, x_align, y_align, x_origin, y_origin,
 		                         patch, ::Ranges + color * 256);
 
@@ -993,13 +971,12 @@ void EAPlayerColors(int x, int y,
                     const short padding, const short limit)
 {
 	byte drawn = 0;
-	for (size_t i = 0; i < sortedPlayers().size(); i++)
+	for (const auto& player : sortedPlayers())
 	{
 		// Make sure we're not overrunning our limit.
 		if (limit != 0 && drawn >= limit)
 			break;
 
-		player_t* player = sortedPlayers()[i];
 		if (ingamePlayer(player))
 		{
 			argb_t playercolor = CL_GetPlayerColor(player);
@@ -1021,13 +998,12 @@ void EATeamPlayerColors(int x, int y,
                         const byte team)
 {
 	byte drawn = 0;
-	for (size_t i = 0; i < sortedPlayers().size(); i++)
+	for (const auto& player : sortedPlayers())
 	{
 		// Make sure we're not overrunning our limit.
 		if (limit != 0 && drawn >= limit)
 			break;
 
-		player_t* player = sortedPlayers()[i];
 		if (inTeamPlayer(player, team))
 		{
 			argb_t playercolor = CL_GetPlayerColor(player);
@@ -1046,13 +1022,13 @@ void EAPlayerNames(int x, int y, const float scale,
                    const short padding, const short limit,
                    const bool force_opaque) {
 	byte drawn = 0;
-	for (size_t i = 0;i < sortedPlayers().size();i++) {
+	for (const auto& player : sortedPlayers())
+	{
 		// Make sure we're not overrunning our limit.
 		if (limit != 0 && drawn >= limit) {
 			break;
 		}
 
-		player_t* player = sortedPlayers()[i];
 		if (ingamePlayer(player)) {
 			int color = CR_GREY;
 			if (player->id == displayplayer().id)
@@ -1100,13 +1076,13 @@ void EATeamPlayerNames(int x, int y, const float scale,
                        const short padding, const short limit,
                        const byte team, const bool force_opaque) {
 	byte drawn = 0;
-	for (size_t i = 0;i < sortedPlayers().size();i++) {
+	for (const auto& player : sortedPlayers())
+	{
 		// Make sure we're not overrunning our limit.
 		if (limit != 0 && drawn >= limit) {
 			break;
 		}
 
-		player_t* player = sortedPlayers()[i];
 		if (inTeamPlayer(player, team)) {
 			int color = CR_GREY;
 			if (G_IsTeamGame())
@@ -1133,13 +1109,12 @@ void EASpectatorNames(int x, int y, const float scale,
                       const bool force_opaque) {
 	byte drawn = 0;
 	std::vector<player_t*> sortPlayers = sortedPlayers();
-	for (size_t i = 0; i < sortPlayers.size(); i++)
+	for (const auto& player : sortedPlayers())
 	{
 		// Make sure we're not overrunning our limit.
 		if (limit != 0 && drawn >= limit)
 			break;
 
-		player_t* player = sortPlayers[i];
 		if (spectatingPlayer(player)) {
 			if (skip <= 0) {
 				int color = CR_GREY;
@@ -1183,7 +1158,7 @@ void EAPlayerRoundWins(int x, int y, const float scale, const x_align_t x_align,
                        const bool force_opaque)
 {
 	byte drawn = 0;
-	for (size_t i = 0; i < sortedPlayers().size(); i++)
+	for (const auto& player : sortedPlayers())
 	{
 		// Make sure we're not overrunning our limit.
 		if (limit != 0 && drawn >= limit)
@@ -1191,7 +1166,6 @@ void EAPlayerRoundWins(int x, int y, const float scale, const x_align_t x_align,
 			break;
 		}
 
-		player_t* player = sortedPlayers()[i];
 		if (ingamePlayer(player))
 		{
 			std::string buffer = fmt::sprintf("%d", player->roundwins);
@@ -1211,7 +1185,7 @@ void EAPlayerLives(int x, int y, const float scale, const x_align_t x_align,
                    const bool force_opaque)
 {
 	byte drawn = 0;
-	for (size_t i = 0; i < sortedPlayers().size(); i++)
+	for (const auto& player : sortedPlayers())
 	{
 		// Make sure we're not overrunning our limit.
 		if (limit != 0 && drawn >= limit)
@@ -1219,7 +1193,6 @@ void EAPlayerLives(int x, int y, const float scale, const x_align_t x_align,
 			break;
 		}
 
-		player_t* player = sortedPlayers()[i];
 		if (ingamePlayer(player))
 		{
 			std::string buffer = fmt::sprintf("%d", player->lives);
@@ -1239,7 +1212,7 @@ void EATeamPlayerLives(int x, int y, const float scale, const x_align_t x_align,
                        const byte team, const bool force_opaque)
 {
 	byte drawn = 0;
-	for (size_t i = 0; i < sortedPlayers().size(); i++)
+	for (const auto& player : sortedPlayers())
 	{
 		// Make sure we're not overrunning our limit.
 		if (limit != 0 && drawn >= limit)
@@ -1247,7 +1220,6 @@ void EATeamPlayerLives(int x, int y, const float scale, const x_align_t x_align,
 			break;
 		}
 
-		player_t* player = sortedPlayers()[i];
 		if (inTeamPlayer(player, team))
 		{
 			std::string buffer = fmt::sprintf("%d", player->lives);
@@ -1268,14 +1240,13 @@ void EAPlayerFrags(int x, int y, const float scale,
                    const bool force_opaque) {
 	byte drawn = 0;
 
-	for (size_t i = 0;i < sortedPlayers().size();i++) {
+	for (const auto& player : sortedPlayers())
+	{
 		// Make sure we're not overrunning our limit.
 		if (limit != 0 && drawn >= limit) {
 			break;
 		}
 
-		player_t* player = sortedPlayers()[i];
-
 		if (ingamePlayer(player)) {
 			std::ostringstream buffer;
 			buffer << player->fragcount;
@@ -1297,14 +1268,13 @@ void EATeamPlayerFrags(int x, int y, const float scale,
 	byte drawn = 0;
 	int frags = 0;
 
-	for (size_t i = 0;i < sortedPlayers().size();i++) {
+	for (const auto& player : sortedPlayers())
+	{
 		// Make sure we're not overrunning our limit.
 		if (limit != 0 && drawn >= limit) {
 			break;
 		}
 
-		player_t* player = sortedPlayers()[i];
-
 		if (G_IsRoundsGame() && G_IsLivesGame())
 		{
 			frags = player->totalpoints;
@@ -1334,7 +1304,7 @@ void EAPlayerDamage(int x, int y, const float scale, const x_align_t x_align,
                     const bool force_opaque)
 {
 	byte drawn = 0;
-	for (size_t i = 0; i < sortedPlayers().size(); i++)
+	for (const auto& player : sortedPlayers())
 	{
 		// Make sure we're not overrunning our limit.
 		if (limit != 0 && drawn >= limit)
@@ -1342,7 +1312,6 @@ void EAPlayerDamage(int x, int y, const float scale, const x_align_t x_align,
 			break;
 		}
 
-		player_t* player = sortedPlayers()[i];
 		if (ingamePlayer(player))
 		{
 			std::ostringstream buffer;
@@ -1363,13 +1332,13 @@ void EAPlayerKills(int x, int y, const float scale,
                    const short padding, const short limit,
                    const bool force_opaque) {
 	byte drawn = 0;
-	for (size_t i = 0;i < sortedPlayers().size();i++) {
+	for (const auto& player : sortedPlayers())
+	{
 		// Make sure we're not overrunning our limit.
 		if (limit != 0 && drawn >= limit) {
 			break;
 		}
 
-		player_t* player = sortedPlayers()[i];
 		if (ingamePlayer(player)) {
 			std::ostringstream buffer;
 			buffer << player->killcount;
@@ -1390,12 +1359,12 @@ void EAPlayerDeaths(int x, int y, const float scale,
                     const bool force_opaque) {
 	byte drawn = 0;
 	int deaths = 0;
-	for (size_t i = 0;i < sortedPlayers().size();i++) {
+	for (const auto& player : sortedPlayers())
+	{
 		// Make sure we're not overrunning our limit.
 		if (limit != 0 && drawn >= limit) {
 			break;
 		}
-		player_t* player = sortedPlayers()[i];
 
 		if (G_IsRoundsGame() && !G_IsDuelGame())
 		{
@@ -1428,14 +1397,13 @@ void EATeamPlayerPoints(int x, int y, const float scale,
 	byte drawn = 0;
 	int points = 0;
 
-	for (size_t i = 0;i < sortedPlayers().size();i++) {
+	for (const auto& player : sortedPlayers())
+	{
 		// Make sure we're not overrunning our limit.
 		if (limit != 0 && drawn >= limit) {
 			break;
 		}
 
-		player_t* player = sortedPlayers()[i];
-
 		if (G_IsRoundsGame())
 		{
 			points = player->totalpoints;
@@ -1466,13 +1434,13 @@ void EAPlayerKD(int x, int y, const float scale,
                 const short padding, const short limit,
                 const bool force_opaque) {
 	byte drawn = 0;
-	for (size_t i = 0;i < sortedPlayers().size();i++) {
+	for (const auto& player : sortedPlayers())
+	{
 		// Make sure we're not overrunning our limit.
 		if (limit != 0 && drawn >= limit) {
 			break;
 		}
 
-		player_t* player = sortedPlayers()[i];
 		if (ingamePlayer(player)) {
 			std::ostringstream buffer;
 			buffer.precision(2);
@@ -1502,13 +1470,13 @@ void EATeamPlayerKD(int x, int y, const float scale,
                     const short padding, const short limit,
                     const byte team, const bool force_opaque) {
 	byte drawn = 0;
-	for (size_t i = 0;i < sortedPlayers().size();i++) {
+	for (const auto& player : sortedPlayers())
+	{
 		// Make sure we're not overrunning our limit.
 		if (limit != 0 && drawn >= limit) {
 			break;
 		}
 
-		player_t* player = sortedPlayers()[i];
 		if (inTeamPlayer(player, team)) {
 			std::ostringstream buffer;
 			buffer.precision(2);
@@ -1537,13 +1505,13 @@ void EAPlayerTimes(int x, int y, const float scale,
                    const short padding, const short limit,
                    const bool force_opaque) {
 	byte drawn = 0;
-	for (size_t i = 0;i < sortedPlayers().size();i++) {
+	for (const auto& player : sortedPlayers())
+	{
 		// Make sure we're not overrunning our limit.
 		if (limit != 0 && drawn >= limit) {
 			break;
 		}
 
-		player_t* player = sortedPlayers()[i];
 		if (ingamePlayer(player)) {
 			std::ostringstream buffer;
 			buffer << player->GameTime / 60;
@@ -1564,13 +1532,13 @@ void EATeamPlayerTimes(int x, int y, const float scale,
                        const short padding, const short limit,
                        const byte team, const bool force_opaque) {
 	byte drawn = 0;
-	for (size_t i = 0;i < sortedPlayers().size();i++) {
+	for (const auto& player : sortedPlayers())
+	{
 		// Make sure we're not overrunning our limit.
 		if (limit != 0 && drawn >= limit) {
 			break;
 		}
 
-		player_t* player = sortedPlayers()[i];
 		if (inTeamPlayer(player, team)) {
 			std::ostringstream buffer;
 			buffer << player->GameTime / 60;
@@ -1590,13 +1558,13 @@ void EAPlayerPings(int x, int y, const float scale,
                    const short padding, const short limit,
                    const bool force_opaque) {
 	byte drawn = 0;
-	for (size_t i = 0;i < sortedPlayers().size();i++) {
+	for (const auto& player : sortedPlayers())
+	{
 		// Make sure we're not overrunning our limit.
 		if (limit != 0 && drawn >= limit) {
 			break;
 		}
 
-		player_t* player = sortedPlayers()[i];
 		if (ingamePlayer(player)) {
 			std::ostringstream buffer;
 			buffer << player->ping;
@@ -1617,13 +1585,13 @@ void EATeamPlayerPings(int x, int y, const float scale,
                        const short padding, const short limit,
                        const byte team, const bool force_opaque) {
 	byte drawn = 0;
-	for (size_t i = 0;i < sortedPlayers().size();i++) {
+	for (const auto& player : sortedPlayers())
+	{
 		// Make sure we're not overrunning our limit.
 		if (limit != 0 && drawn >= limit) {
 			break;
 		}
 
-		player_t* player = sortedPlayers()[i];
 		if (inTeamPlayer(player, team)) {
 			std::ostringstream buffer;
 			buffer << player->ping;
@@ -1645,13 +1613,13 @@ void EASpectatorPings(int x, int y, const float scale,
                       const short padding, short skip, const short limit,
                       const bool force_opaque) {
 	byte drawn = 0;
-	for (size_t i = 0;i < sortedPlayers().size();i++) {
+	for (const auto& player : sortedPlayers())
+	{
 		// Make sure we're not overrunning our limit.
 		if (limit != 0 && drawn >= limit) {
 			break;
 		}
 
-		player_t* player = sortedPlayers()[i];
 		if (spectatingPlayer(player)) {
 			if (skip <= 0) {
 				std::ostringstream buffer;
@@ -1702,21 +1670,21 @@ void EATargets(int x, int y, const float scale,
 	std::vector<TargetInfo_t> Targets;
 
 	// What players should be drawn?
-	for (Players::iterator it = players.begin();it != players.end();++it)
+	for (auto& player : players)
 	{
-		if (it->spectator || !(it->mo) || it->mo->health <= 0)
+		if (player.spectator || !(player.mo) || player.mo->health <= 0)
 			continue;
 
 		// We don't care about the player whose eyes we are looking through.
-		if (&*it == &(displayplayer()))
+		if (&player == &(displayplayer()))
 			continue;
 
-		if (!P_ActorInFOV(displayplayer().mo, it->mo, 45.0f, 512 * FRACUNIT))
+		if (!P_ActorInFOV(displayplayer().mo, player.mo, 45.0f, 512 * FRACUNIT))
 			continue;
 
 		// The server doesn't want us to see enemy target names.
 		if (!netdemoplaying && !::sv_allowtargetnames && !consoleplayer().spectator &&
-		    !P_AreTeammates(displayplayer(), *it))
+		    !P_AreTeammates(displayplayer(), player))
 		{
 			continue;
 		}
@@ -1725,15 +1693,15 @@ void EATargets(int x, int y, const float scale,
 		int color;
 		if (G_IsTeamGame()) {
 			// In teamgames, we want to use team colors for targets.
-			color = V_GetTextColor(GetTeamInfo(it->userinfo.team)->TextColor.c_str());
+			color = V_GetTextColor(GetTeamInfo(player.userinfo.team)->TextColor.c_str());
 		} else {
 			color = CR_GREY;
 		}
 
 		// Ok, make the temporary player info then add it
 		TargetInfo_t temp = {
-			&*it,
-			P_AproxDistance2(displayplayer().mo, it->mo) >> FRACBITS,
+			&player,
+			P_AproxDistance2(displayplayer().mo, player.mo) >> FRACBITS,
 			color
 		};
 		Targets.push_back(temp);
@@ -1758,7 +1726,7 @@ void EATargets(int x, int y, const float scale,
 
 	// [AM] New ElementArray drawing function
 	byte drawn = 0;
-	for (size_t i = 0; i < Targets.size(); i++)
+	for (const auto& target : Targets)
 	{
 		// Make sure we're not overrunning our limit.
 		if (limit != 0 && drawn >= limit)
@@ -1766,20 +1734,20 @@ void EATargets(int x, int y, const float scale,
 			break;
 		}
 
-		if (Targets[i].PlayPtr == &(consoleplayer()))
+		if (target.PlayPtr == &(consoleplayer()))
 		{
 			// You're looking at yourself.
 			hud::DrawText(x, y, scale, x_align, y_align, x_origin, y_origin, "You",
-			              Targets[i].Color);
+			              target.Color);
 		}
 		else
 		{
 			// Figure out if we should be showing this player's health.
 			std::string nameplate;
 			if (netdemoplaying || (::hud_targethealth_debug &&
-			                       P_AreTeammates(*Targets[i].PlayPtr, consoleplayer())))
+			                       P_AreTeammates(*target.PlayPtr, consoleplayer())))
 			{
-				int health = Targets[i].PlayPtr->health;
+				int health = target.PlayPtr->health;
 
 				const char* color;
 				if (health < 25)
@@ -1794,14 +1762,14 @@ void EATargets(int x, int y, const float scale,
 					color = TEXTCOLOR_LIGHTBLUE;
 
 				nameplate = fmt::sprintf("%s %s%d",
-				          Targets[i].PlayPtr->userinfo.netname.c_str(), color, health);
+				          target.PlayPtr->userinfo.netname, color, health);
 			}
 			else
 			{
-				nameplate = Targets[i].PlayPtr->userinfo.netname;
+				nameplate = target.PlayPtr->userinfo.netname;
 			}
 			hud::DrawText(x, y, scale, x_align, y_align, x_origin, y_origin,
-			              nameplate.c_str(), Targets[i].Color);
+			              nameplate.c_str(), target.Color);
 		}
 
 		y += 7 + padding;
