@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: bef3f897edc1e9544d2438142a2c03f72398e734 $
+// $Id: 443d1f0e2a88cedec561a676979d64b82e30d5b6 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -105,7 +105,7 @@ size_t 				saveCharIndex;	// which char we're editing
 // old save description before edit
 char				saveOldString[SAVESTRINGSIZE];
 
-BOOL 				menuactive;
+bool 				menuactive;
 
 int                 repeatKey;
 int                 repeatCount;
@@ -198,6 +198,28 @@ static IWindowSurface* fire_surface;
 static constexpr int fire_surface_width = 72;
 static constexpr int fire_surface_height = 77;
 
+static void M_PauseSound(void)
+{
+	if (paused || gamestate != GS_LEVEL || multiplayer || demoplayback ||
+	    netdemo.isPlaying())
+	{
+		return;
+	}
+
+	S_PauseSound();
+}
+
+static void M_ResumeSound(void)
+{
+	if (paused || gamestate != GS_LEVEL || multiplayer || demoplayback ||
+	    netdemo.isPlaying())
+	{
+		return;
+	}
+
+	S_ResumeSound();
+}
+
 //
 // DOOM MENU
 //
@@ -214,12 +236,12 @@ enum d1_main_t
 
 oldmenuitem_t DoomMainMenu[]=
 {
-	{1,"M_NGAME","\0",M_NewGame,'N'},
-	{1,"M_OPTION","\0",M_Options,'O'},	// [RH] Moved
-    {1,"M_LOADG","\0",M_LoadGame,'L'},
-    {1,"M_SAVEG","\0",M_SaveGame,'S'},
-    {1,"M_RDTHIS","\0",M_ReadThis,'R'},
-	{1,"M_QUITG","\0",M_QuitDOOM,'Q'}
+	{1,"M_NGAME","",M_NewGame,'N'},
+	{1,"M_OPTION","",M_Options,'O'},	// [RH] Moved
+    {1,"M_LOADG","",M_LoadGame,'L'},
+    {1,"M_SAVEG","",M_SaveGame,'S'},
+    {1,"M_RDTHIS","",M_ReadThis,'R'},
+	{1,"M_QUITG","",M_QuitDOOM,'Q'}
 };
 
 //
@@ -238,11 +260,11 @@ enum d2_main_t
 
 oldmenuitem_t Doom2MainMenu[]=
 {
-	{1,"M_NGAME","\0",M_NewGame,'N'},
-	{1,"M_OPTION","\0",M_Options,'O'},	// [RH] Moved
-    {1,"M_LOADG","\0",M_LoadGame,'L'},
-    {1,"M_SAVEG","\0",M_SaveGame,'S'},
-	{1,"M_QUITG","\0",M_QuitDOOM,'Q'}
+	{1,"M_NGAME","",M_NewGame,'N'},
+	{1,"M_OPTION","",M_Options,'O'},	// [RH] Moved
+    {1,"M_LOADG","",M_LoadGame,'L'},
+    {1,"M_SAVEG","",M_SaveGame,'S'},
+	{1,"M_QUITG","",M_QuitDOOM,'Q'}
 };
 
 
@@ -262,14 +284,16 @@ oldmenu_t MainDef =
 
 oldmenuitem_t EpisodeMenu[MAX_EPISODES] =
 {
-	{1,"\0","\0", M_Episode,0},
-	{1,"\0","\0", M_Episode,0},
-	{1,"\0","\0", M_Episode,0},
-	{1,"\0","\0", M_Episode,0},
-	{1,"\0","\0", M_Episode,0},
-	{1,"\0","\0", M_Episode,0},
-	{1,"\0","\0", M_Episode,0},
-	{1,"\0","\0", M_Episode,0}
+	{1,"","\0", M_Episode,0},
+	{1,"","\0", M_Episode,0},
+	{1,"","\0", M_Episode,0},
+	{1,"","\0", M_Episode,0},
+	{1,"","\0", M_Episode,0},
+	{1,"","\0", M_Episode,0},
+	{1,"","\0", M_Episode,0},
+	{1,"","\0", M_Episode,0},
+	{1,"","\0", M_Episode,0},
+	{1,"","\0", M_Episode,0}
 };
 
 oldmenu_t EpiDef =
@@ -315,14 +339,14 @@ oldmenu_t ExpDef =
 
 oldmenuitem_t NewGameMenu[MAX_SKILLS + 1]=
 {
-	{1,"\0","\0", M_ChooseSkill,0},
-	{1,"\0","\0", M_ChooseSkill,0},
-	{1,"\0","\0", M_ChooseSkill,0},
-	{1,"\0","\0", M_ChooseSkill,0},
-	{1,"\0","\0", M_ChooseSkill,0},
-	{1,"\0","\0", M_ChooseSkill,0},
-	{1,"\0","\0", M_ChooseSkill,0},
-	{1,"\0","\0", M_ChooseSkill,0},
+	{1,"","\0", M_ChooseSkill,0},
+	{1,"","\0", M_ChooseSkill,0},
+	{1,"","\0", M_ChooseSkill,0},
+	{1,"","\0", M_ChooseSkill,0},
+	{1,"","\0", M_ChooseSkill,0},
+	{1,"","\0", M_ChooseSkill,0},
+	{1,"","\0", M_ChooseSkill,0},
+	{1,"","\0", M_ChooseSkill,0},
 	//{1,"\0", M_ChooseSkill,0}
 };
 
@@ -510,7 +534,6 @@ oldmenu_t SaveDef =
 // through console commands.
 BEGIN_COMMAND (menu_main)
 {
-    S_Sound (CHAN_INTERFACE, "switches/normbutn", 1, ATTN_NONE);
 	M_StartControlPanel ();
 	M_SetupNextMenu (&MainDef);
 	PSetupDepth = 2;
@@ -520,7 +543,6 @@ END_COMMAND (menu_main)
 BEGIN_COMMAND (menu_help)
 {
     // F1
-    S_Sound (CHAN_INTERFACE, "switches/normbutn", 1, ATTN_NONE);
 	M_StartControlPanel ();
 	M_ReadThis(0);
 }
@@ -529,7 +551,6 @@ END_COMMAND (menu_help)
 BEGIN_COMMAND (menu_save)
 {
     // F2
-	S_Sound (CHAN_INTERFACE, "switches/normbutn", 1, ATTN_NONE);
 	M_StartControlPanel ();
 	M_SaveGame (0);
 	//Printf (PRINT_WARNING, "Saving is not available at this time.\n");
@@ -539,7 +560,6 @@ END_COMMAND (menu_save)
 BEGIN_COMMAND (menu_load)
 {
     // F3
-	S_Sound (CHAN_INTERFACE, "switches/normbutn", 1, ATTN_NONE);
 	M_StartControlPanel ();
 	M_LoadGame (0);
 	//Printf (PRINT_WARNING, "Loading is not available at this time.\n");
@@ -549,7 +569,6 @@ END_COMMAND (menu_load)
 BEGIN_COMMAND (menu_options)
 {
     // F4
-    S_Sound (CHAN_INTERFACE, "switches/normbutn", 1, ATTN_NONE);
     M_StartControlPanel ();
 	M_Options(0);
 	PSetupDepth = 1;
@@ -559,7 +578,6 @@ END_COMMAND (menu_options)
 BEGIN_COMMAND (quicksave)
 {
     // F6
-	S_Sound (CHAN_INTERFACE, "switches/normbutn", 1, ATTN_NONE);
 	M_StartControlPanel ();
 	M_QuickSave ();
 	//Printf (PRINT_WARNING, "Saving is not available at this time.\n");
@@ -568,7 +586,6 @@ END_COMMAND (quicksave)
 
 BEGIN_COMMAND (menu_endgame)
 {	// F7
-    S_Sound (CHAN_INTERFACE, "switches/normbutn", 1, ATTN_NONE);
 	M_StartControlPanel ();
 	M_EndGame(0);
 }
@@ -577,7 +594,6 @@ END_COMMAND (menu_endgame)
 BEGIN_COMMAND (quickload)
 {
     // F9
-	S_Sound (CHAN_INTERFACE, "switches/normbutn", 1, ATTN_NONE);
 	M_StartControlPanel ();
 	M_QuickLoad ();
 	//Printf (PRINT_WARNING, "Loading is not available at this time.\n");
@@ -586,7 +602,6 @@ END_COMMAND (quickload)
 
 BEGIN_COMMAND (menu_quit)
 {	// F10
-	S_Sound (CHAN_INTERFACE, "switches/normbutn", 1, ATTN_NONE);
 	M_StartControlPanel ();
 	M_QuitDOOM(0);
 }
@@ -594,7 +609,6 @@ END_COMMAND (menu_quit)
 
 BEGIN_COMMAND (menu_player)
 {
-    S_Sound (CHAN_INTERFACE, "switches/normbutn", 1, ATTN_NONE);
 	M_StartControlPanel ();
 	M_PlayerSetup(0);
 	PSetupDepth = 0;
@@ -630,7 +644,7 @@ void M_ReadSaveStrings()
 		FILE* handle = fopen(name.c_str(), "rb");
 		if (handle == NULL)
 		{
-			strcpy (&savegamestrings[i][0], GStrings(EMPTYSTRING));
+			M_StringCopy(&savegamestrings[i][0], GStrings(EMPTYSTRING), SAVESTRINGSIZE);
 			LoadSavegameMenu[i].status = 0;
 		}
 		else
@@ -638,7 +652,7 @@ void M_ReadSaveStrings()
 			const size_t readlen = fread (&savegamestrings[i], SAVESTRINGSIZE, 1, handle);
 			if (readlen < 1)
 			{
-				printf("M_Read_SaveStrings(): Failed to read handle.\n");
+				fmt::print("M_Read_SaveStrings(): Failed to read handle.\n");
 				fclose(handle);
 				return;
 			}
@@ -670,7 +684,7 @@ void M_LoadSelect (int choice)
 	std::string name;
 
 	G_BuildSaveName (name, choice);
-	G_LoadGame ((char *)name.c_str());
+	G_LoadGame(name);
 	gamestate = gamestate == GS_FULLCONSOLE ? GS_HIDECONSOLE : gamestate;
 	M_ClearMenus ();
 	if (quickSaveSlot == -2)
@@ -721,7 +735,7 @@ void M_DrawSave()
 //
 void M_DoSave (int slot)
 {
-	G_SaveGame (slot,savegamestrings[slot]);
+	G_SaveGame (slot, { savegamestrings[slot], 24 });
 	M_ClearMenus ();
 		// PICK QUICKSAVE SLOT YET?
 	if (quickSaveSlot == -2)
@@ -744,7 +758,7 @@ void M_SaveSelect (int choice)
 	genStringLen = SAVESTRINGSIZE-1;
 
 	saveSlot = choice;
-	strcpy(saveOldString,savegamestrings[choice]);
+	M_StringCopy(saveOldString, savegamestrings[choice], SAVESTRINGSIZE);
 
 	// If on a game console, auto-fill with date and time to save name
 
@@ -931,7 +945,7 @@ void M_DrawNewGame()
 	screen->DrawPatchClean(W_CachePatch("M_NEWG"), 96, 14);
 	screen->DrawPatchClean(W_CachePatch("M_SKILL"), 54, 38);
 
-	constexpr int SMALLFONT_OFFSET = 8; // Line up with the skull
+	static constexpr int SMALLFONT_OFFSET = 8; // Line up with the skull
 
 	const char* pslabel = "Pistol Start Each Level ";
 	const int psy = NewDef.y + (LINEHEIGHT * skillnum) + SMALLFONT_OFFSET;
@@ -953,7 +967,7 @@ namespace
 			}
 			else
 			{
-				strncpy(EpisodeMenu[i].name, EpisodeInfos[i].pic_name.c_str(), 8);
+				EpisodeMenu[i].name = EpisodeInfos[i].pic_name;
 			}
 
 			EpisodeMenu[i].alphaKey = EpisodeInfos[i].key;
@@ -973,13 +987,13 @@ namespace
 		    }
 		    else
 		    {
-			    strncpy(NewGameMenu[i].name, SkillInfos[i].pic_name.c_str(), 8);
+			    NewGameMenu[i].name = SkillInfos[i].pic_name;
 		    }
 
 			NewGameMenu[i].alphaKey = SkillInfos[i].shortcut;
 	    }
 
-		strncpy(NewGameMenu[i].name, "\0", 1);
+		NewGameMenu[i].name.clear();
 	    NewGameMenu[i].alphaKey = 'p';
 	}
 }
@@ -1002,7 +1016,7 @@ void M_NewGame(int choice)
 
 		if (episodenum > 4)
 		{
-			EpiDef.y -= LINEHEIGHT;
+			EpiDef.y -= LINEHEIGHT * (episodenum / 4);
 		}
 
 		epi = 0;
@@ -1031,7 +1045,7 @@ void M_DrawEpisode()
 
 	if (episodenum > 4)
 	{
-		y -= (LINEHEIGHT * (episodenum - 4));
+		y -= LINEHEIGHT * (episodenum / 4);
 	}
 
 	screen->DrawPatchClean(W_CachePatch("M_EPISOD"), 54, y);
@@ -1081,7 +1095,7 @@ void M_StartGame(int choice)
     }
     else
     {
-        G_DeferedInitNew (EpisodeMaps[epi].c_str());
+        G_DeferedInitNew (EpisodeMaps[epi]);
     }
 
     M_ClearMenus ();
@@ -1146,7 +1160,7 @@ void M_Expansion(int choice)
 //
 void M_DrawReadThis1()
 {
-	const patch_t *p = W_CachePatch(gameinfo.infoPage[0].c_str());
+	const patch_t *p = W_CachePatch(gameinfo.infoPage[0]);
 	screen->DrawPatchFullScreen(p, false);
 }
 
@@ -1155,7 +1169,7 @@ void M_DrawReadThis1()
 //
 void M_DrawReadThis2()
 {
-	const patch_t *p = W_CachePatch(gameinfo.infoPage[1].c_str());
+	const patch_t *p = W_CachePatch(gameinfo.infoPage[1]);
 	screen->DrawPatchFullScreen(p, false);
 }
 
@@ -1164,7 +1178,7 @@ void M_DrawReadThis2()
 //
 void M_DrawReadThis3()
 {
-	const patch_t *p = W_CachePatch(gameinfo.infoPage[2].c_str());
+	const patch_t *p = W_CachePatch(gameinfo.infoPage[2]);
 	screen->DrawPatchFullScreen(p, false);
 }
 
@@ -1194,6 +1208,7 @@ void M_EndGameResponse(int ch)
 	}
 
 	currentMenu->lastOn = itemOn;
+	S_StopAmbientSound();
 	M_ClearMenus ();
 	D_StartTitle ();
 	CL_QuitNetGame(NQ_SILENT);
@@ -1248,7 +1263,8 @@ void M_QuitDOOM(int choice)
 {
 	// We pick index 0 which is language sensitive,
 	//  or one at random, between 1 and maximum number.
-	static std::string endstring =
+	static std::string endstring;
+	endstring =
 		fmt::sprintf("%s\n\n%s",
 		             GStrings.getIndex(GStrings.toIndex(QUITMSG) + (gametic % NUM_QUITMESSAGES)),
 		             GStrings(DOSY));
@@ -1280,7 +1296,7 @@ EXTERN_CVAR (cl_autoaim)
 
 void M_PlayerSetup(int choice)
 {
-	strcpy(savegamestrings[0], cl_name.cstring());
+	M_StringCopy(savegamestrings[0], cl_name.cstring(), SAVESTRINGSIZE);
 	M_SetupNextMenu (&PSetupDef);
 	PlayerState = &states[mobjinfo[MT_PLAYER].seestate];
 	PlayerTics = PlayerState->tics;
@@ -1716,8 +1732,8 @@ static void M_EditPlayerName (int choice)
 	genStringLen = MAXPLAYERNAME;
 
 	saveSlot = 0;
-	strcpy(saveOldString,savegamestrings[0]);
-	if (!strcmp(savegamestrings[0],GStrings(EMPTYSTRING)))
+	M_StringCopy(saveOldString, savegamestrings[0], SAVESTRINGSIZE);
+	if (!strcmp(savegamestrings[0], GStrings(EMPTYSTRING)))
 		savegamestrings[0][0] = 0;
 	saveCharIndex = strlen(savegamestrings[0]);
 }
@@ -1940,7 +1956,7 @@ bool M_Responder (event_t* ev)
 			if (genStringEnter == oldmenustring_t::SAVEGAME)
 				M_ClearMenus();
 			genStringEnter = oldmenustring_t::NONE;
-			strcpy(&savegamestrings[saveSlot][0], saveOldString);
+			M_StringCopy(&savegamestrings[saveSlot][0], saveOldString, SAVESTRINGSIZE);
 		}
 		else if (Key_IsAcceptKey(ch))
 		{
@@ -1985,6 +2001,7 @@ bool M_Responder (event_t* ev)
 		}
 
 		menuactive = false;
+		M_ResumeSound();
 		S_Sound (CHAN_INTERFACE, "switches/exitbutn", 1, ATTN_NONE);
 		return true;
 	}
@@ -2134,6 +2151,8 @@ void M_StartControlPanel()
 	currentMenu = &MainDef;
 	itemOn = currentMenu->lastOn;
 	OptionsActive = false;			// [RH] Make sure none of the options menus appear.
+	M_PauseSound();
+	S_Sound(CHAN_INTERFACE, "switches/normbutn", 1, ATTN_NONE);
 }
 
 
@@ -2220,6 +2239,7 @@ void M_ClearMenus()
 	menuactive = false;
 	drawSkull = true;
 	M_DemoNoPlay = false;
+    M_ResumeSound();
 }
 
 
@@ -2261,7 +2281,6 @@ void M_PopMenuStack()
 		M_ClearMenus ();
 		if (currentMenu == &PSetupDef && PSetupDepth > 0)			// hack for PlayerSetup
 		{
-			S_Sound (CHAN_INTERFACE, "switches/normbutn", 1, ATTN_NONE);
 			M_StartControlPanel();
 			if (PSetupDepth == 2)
 				M_SetupNextMenu(&MainDef);
@@ -2356,4 +2375,4 @@ size_t M_FindCvarInMenu(cvar_t &cvar, menuitem_t *menu, size_t length)
 }
 
 
-VERSION_CONTROL (m_menu_cpp, "$Id: bef3f897edc1e9544d2438142a2c03f72398e734 $")
+VERSION_CONTROL (m_menu_cpp, "$Id: 443d1f0e2a88cedec561a676979d64b82e30d5b6 $")
