@@ -1,7 +1,7 @@
-// Emacs style mode select   -*- C++ -*- 
+// Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: cddd55dc53430b4bf495de85d2c31689cb96220a $
+// $Id: 1d290416b7976928151fdb5a374ab8012dd0a747 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -32,6 +32,7 @@
 #include "r_plane.h"
 #include "r_draw.h"
 #include "r_things.h"
+#include "r_sky.h"
 #include "p_local.h"
 #include "m_vectors.h"
 
@@ -93,10 +94,10 @@ void R_ReallocDrawSegs(void)
 	{
 		unsigned pos = ds_p - drawsegs;	// jff 8/9/98 fix from ZDOOM1.14a
 		unsigned newmax = maxdrawsegs ? maxdrawsegs*2 : 128; // killough
-		drawsegs = (drawseg_t*)Realloc(drawsegs, newmax*sizeof(*drawsegs));
+		drawsegs = (drawseg_t*)M_Realloc(drawsegs, newmax*sizeof(*drawsegs));
 		ds_p = drawsegs + pos;				// jff 8/9/98 fix from ZDOOM1.14a
 		maxdrawsegs = newmax;
-		DPrintf("MaxDrawSegs increased to %d\n", maxdrawsegs);
+		DPrintFmt("MaxDrawSegs increased to {}\n", maxdrawsegs);
 	}
 }
 
@@ -128,7 +129,7 @@ static void R_ClipWallSegment(int first, int last, bool makesolid)
 			// if all columns remaining are solid, we're done
 			byte* p = (byte*)memchr(solidcol + first, 0, last - first + 1);
 			if (p == NULL)
-				return; 
+				return;
 
 			first = p - solidcol;
 		}
@@ -304,7 +305,7 @@ sector_t *R_FakeFlat(sector_t *sec, sector_t *tempsec,
 			// will any columns of this window be visible or will they be blocked
 			// by 1s lines and closed doors?
 			if (memchr(solidcol + rw_start, 0, rw_stop - rw_start + 1) != NULL)
-			{	
+			{
 				doorunderwater = true;
 				r_fakingunderwater = true;
 			}
@@ -335,7 +336,7 @@ sector_t *R_FakeFlat(sector_t *sec, sector_t *tempsec,
 		tempsec->ceilingplane		= s->floorplane;
 		P_InvertPlane(&tempsec->ceilingplane);
 		P_ChangeCeilingHeight(tempsec, -1);
-		if (s->ceilingpic == skyflatnum)
+		if (R_IsSkyFlat(s->ceilingpic))
 		{
 			tempsec->floorplane			= tempsec->ceilingplane;
 			P_InvertPlane(&tempsec->floorplane);
@@ -399,7 +400,7 @@ sector_t *R_FakeFlat(sector_t *sec, sector_t *tempsec,
 		tempsec->base_floor_angle	= tempsec->base_ceiling_angle	= s->base_ceiling_angle;
 		tempsec->base_floor_yoffs	= tempsec->base_ceiling_yoffs	= s->base_ceiling_yoffs;
 
-		if (s->floorpic != skyflatnum)
+		if (!R_IsSkyFlat(s->floorpic))
 		{
 			tempsec->ceilingplane	= sec->ceilingplane;
 			tempsec->floorpic		= s->floorpic;
@@ -495,11 +496,11 @@ void R_AddLine (seg_t *line)
 
 		// if door is closed because back is shut:
 		((rw_backcz1 <= rw_backfz1 && rw_backcz2 <= rw_backfz2) &&
-		
+
 		// preserve a kind of transparent door/lift special effect:
 		((rw_backcz1 >= rw_frontcz1 && rw_backcz2 >= rw_frontcz2) ||
 		 line->sidedef->toptexture) &&
-		
+
 		((rw_backfz1 <= rw_frontfz1 && rw_backfz2 <= rw_frontfz2) ||
 		 line->sidedef->bottomtexture) &&
 
@@ -618,7 +619,7 @@ static bool R_CheckBBox(const fixed_t *bspcoord)
 	{
 		v2fixed_t p1 = box_pts[i][0];
 		v2fixed_t p2 = box_pts[i][1];
-		
+
 		if (R_PointOnLine(0, 0, p1.x, p1.y, p2.x, p2.y))
 			return true;
 
@@ -630,7 +631,7 @@ static bool R_CheckBBox(const fixed_t *bspcoord)
 			int x2 = R_ProjectPointX(p2.x, p2.y) - 1;
 			if (R_CheckProjectionX(x1, x2))
 			{
-				if (memchr(solidcol + x1, 0, x2 - x1 + 1) != NULL)	
+				if (memchr(solidcol + x1, 0, x2 - x1 + 1) != NULL)
 					return true;
 			}
 		}
@@ -656,9 +657,9 @@ void R_Subsector (int num)
 
 #ifdef RANGECHECK
     if (num>=numsubsectors)
-		I_Error ("R_Subsector: ss %i with numss = %i",
-				 num,
-				 numsubsectors);
+		I_Error("R_Subsector: ss {} with numss = {}",
+				num,
+				numsubsectors);
 #endif
 
 	sub = &subsectors[num];
@@ -673,12 +674,12 @@ void R_Subsector (int num)
 	basecolormap = frontsector->colormap->maps;
 
 	ceilingplane = P_CeilingHeight(viewx, viewy, frontsector) > viewz ||
-		frontsector->ceilingpic == skyflatnum ||
-		(frontsector->heightsec && 
-		!(frontsector->heightsec->MoreFlags & SECF_IGNOREHEIGHTSEC) && 
-		frontsector->heightsec->floorpic == skyflatnum) ?
+		R_IsSkyFlat(frontsector->ceilingpic) ||
+		(frontsector->heightsec &&
+		!(frontsector->heightsec->MoreFlags & SECF_IGNOREHEIGHTSEC) &&
+		R_IsSkyFlat(frontsector->heightsec->floorpic)) ?
 		R_FindPlane(frontsector->ceilingplane,		// killough 3/8/98
-					frontsector->ceilingpic == skyflatnum &&  // killough 10/98
+					R_IsSkyFlat(frontsector->ceilingpic) &&  // killough 10/98
 						frontsector->sky & PL_SKYFLAT ? frontsector->sky :
 						frontsector->ceilingpic,
 					ceilinglightlevel,				// killough 4/11/98
@@ -695,9 +696,9 @@ void R_Subsector (int num)
 	floorplane = P_FloorHeight(viewx, viewy, frontsector) < viewz || // killough 3/7/98
 		(frontsector->heightsec &&
 		!(frontsector->heightsec->MoreFlags & SECF_IGNOREHEIGHTSEC) &&
-		frontsector->heightsec->ceilingpic == skyflatnum) ?
+		R_IsSkyFlat(frontsector->heightsec->ceilingpic)) ?
 		R_FindPlane(frontsector->floorplane,
-					frontsector->floorpic == skyflatnum &&  // killough 10/98
+					R_IsSkyFlat(frontsector->floorpic) &&  // killough 10/98
 						frontsector->sky & PL_SKYFLAT ? frontsector->sky :
 						frontsector->floorpic,
 					floorlightlevel,				// killough 3/16/98
@@ -723,7 +724,7 @@ void R_Subsector (int num)
 	{
 		for (WORD i = ParticlesInSubsec[num]; i != NO_PARTICLE; i = Particles[i].nextinsubsector)
 			R_ProjectParticle(Particles + i, subsectors[num].sector, FakeSide);
-	}		
+	}
 
 	if (sub->poly)
 	{ // Render the polyobj in the subsector first
@@ -732,7 +733,7 @@ void R_Subsector (int num)
 		while (polyCount--)
 			R_AddLine (*polySeg++);
 	}
-	
+
 	while (count--)
 		R_AddLine (line++);
 }
@@ -769,4 +770,4 @@ void R_RenderBSPNode (int bspnum)
 }
 
 
-VERSION_CONTROL (r_bsp_cpp, "$Id: cddd55dc53430b4bf495de85d2c31689cb96220a $")
+VERSION_CONTROL (r_bsp_cpp, "$Id: 1d290416b7976928151fdb5a374ab8012dd0a747 $")
