@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 224045131d870fdd2b2cbb90bc67f8caf0ab6057 $
+// $Id: d0a6d8fa9b6f2dbc5c83d0b95529405303b52cd1 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -72,38 +72,13 @@ fixed_t			fovtan;
 float			focratio;
 float			ifocratio;
 
-// increment every time a check is made
-int 			validcount = 1;
-
 // [RH] colormap currently drawing with
 shaderef_t		basecolormap;
 int				fixedlightlev;
 shaderef_t		fixedcolormap;
 
-int 			centerx;
-int				centery;
-
-fixed_t 		centerxfrac;
-fixed_t 		centeryfrac;
-fixed_t			yaspectmul;
-
 // just for profiling purposes
 int 			framecount;
-int 			linecount;
-int 			loopcount;
-
-fixed_t 		viewx;
-fixed_t 		viewy;
-fixed_t 		viewz;
-
-angle_t 		viewangle;
-sector_t*		viewsector;
-LocalView		localview;
-
-fixed_t 		viewcos;
-fixed_t 		viewsin;
-
-AActor			*camera;	// [RH] camera to draw from. doesn't have to be a player
 
 //
 // precalculated math tables
@@ -119,12 +94,6 @@ int				zlight[LIGHTLEVELS][MAXLIGHTZ];
 int				lightscalexmul;
 int				lightscaleymul;
 
-// bumped light from gun blasts
-int 			extralight;
-
-// [RH] ignore extralight and fullbright
-BOOL			foggy;
-
 static bool		setsizeneeded = true;
 int				setblocks;
 
@@ -144,8 +113,6 @@ void (*spanslopefunc) (void);
 int FieldOfView = 2048;
 int CorrectFieldOfView = 2048;
 
-fixed_t			render_lerp_amount;
-
 static void R_InitViewWindow();
 
 IWindowSurface* screenblocks_surface;
@@ -614,7 +581,7 @@ void R_SetViewSize(int blocks)
 
 CVAR_FUNC_IMPL(screenblocks)
 {
-	R_SetViewSize((int)var);
+	R_SetViewSize(var.asInt());
 }
 
 
@@ -1322,4 +1289,4 @@ void R_ExitLevel()
 	r_underwater = false;
 }
 
-VERSION_CONTROL (r_main_cpp, "$Id: 224045131d870fdd2b2cbb90bc67f8caf0ab6057 $")
+VERSION_CONTROL (r_main_cpp, "$Id: d0a6d8fa9b6f2dbc5c83d0b95529405303b52cd1 $")
