@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 77f7a7db9901d39da3b0c7ccb200b6f792c4e3c7 $
+// $Id: 1f17e03524ba2494783aef9e65e228f542f16d76 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -45,13 +45,12 @@ extern fixed_t freelookviewheight;
 EXTERN_CVAR(sv_freelook)
 EXTERN_CVAR(cl_mouselook)
 EXTERN_CVAR(r_skypalette)
+EXTERN_CVAR(r_linearsky)
 
 
 //
 // sky mapping
 //
-int 		skyflatnum;
-int 		sky1texture,    sky2texture;
 fixed_t		defaultskytexturemid;
 fixed_t		skyscale;
 int			skystretch;
@@ -59,21 +58,18 @@ fixed_t		skyheight;
 fixed_t		skyiscale;
 
 int			sky1shift,        sky2shift;
-fixed_t		sky2scrollxdelta;
-fixed_t		sky2columnoffset;
 
 // The xtoviewangleangle[] table maps a screen pixel
 // to the lowest viewangle that maps back to x ranges
 // from clipangle to -clipangle.
 static angle_t xtoviewangle[MAXWIDTH + 1];
+static angle_t linearskyangle[MAXWIDTH + 1];
 
 CVAR_FUNC_IMPL(r_stretchsky)
 {
 	R_InitSkyMap ();
 }
 
-OLumpName SKYFLATNAME = "F_SKY1";
-
 static tallpost_t* skyposts[MAXWIDTH];
 static byte transparentskybuffer[MAXWIDTH][512]; // holds foreground sky with transparency to blit to the screen
 
@@ -241,17 +237,27 @@ static void R_InitXToViewAngle()
 			const fixed_t dfocus = FocalLengthX >> DBITS;
 
 			for (int i = centerx, slope = 0; i <= t; i++, slope += slopestep)
-				xtoviewangle[i] = (angle_t)-(signed)tantoangle[slope >> DBITS];
+			{
+				xtoviewangle[i]   = (angle_t)-(signed)tantoangle[slope >> DBITS];
+				linearskyangle[i] = (0.5 - i / (double)viewwidth) * FIXED2DOUBLE(hitan) * ANG90;
+			}
 
 			for (int i = t + 1; i <= viewwidth; i++)
-				xtoviewangle[i] = ANG270+tantoangle[dfocus / (i - centerx)];
+			{
+				xtoviewangle[i]   = ANG270+tantoangle[dfocus / (i - centerx)];
+				linearskyangle[i] = (0.5 - i / (double)viewwidth) * FIXED2DOUBLE(hitan) * ANG90;
+			}
 
 			for (int i = 0; i < centerx; i++)
-				xtoviewangle[i] = (angle_t)(-(signed)xtoviewangle[viewwidth-i-1]);
+			{
+				xtoviewangle[i]   = (angle_t)(-(signed)xtoviewangle[viewwidth-i-1]);
+				linearskyangle[i] = (angle_t)(-(signed)linearskyangle[viewwidth-i-1]);
+			}
 		}
 		else
 		{
 			memset(xtoviewangle, 0, sizeof(angle_t) * viewwidth + 1);
+			memset(linearskyangle, 0, sizeof(angle_t) * viewwidth + 1);
 		}
 
 		last_viewwidth = viewwidth;
@@ -325,12 +331,12 @@ sky_t* R_GetSky(const OLumpName& name, bool create)
 		return found->second;
 	}
 
-	if(!create)
+	if (!create)
 	{
 		return nullptr;
 	}
 
-	int32_t tex = R_TextureNumForName(name.c_str());
+	int32_t tex = R_TextureNumForName(name);
 	if (tex < 0) return nullptr;
 
 	OLumpName skytexname;
@@ -340,7 +346,7 @@ sky_t* R_GetSky(const OLumpName& name, bool create)
 	sky->background.scrolly = INT2FIXED(0);
 	if (level.flags & LEVEL_DOUBLESKY)
 	{
-		sky->background.texnum = R_TextureNumForName(level.skypic2.c_str());
+		sky->background.texnum = R_TextureNumForName(level.skypic2);
 		sky->background.texture = level.skypic2;
 		sky->background.scrollx = level.sky2ScrollDelta & 0xffffff;
 		sky->foreground.scrollx = level.sky1ScrollDelta & 0xffffff;
@@ -378,10 +384,10 @@ void R_InitSkyDefs()
 		const Json::Value& skyarray = elem["skies"];
 		const Json::Value& flatmappings = elem["flatmapping"];
 
-		if(!(skyarray.isArray() || skyarray.isNull())) return jsonlumpresult_t::PARSEERROR;
-		if(!(flatmappings.isArray() || flatmappings.isNull())) return jsonlumpresult_t::PARSEERROR;
+		if (!(skyarray.isArray() || skyarray.isNull())) return jsonlumpresult_t::PARSEERROR;
+		if (!(flatmappings.isArray() || flatmappings.isNull())) return jsonlumpresult_t::PARSEERROR;
 
-		for(const Json::Value& skyelem : skyarray)
+		for (const Json::Value& skyelem : skyarray)
 		{
 			const Json::Value& type     = skyelem["type"];
 
@@ -396,13 +402,13 @@ void R_InitSkyDefs()
 			const Json::Value& foreelem = skyelem["foregroundtex"];
 
 			auto skytype = static_cast<skytype_t>(type.asInt());
-			if(skytype < skytype_t::NORMAL || skytype > skytype_t::DOUBLESKY) return jsonlumpresult_t::PARSEERROR;
+			if (skytype < skytype_t::NORMAL || skytype > skytype_t::DOUBLESKY) return jsonlumpresult_t::PARSEERROR;
 
 			OLumpName skytexname = skytex.asString();
-			int32_t tex = R_TextureNumForName(skytexname.c_str());
-			if(tex < 0) return jsonlumpresult_t::PARSEERROR;
+			int32_t tex = R_TextureNumForName(skytexname);
+			if (tex < 0) return jsonlumpresult_t::PARSEERROR;
 
-			if(!mid.isNumeric()
+			if (!mid.isNumeric()
 			   || !scrollx.isNumeric()
 			   || !scrolly.isNumeric()
 			   || !scalex.isNumeric()
@@ -416,7 +422,7 @@ void R_InitSkyDefs()
 			sky->type = skytype;
 			sky->usedefaultmid = false;
 
-			constexpr float_t ticratescale = 1.0 / TICRATE;
+			static constexpr float_t ticratescale = 1.0 / TICRATE;
 
 			sky->background.texnum  = tex;
 			sky->background.texture = skytexname;
@@ -426,25 +432,25 @@ void R_InitSkyDefs()
 			sky->background.scalex  = FLOAT2FIXED(1.0f / scalex.asFloat());
 			sky->background.scaley  = FLOAT2FIXED(1.0f / scaley.asFloat());
 
-			if(sky->type == skytype_t::FIRE)
+			if (sky->type == skytype_t::FIRE)
 			{
-				if(!fireelem.isObject()) return jsonlumpresult_t::PARSEERROR;
+				if (!fireelem.isObject()) return jsonlumpresult_t::PARSEERROR;
 
 				const Json::Value& firepalette    = fireelem["palette"];
 				const Json::Value& fireupdatetime = fireelem["updatetime"];
 
-				if(!firepalette.isArray()) return jsonlumpresult_t::PARSEERROR;
+				if (!firepalette.isArray()) return jsonlumpresult_t::PARSEERROR;
 				sky->numfireentries = (int32_t)firepalette.size();
 				byte* output = sky->firepalette = (byte*)Z_Malloc(sizeof(byte) * sky->numfireentries, PU_STATIC, nullptr);
-				for(const Json::Value& palentry : firepalette)
+				for (const Json::Value& palentry : firepalette)
 				{
 					*output++ = palentry.asUInt();
 				}
 				sky->fireticrate = (int32_t)(fireupdatetime.asFloat() * TICRATE);
 			}
-			else if(sky->type == skytype_t::DOUBLESKY)
+			else if (sky->type == skytype_t::DOUBLESKY)
 			{
-				if(!foreelem.isObject()) return jsonlumpresult_t::PARSEERROR;
+				if (!foreelem.isObject()) return jsonlumpresult_t::PARSEERROR;
 
 				const Json::Value& foreskytex  = foreelem["name"];
 				const Json::Value& foremid     = foreelem["mid"];
@@ -454,10 +460,10 @@ void R_InitSkyDefs()
 				const Json::Value& forescaley  = foreelem["scaley"];
 
 				OLumpName foreskytexname = foreskytex.asString();
-				int32_t foretex = R_TextureNumForName(foreskytexname.c_str());
-				if(foretex < 0) return jsonlumpresult_t::PARSEERROR;
+				int32_t foretex = R_TextureNumForName(foreskytexname);
+				if (foretex < 0) return jsonlumpresult_t::PARSEERROR;
 
-				if(!foremid.isNumeric()
+				if (!foremid.isNumeric()
 				   || !forescrollx.isNumeric()
 				   || !forescrolly.isNumeric()
 				   || !forescalex.isNumeric()
@@ -476,20 +482,20 @@ void R_InitSkyDefs()
 			}
 			else
 			{
-				if(!fireelem.isNull() || !foreelem.isNull()) return jsonlumpresult_t::PARSEERROR;
+				if (!fireelem.isNull() || !foreelem.isNull()) return jsonlumpresult_t::PARSEERROR;
 			}
 
 			skylookup[skytexname] = sky;
 		}
 
-		for(const Json::Value& flatentry : flatmappings)
+		for (const Json::Value& flatentry : flatmappings)
 		{
 			const Json::Value& flatelem = flatentry["flat"];
 			const Json::Value& skyelem = flatentry["sky"];
 
 			OLumpName flatname = flatelem.asString();
-			int32_t flatnum = R_FlatNumForName(flatname.c_str());
-			if(flatnum < 0 || flatnum >= ::numflats) return jsonlumpresult_t::PARSEERROR;
+			int32_t flatnum = R_FlatNumForName(flatname);
+			if (flatnum < 0 || flatnum >= ::numflats) return jsonlumpresult_t::PARSEERROR;
 
 			OLumpName skyname = skyelem.asString();
 			sky_t* sky = R_GetSky(skyname, true);
@@ -502,7 +508,7 @@ void R_InitSkyDefs()
 
 	jsonlumpresult_t result =  M_ParseJSONLump("SKYDEFS", "skydefs", { 1, 0, 0 }, ParseSkydef);
 	if (result != jsonlumpresult_t::SUCCESS && result != jsonlumpresult_t::NOTFOUND)
-		I_Error("R_InitSkyDefs: SKYDEFS JSON error: %s", M_JSONLumpResultToString(result));
+		I_Error("R_InitSkyDefs: SKYDEFS JSON error: {}", M_JSONLumpResultToString(result));
 }
 
 void R_ClearSkyDefs()
@@ -515,7 +521,7 @@ void spreadFire(int src, byte* firepixels, int width)
 {
 	const byte pixel = firepixels[src];
 	const int copyloc0 = src - width;
-	if(pixel == 0) {
+	if (pixel == 0) {
 		if (copyloc0 >= 0)
 			firepixels[copyloc0] = 0;
 	} else {
@@ -531,13 +537,13 @@ static void R_UpdateFireSky(sky_t* sky, bool init = false)
 	if (gametic % sky->fireticrate != 0 && !init) return;
 	const int texnum = sky->background.texnum;
 	texture_t* tex = textures[texnum];
-    for (int x = 0 ; x < tex->width; x++)
+	for (int x = 0 ; x < tex->width; x++)
 	{
-        for (int y = 1; y < tex->height; y++)
+		for (int y = 1; y < tex->height; y++)
 		{
-            spreadFire(y * tex->width + x, sky->firetexturedata, tex->width);
-        }
-    }
+			spreadFire(y * tex->width + x, sky->firetexturedata, tex->width);
+		}
+	}
 	byte* coldata;
 	for (int x = 0; x < tex->width; x++)
 	{
@@ -575,7 +581,7 @@ static void R_UpdateSky(sky_t* sky)
 	sky->background.currx += sky->background.scrollx;
 	sky->background.curry += sky->background.scrolly;
 
-	if(sky->type == skytype_t::FIRE)
+	if (sky->type == skytype_t::FIRE)
 	{
 		R_UpdateFireSky(sky);
 	}
@@ -584,9 +590,9 @@ static void R_UpdateSky(sky_t* sky)
 
 void R_UpdateSkies()
 {
-	for(auto& [_, sky] : skylookup)
+	for (auto& [_, sky] : skylookup)
 	{
-		if(sky->active)
+		if (sky->active)
 		{
 			R_UpdateSky(sky);
 		}
@@ -612,7 +618,7 @@ void R_ActivateSky(sky_t* sky)
 
 void R_ActivateSkies(const byte* hitlist, std::vector<int>& skytextures)
 {
-	for(auto& [flat, sky] : skyflatlookup)
+	for (auto& [flat, sky] : skyflatlookup)
 	{
 		if (hitlist[flat])
 			R_ActivateSky(sky);
@@ -632,7 +638,7 @@ void R_ActivateSkies(const byte* hitlist, std::vector<int>& skytextures)
 
 void R_InitSkiesForLevel()
 {
-	for(auto& [_, sky] : skylookup)
+	for (auto& [_, sky] : skylookup)
 	{
 		sky->active = false;
 		sky->foreground.currx = 0;
@@ -706,7 +712,7 @@ inline bool R_PostDataIsTransparent(byte* data)
 
 bool R_IsSkyFlat(int flatnum)
 {
-	return skyflatlookup.count(flatnum);
+	return flatnum == skyflatnum || skyflatlookup.count(flatnum);
 }
 
 //
@@ -723,13 +729,14 @@ void R_RenderSkyRange(visplane_t* pl)
 	if (pl->minx > pl->maxx)
 		return;
 
-	constexpr int columnmethod = 2;
+	static constexpr int columnmethod = 2;
 	int frontskytex, backskytex;
 	fixed_t front_offset = 0;
 	fixed_t back_offset = 0;
 	fixed_t frontrow_offset = 0;
 	fixed_t backrow_offset = 0;
 	angle_t skyflip = 0;
+	const angle_t* xtoskyangle = r_linearsky.asBool() ? linearskyangle : xtoviewangle;
 
 	auto skyflat = skyflatlookup.find(pl->picnum);
 
@@ -801,7 +808,7 @@ void R_RenderSkyRange(visplane_t* pl)
 		front_offset = (-side->textureoffset) >> 6;
 
 		// Vertical offset allows careful sky positioning.
-		defaultskytexturemid = side->rowoffset - 28*FRACUNIT;
+		sky1mid = side->rowoffset - 28*FRACUNIT;
 
 		// We sometimes flip the picture horizontally.
 		//
@@ -844,7 +851,7 @@ void R_RenderSkyRange(visplane_t* pl)
 
 		for (int x = pl->minx; x <= pl->maxx; x++)
 		{
-			int sky2colnum = ((((viewangle + xtoviewangle[x]) ^ skyflip) >> sky2shift) + back_offset) >> FRACBITS;
+			int sky2colnum = ((((viewangle + xtoskyangle[x]) ^ skyflip) >> sky2shift) + back_offset) >> FRACBITS;
 			sky2colnum = FIXED2INT(FixedMul(INT2FIXED(sky2colnum), sky2scalex));
 			tallpost_t* skypost = R_GetTextureColumn(backskytex, sky2colnum);
 			skyposts[x] = skypost;
@@ -863,7 +870,7 @@ void R_RenderSkyRange(visplane_t* pl)
 	{
 		for (int x = pl->minx; x <= pl->maxx; x++)
 		{
-			int sky1colnum = ((((viewangle + xtoviewangle[x]) ^ skyflip) >> sky1shift) + front_offset) >> FRACBITS;
+			int sky1colnum = ((((viewangle + xtoskyangle[x]) ^ skyflip) >> sky1shift) + front_offset) >> FRACBITS;
 			sky1colnum = FIXED2INT(FixedMul(INT2FIXED(sky1colnum), sky1scalex));
 			tallpost_t* skypost = R_GetTextureColumn(frontskytex, sky1colnum);
 			skyposts[x] = skypost;
@@ -876,7 +883,7 @@ void R_RenderSkyRange(visplane_t* pl)
 	{
 		for (int x = pl->minx; x <= pl->maxx; x++)
 		{
-			int sky1colnum = ((((viewangle + xtoviewangle[x]) ^ skyflip) >> sky1shift) + front_offset) >> FRACBITS;
+			int sky1colnum = ((((viewangle + xtoskyangle[x]) ^ skyflip) >> sky1shift) + front_offset) >> FRACBITS;
 			sky1colnum = FIXED2INT(FixedMul(INT2FIXED(sky1colnum), sky1scalex));
 			tallpost_t* skypost = R_GetTextureColumn(frontskytex, sky1colnum);
 
@@ -909,7 +916,7 @@ void R_RenderSkyRange(visplane_t* pl)
 					destpostlen += translen;
 				}
 
-				if (!skypost->next()->end() && destpostlen >= skypost->topdelta + skypost->length)
+				if (!skypost->end() && !skypost->next()->end() && destpostlen >= skypost->topdelta + skypost->length)
 				{
 					skypost = skypost->next();
 				}
@@ -934,4 +941,4 @@ void R_RenderSkyRange(visplane_t* pl)
 	R_ResetDrawFuncs();
 }
 
-VERSION_CONTROL (r_sky_cpp, "$Id: 77f7a7db9901d39da3b0c7ccb200b6f792c4e3c7 $")
+VERSION_CONTROL (r_sky_cpp, "$Id: 1f17e03524ba2494783aef9e65e228f542f16d76 $")
