@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: d15fc7b0fd91a95af22f1a965dd204bb2cc6ae60 $
+// $Id: 971f9911fdb77250fae7bbfc9476aa586a5123eb $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -580,7 +580,7 @@ void DCanvas::DrawWrapper(EWrapperCode drawer, const patch_t* patch, int x, int
 	{
 	  // Printf (PRINT_HIGH, "Patch at %d,%d exceeds LFB\n", x,y );
 	  // No I_Error abort - what is up with TNT.WAD?
-	  DPrintf ("DCanvas::DrawWrapper: bad patch (ignored)\n");
+	  DPrintFmt("DCanvas::DrawWrapper: bad patch (ignored)\n");
 	  return;
 	}
 #endif
@@ -666,7 +666,7 @@ void DCanvas::DrawSWrapper(EWrapperCode drawer, const patch_t* patch, int x0, in
 #ifdef RANGECHECK
 	if (x0 < 0 || x0 + destwidth > surface_width || y0 < 0 || y0 + destheight > surface_height)
 	{
-		DPrintf("DCanvas::DrawSWrapper: bad patch (ignored)\n");
+		DPrintFmt("DCanvas::DrawSWrapper: bad patch (ignored)\n");
 		return;
 	}
 #endif
@@ -798,7 +798,7 @@ void DCanvas::DrawPatchFlipped(const patch_t *patch, int x, int y) const
 	if (x < 0 || x + patch->width() > surface_width || y < 0 || y + patch->height() > surface_height)
 	{
 		//Printf ("Patch at %d,%d exceeds LFB\n", x0,y0 );
-		DPrintf ("DCanvas::DrawPatchFlipped: bad patch (ignored)\n");
+		DPrintFmt("DCanvas::DrawPatchFlipped: bad patch (ignored)\n");
 		return;
 	}
 #endif
@@ -872,7 +872,7 @@ void DCanvas::DrawPatchIndirectFlipped(const patch_t *patch, int x0, int y0) con
 	if (x0 < 0 || x0 + destwidth > surface_width || y0 < 0 || y0 + destheight > surface_height)
 	{
 		//Printf ("Patch at %d,%d exceeds LFB\n", x0,y0 );
-		DPrintf ("DCanvas::DrawPatchFlipped: bad patch (ignored)\n");
+		DPrintFmt("DCanvas::DrawPatchFlipped: bad patch (ignored)\n");
 		return;
 	}
 #endif
@@ -1003,4 +1003,4 @@ void DCanvas::GetTransposedBlock(int x, int y, int width, int height, byte* dest
 				x, y, width, height, mSurface->getPitchInPixels());
 }
 
-VERSION_CONTROL (v_draw_cpp, "$Id: d15fc7b0fd91a95af22f1a965dd204bb2cc6ae60 $")
+VERSION_CONTROL (v_draw_cpp, "$Id: 971f9911fdb77250fae7bbfc9476aa586a5123eb $")
