@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: ce03c68a457b168966b4d40c75ff59b02394935c $
+// $Id: f71fc0457ea9ebe1d35b34029f12992537c7e3c9 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -492,7 +492,7 @@ static std::string V_GetColorStringByName(const std::string& name)
 	 * with a NULL byte. This is so that COM_Parse is able to
 	 * detect the end of the lump.
 	 */
-	char *rgbNames, *data, descr[5*3];
+	char *rgbNames, *data;
 	int c[3], step;
 
 	if (!(rgbNames = (char*)W_CacheLumpName("X11R6RGB", PU_CACHE)))
@@ -525,11 +525,10 @@ static std::string V_GetColorStringByName(const std::string& name)
 
 			if (!stricmp(com_token, name.c_str()))
 			{
-				snprintf(descr, 15, "%04x %04x %04x",
-						 (c[0] << 8) | c[0],
-						 (c[1] << 8) | c[1],
-						 (c[2] << 8) | c[2]);
-				return descr;
+				return fmt::format("{:04x} {:04x} {:04x}",
+				                   (c[0] << 8) | c[0],
+				                   (c[1] << 8) | c[1],
+				                   (c[2] << 8) | c[2]);
 			}
 		}
 	}
@@ -607,7 +606,7 @@ void V_InitPalette(const char* lumpname)
 
 	const int lumpnum = W_GetNumForName(palette_lumpname);
 	if (lumpnum < 0)
-		I_FatalError("Could not initialize %s palette", palette_lumpname.c_str());
+		I_FatalError("Could not initialize {} palette", palette_lumpname);
 
 	current_palette_num = -1;
 
@@ -1237,4 +1236,4 @@ void V_ResetPalette()
 
 
 
-VERSION_CONTROL (v_palette_cpp, "$Id: ce03c68a457b168966b4d40c75ff59b02394935c $")
+VERSION_CONTROL (v_palette_cpp, "$Id: f71fc0457ea9ebe1d35b34029f12992537c7e3c9 $")
