@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 7b8baf9d280e7145373958917cdf9c3c47ef5935 $
+// $Id: f8380f85221b7f07c5dc7485288871c1ba201c18 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -42,9 +42,6 @@
 
 #include "szp.h"
 
-// STL
-#include <map>
-
 //
 // NOTES: AActor
 //
@@ -138,7 +135,7 @@ public:
 		bitfield[bytenum] &= ~(1 << bitnum);
 	}
 
-	bool get(byte id) const
+	[[nodiscard]] bool get(byte id) const
 	{
 		int bytenum = id >> 3;
 		int bitnum = id & bytemask;
@@ -149,10 +146,10 @@ public:
 private:
 	static constexpr int bytesize = 8 * sizeof(byte);
 	static constexpr int bytemask = bytesize - 1;
-	
+
 	// Hacky way of getting ceil() at compile-time
 	static constexpr size_t fieldsize = (MAXPLAYERS + bytemask) / bytesize;
-	
+
 	byte	bitfield[fieldsize];
 };
 
@@ -207,6 +204,8 @@ enum mobjflag_t
 	MF_BOUNCES = BIT(29), // MBF - PARTIAL IMPLEMENTATION
 	MF_FRIEND  = BIT(30), // MBF - UNUSED FOR NOW
 
+	MF_TRANSLUCENT = BIT(31),
+
 	// --- mobj.flags2 ---
 	// Heretic flags
 	MF2_LOGRAV			= BIT(0),   // alternate gravity setting
@@ -414,6 +413,15 @@ class AActor : public DThinker
 			return ptr;
 		}
 
+		operator const AActorPtr() const
+		{
+			return ptr;
+		}
+		operator const AActor*() const
+		{
+			return ptr;
+		}
+
 		AActor &operator *()
 		{
 			return *ptr;
@@ -422,6 +430,14 @@ class AActor : public DThinker
 		{
 			return ptr;
 		}
+		const AActor &operator *() const
+		{
+			return *ptr;
+		}
+		const AActor *operator ->() const
+		{
+			return ptr;
+		}
 	};
 
 public:
@@ -429,7 +445,7 @@ public:
 	AActor (const AActor &other);
 	AActor &operator= (const AActor &other);
 	AActor (fixed_t x, fixed_t y, fixed_t z, mobjtype_t type);
-	void Destroy ();
+	void Destroy() override;
 	~AActor ();
 
 	void RunThink () override;
@@ -550,10 +566,10 @@ public:
 	static void ClearTIDHashes ();
 	void AddToHash ();
 	void RemoveFromHash ();
-	AActor *FindByTID (int tid) const;
-	static AActor *FindByTID (const AActor *first, int tid);
-	AActor *FindGoal (int tid, int kind) const;
-	static AActor *FindGoal (const AActor *first, int tid, int kind);
+	[[nodiscard]] AActor *FindByTID (int tid) const;
+	[[nodiscard]] static AActor *FindByTID (const AActor *first, int tid);
+	[[nodiscard]] AActor *FindGoal (int tid, int kind) const;
+	[[nodiscard]] static AActor *FindGoal (const AActor *first, int tid, int kind);
 
 	uint32_t		netid;          // every object has its own netid
 	short			tid;			// thing identifier
@@ -595,7 +611,7 @@ public:
 	private:
 		void clear();
 		size_t getIndex(int bmx, int bmy);
-		
+
 		static constexpr size_t BLOCKSX = 3;
 		static constexpr size_t BLOCKSY = 3;
 
