@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 9ec435d65c2864158a20099102b550fd00edc705 $
+// $Id: 339f51668dff894dcda91bd6ea44ec03f70997d0 $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -345,6 +345,9 @@ CVAR_RANGE(sv_countdown, "5",
 	CVAR(			co_removesoullimit, "0", "Allows pain elementals to still spawn lost souls if more than 20 are present",
 					CVARTYPE_BOOL, CVAR_ARCHIVE | CVAR_SERVERINFO)
 
+	CVAR(			co_mbfphys, "0", "Use MBF's movement code. Fixes mancubus fireball clipping and linedef skips.",
+					CVARTYPE_BOOL, CVAR_ARCHIVE | CVAR_SERVERINFO)
+
 
 
 	// ZDoom-compatibility changes
@@ -355,6 +358,9 @@ CVAR_RANGE(sv_countdown, "5",
 	CVAR(			co_zdoomsound, "0", "Enable sound attenuation curve + attenuation of switch sounds with distance",
 					CVARTYPE_BOOL, CVAR_ARCHIVE | CVAR_SERVERINFO)
 
+	CVAR(			co_zdoomammo, "0", "Enable/disable ZDoom 1.23b33-based ammo checks",
+					CVARTYPE_BOOL, CVAR_ARCHIVE | CVAR_SERVERINFO)
+
 	CVAR(			co_fineautoaim, "0", "Increase precision of vertical auto-aim",
 					CVARTYPE_BOOL, CVAR_ARCHIVE | CVAR_SERVERINFO)
 
@@ -443,4 +449,4 @@ CVAR_RANGE_FUNC_DECL(net_sndbuf, "131072", "Net send buffer size in bytes",
 CVAR(				sv_weapondrop, "0", "Enable/disable weapon drop.",
 					CVARTYPE_BOOL, CVAR_SERVERARCHIVE | CVAR_SERVERINFO)
 
-VERSION_CONTROL (c_cvarlist_cpp, "$Id: 9ec435d65c2864158a20099102b550fd00edc705 $")
+VERSION_CONTROL (c_cvarlist_cpp, "$Id: 339f51668dff894dcda91bd6ea44ec03f70997d0 $")
