@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 6593ce5b7bd272881ef3001b5280f3f5caad3226 $
+// $Id: 644e6783221ad05fe60fd31fbe52fb5c2cd01c70 $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -174,16 +174,14 @@ void cvar_t::ForceSet(const char* valstr)
 
 		// perform rounding to nearest integer for integral types
 		if (integral_type)
-			valf = floor(valf + 0.5f);
+			valf = std::round(valf);
 
 		valf = clamp(valf, m_MinValue, m_MaxValue);
 
 		if (numerical_value || integral_type || floating_type)
 		{
 			// generate m_String based on the clamped valf value
-			char tmp[32];
-			snprintf(tmp, 32, "%g", valf);
-			m_String = tmp;
+			m_String = fmt::format("{:g}", valf);
 		}
 		else
 		{
@@ -488,7 +486,7 @@ void cvar_t::C_BackupCVars (unsigned int bitflag)
 		if (cvar->m_Flags & bitflag)
 		{
 			if (backup == &CVarBackups[MAX_BACKUPCVARS])
-				I_Error ("C_BackupDemoCVars: Too many cvars to save (%d)", MAX_BACKUPCVARS);
+				I_Error("C_BackupDemoCVars: Too many cvars to save ({})", MAX_BACKUPCVARS);
 			backup->name = cvar->m_Name;
 			backup->string = cvar->m_String;
 			backup++;
@@ -730,11 +728,11 @@ BEGIN_COMMAND (get)
 		// [Russell] - Don't make the user feel inadequate, tell
 		// them its either enabled, disabled or its other value
 		Printf(PRINT_HIGH, "\"%s\" is %s%s.\n",
-				var->name(), C_GetValueString(var).c_str(), control.c_str());
+				var->name(), C_GetValueString(var), control);
 
 		if (var->flags() & CVAR_LATCH && var->flags() & CVAR_MODIFIED)
 			Printf(PRINT_HIGH, "\"%s\" will be changed to %s.\n",
-					var->name(), C_GetLatchedValueString(var).c_str());
+					var->name(), C_GetLatchedValueString(var));
 	}
 	else
 	{
@@ -764,6 +762,16 @@ BEGIN_COMMAND (toggle)
 	{
 		Printf(PRINT_HIGH, "\"%s\" cannot be toggled.\n", argv[1]);
 	}
+	else if (var->flags() & CVAR_NOSET)
+	{
+		PrintFmt(PRINT_HIGH, "{} is write protected.\n", argv[1]);
+		return;
+	}
+	else if (multiplayer && baseapp == client && (var->flags() & CVAR_SERVERINFO))
+	{
+		PrintFmt(PRINT_HIGH, "{} is under server control.\n", argv[1]);
+		return;
+	}
 	else
 	{
 		if (var->flags() & CVAR_LATCH && var->flags() & CVAR_MODIFIED)
@@ -774,11 +782,11 @@ BEGIN_COMMAND (toggle)
 		// [Russell] - Don't make the user feel inadequate, tell
 		// them its either enabled, disabled or its other value
 		Printf(PRINT_HIGH, "\"%s\" is %s.\n",
-				var->name(), C_GetValueString(var).c_str());
+				var->name(), C_GetValueString(var));
 
 		if (var->flags() & CVAR_LATCH && var->flags() & CVAR_MODIFIED)
 			Printf(PRINT_HIGH, "\"%s\" will be changed to %s.\n",
-					var->name(), C_GetLatchedValueString(var).c_str());
+					var->name(), C_GetLatchedValueString(var));
 	}
 }
 END_COMMAND (toggle)
@@ -852,4 +860,4 @@ END_COMMAND(crashout)
 
 #endif
 
-VERSION_CONTROL (c_cvars_cpp, "$Id: 6593ce5b7bd272881ef3001b5280f3f5caad3226 $")
+VERSION_CONTROL (c_cvars_cpp, "$Id: 644e6783221ad05fe60fd31fbe52fb5c2cd01c70 $")
