@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 1d91bd4a875ab4b7cb48d3f732143748d9ffd307 $
+// $Id: 6e2bfb3d57a0c854db27b10678da1b22c7ac69e5 $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -27,6 +27,7 @@
 #include <sstream>
 #include <algorithm>
 #include <ctime>
+#include <map>
 
 #include "cmdlib.h"
 #include "c_console.h"
@@ -110,7 +111,7 @@ public:
 	{
 		ActionKeyListTable::iterator it = mTable.find(action);
 		if (it == mTable.end())
-			it = mTable.insert(std::make_pair(action, ActionKeyList())).first;
+			it = mTable.emplace(action, ActionKeyList()).first;
 		ActionKeyList* action_key_list = &it->second;
 
 		if (std::find(action_key_list->begin(), action_key_list->end(), key) != action_key_list->end())
@@ -240,15 +241,16 @@ void C_DoCommand(const char *cmd, uint32_t key)
 	if (check == -1)
 	{
 		argc = 1;
-		argsize = strlen (com_token) + 1;
+		argsize = strlen(com_token) + 1;
 
-		realargs = new char[strlen (data) + 1];
-		strcpy (realargs, data);
+		size_t datalen = strlen(data) + 1;
+		realargs = new char[datalen];
+		M_StringCopy(realargs, data, datalen);
 
-		while ( (data = ParseString (data)) )
+		while (data = ParseString(data))
 		{
 			argc++;
-			argsize += strlen (com_token) + 1;
+			argsize += strlen(com_token) + 1;
 		}
 
 		args = new char[argsize];
@@ -257,12 +259,12 @@ void C_DoCommand(const char *cmd, uint32_t key)
 		arg = args;
 		data = cmd;
 		argsize = 0;
-		while ( (data = ParseString (data)) )
+		while (data = ParseString(data))
 		{
-			strcpy (arg, com_token);
+			size_t tokenlen = strlen(com_token) + 1;
+			M_StringCopy(arg, com_token, tokenlen);
 			argv[argsize] = arg;
-			arg += strlen (arg);
-			*arg++ = 0;
+			arg += tokenlen;
 			argsize++;
 		}
 
@@ -433,33 +435,48 @@ BEGIN_COMMAND (exec)
 	static std::vector<std::string> exec_stack;
 	static std::vector<bool>	tag_stack;
 
-	if(std::find(exec_stack.begin(), exec_stack.end(), argv[1]) != exec_stack.end())
+	std::string found = M_FindUserFileName(argv[1], ".cfg");
+	if (found.empty())
 	{
-		Printf (PRINT_HIGH, "Ignoring recursive exec \"%s\"\n", argv[1]);
+		const char* cfgdir = Args.CheckValue("-cfgdir");
+		if (!cfgdir)
+		{
+			Printf(PRINT_WARNING, "Could not find \"%s\"\n", argv[1]);
+			return;
+		}
+
+		found = M_CleanPath(M_JoinPath(cfgdir, argv[1]));
+		if (!M_FileExists(found))
+		{
+			found += ".cfg";
+			if (!M_FileExists(found))
+			{
+				Printf(PRINT_WARNING, "Could not find \"%s\"\n", argv[1]);
+				return;
+			}
+		}
+	}
+
+	if(std::find(exec_stack.begin(), exec_stack.end(), found) != exec_stack.end())
+	{
+		Printf (PRINT_HIGH, "Ignoring recursive exec \"%s\"\n", found);
 		return;
 	}
 
 	if(exec_stack.size() >= MAX_EXEC_DEPTH)
 	{
-		Printf (PRINT_HIGH, "Ignoring recursive exec \"%s\"\n", argv[1]);
+		Printf (PRINT_HIGH, "Ignoring recursive exec \"%s\"\n", found);
 		return;
 	}
 
-	std::string found = M_FindUserFileName(argv[1], ".cfg");
-	if (found.empty())
-	{
-		Printf(PRINT_WARNING, "Could not find \"%s\"\n", argv[1]);
-		return;
-	}
-
-	std::ifstream ifs(argv[1]);
+	std::ifstream ifs(found);
 	if(ifs.fail())
 	{
-		Printf(PRINT_WARNING, "Could not open \"%s\"\n", argv[1]);
+		Printf(PRINT_WARNING, "Could not open \"%s\"\n", found);
 		return;
 	}
 
-	exec_stack.push_back(argv[1]);
+	exec_stack.push_back(found);
 
 	while(ifs)
 	{
@@ -669,7 +686,7 @@ const char *ParseString (const char *data)
 		{
 			if ( (var = cvar_t::FindCVar (&com_token[1], &dummy)) )
 			{
-				strcpy (com_token, var->cstring());
+				M_StringCopy(com_token, var->cstring(), 8192);
 			}
 		}
 	}
@@ -690,7 +707,7 @@ DConsoleCommand::DConsoleCommand (const char *name)
 		// Add all the action commands for tab completion
 		for (i = 0; i < NUM_ACTIONS; i++)
 		{
-			strcpy (&tname[1], actionbits[i].name);
+			M_StringCopy(&tname[1], actionbits[i].name, 15);
 			tname[0] = '+';
 			C_AddTabCommand (tname);
 			tname[0] = '-';
@@ -794,16 +811,16 @@ std::string C_QuoteString(const std::string &argstr)
 {
 	std::ostringstream buffer;
 	buffer << "\"";
-	for (std::string::const_iterator it = argstr.begin();it != argstr.end();++it)
+	for (const auto c : argstr)
 	{
-		if (ValidEscape(*it))
+		if (ValidEscape(c))
 		{
 			// Escape this char.
-			buffer << '\\' << *it;
+			buffer << '\\' << c;
 		}
 		else
 		{
-			buffer << *it;
+			buffer << c;
 		}
 	}
 	buffer << "\"";
@@ -826,14 +843,12 @@ std::string C_EscapeWadList(const std::vector<std::string> wadlist)
 	return wadstr;
 }
 
-static int DumpHash (BOOL aliases)
+static int DumpHash (bool aliases)
 {
 	int count = 0;
 
-	for (command_map_t::iterator i = Commands().begin(), e = Commands().end(); i != e; ++i)
+	for (const auto& [_, cmd] : Commands())
 	{
-		DConsoleCommand *cmd = i->second;
-
 		count++;
 		if (cmd->IsAlias())
 		{
@@ -849,15 +864,13 @@ static int DumpHash (BOOL aliases)
 
 void DConsoleAlias::Archive(FILE *f)
 {
-	fprintf(f, "alias %s %s\n", C_QuoteString(m_Name).c_str(), C_QuoteString(m_Command).c_str());
+	fmt::print(f, "alias {} {}\n", C_QuoteString(m_Name), C_QuoteString(m_Command));
 }
 
 void DConsoleAlias::C_ArchiveAliases (FILE *f)
 {
-	for (command_map_t::iterator i = Commands().begin(), e = Commands().end(); i != e; ++i)
+	for (const auto& [_, alias] : Commands())
 	{
-		DConsoleCommand *alias = i->second;
-
 		if (alias->IsAlias())
 			static_cast<DConsoleAlias *>(alias)->Archive (f);
 	}
@@ -865,10 +878,8 @@ void DConsoleAlias::C_ArchiveAliases (FILE *f)
 
 void DConsoleAlias::DestroyAll()
 {
-	for (command_map_t::iterator i = Commands().begin(), e = Commands().end(); i != e; ++i)
+	for (const auto& [_, alias] : Commands())
 	{
-		DConsoleCommand *alias = i->second;
-
 		if (alias->IsAlias())
 			delete alias;
 	}
@@ -1001,7 +1012,7 @@ BEGIN_COMMAND(logfile)
 
 		time(&rawtime);
 		timeinfo = localtime(&rawtime);
-		Printf("Log file %s closed on %s\n", ::LOG_FILE.c_str(), asctime(timeinfo));
+		Printf("Log file %s closed on %s\n", ::LOG_FILE, asctime(timeinfo));
 		::LOG.close();
 	}
 
@@ -1010,7 +1021,7 @@ BEGIN_COMMAND(logfile)
 
 	if (!::LOG.is_open())
 	{
-		Printf(PRINT_HIGH, "Unable to create logfile: %s\n", ::LOG_FILE.c_str());
+		Printf(PRINT_HIGH, "Unable to create logfile: %s\n", ::LOG_FILE);
 	}
 	else
 	{
@@ -1018,7 +1029,7 @@ BEGIN_COMMAND(logfile)
 		timeinfo = localtime(&rawtime);
 		::LOG.flush();
 		::LOG << std::endl;
-		Printf(PRINT_HIGH, "Logging in file %s started %s\n", ::LOG_FILE.c_str(),
+		Printf(PRINT_HIGH, "Logging in file %s started %s\n", ::LOG_FILE,
 		       asctime(timeinfo));
 	}
 }
@@ -1032,7 +1043,7 @@ BEGIN_COMMAND (stoplog)
 	if (LOG.is_open()) {
 		time (&rawtime);
     	timeinfo = localtime (&rawtime);
-		Printf (PRINT_HIGH, "Logging to file %s stopped %s\n", LOG_FILE.c_str(), asctime (timeinfo));
+		Printf (PRINT_HIGH, "Logging to file %s stopped %s\n", LOG_FILE, asctime (timeinfo));
 		LOG.close();
 	}
 }
@@ -1066,8 +1077,8 @@ END_COMMAND (puke)
 BEGIN_COMMAND (error)
 {
 	std::string text = C_ArgCombine(argc - 1, (const char **)(argv + 1));
-	I_Error (text.c_str());
+	I_Error (text);
 }
 END_COMMAND (error)
 
-VERSION_CONTROL (c_dispatch_cpp, "$Id: 1d91bd4a875ab4b7cb48d3f732143748d9ffd307 $")
+VERSION_CONTROL (c_dispatch_cpp, "$Id: 6e2bfb3d57a0c854db27b10678da1b22c7ac69e5 $")
