@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 2eebef3455e4969233264ae31a78a58c1421c77b $
+// $Id: fb83213af98759f1abbadfce6c5e463589319c82 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -179,9 +179,35 @@ static const char* steam_install_subdirs[] =
 	"steamapps\\common\\ultimate doom\\base\\plutonia",
 	"steamapps\\common\\ultimate doom\\base\\tnt",
 	"steamapps\\common\\ultimate doom\\rerelease",
-
 };
 
+static registry_value_t gog_doom_plus_doom2 =
+{
+	HKEY_LOCAL_MACHINE,
+	SOFTWARE_KEY "\\GOG.com\\Games\\1413291984",
+	"path",
+};
+
+static registry_value_t gog_doom =
+{
+	HKEY_LOCAL_MACHINE,
+	SOFTWARE_KEY "\\GOG.com\\Games\\1435827232",
+	"path",
+};
+
+static registry_value_t gog_doom2 =
+{
+	HKEY_LOCAL_MACHINE,
+	SOFTWARE_KEY "\\GOG.com\\Games\\1435848814",
+	"path",
+};
+
+static registry_value_t gog_final_doom =
+{
+	HKEY_LOCAL_MACHINE,
+	SOFTWARE_KEY "\\GOG.com\\Games\\1435848742",
+	"path",
+};
 
 static char *GetRegistryString(registry_value_t *reg_val)
 {
@@ -211,8 +237,7 @@ static char *GetRegistryString(registry_value_t *reg_val)
 		if (RegQueryValueEx(key, reg_val->value, NULL, &valtype,
 		    (unsigned char *)result, &len) != ERROR_SUCCESS)
 		{
-			free(result);
-			result = NULL;
+			M_Free(result);
 		}
 	}
 
@@ -262,15 +287,13 @@ void D_AddPlatformSearchDirs(std::vector<std::string> &dirs)
 
 	// Doom 95
 	{
-		unsigned int i;
-
-		for (i = 0; i < ARRAY_LENGTH(uninstall_values); ++i)
+		for (auto& uninstallval : uninstall_values)
 		{
 			char* val;
 			char* path;
 			char* unstr;
 
-			val = GetRegistryString(&uninstall_values[i]);
+			val = GetRegistryString(&uninstallval);
 
 			if (val == NULL)
 				continue;
@@ -279,7 +302,7 @@ void D_AddPlatformSearchDirs(std::vector<std::string> &dirs)
 
 			if (unstr == NULL)
 			{
-				free(val);
+				M_Free(val);
 			}
 			else
 			{
@@ -293,52 +316,76 @@ void D_AddPlatformSearchDirs(std::vector<std::string> &dirs)
 
 	// Doom Collectors Edition
 	{
-		char* install_path;
-		char* subpath;
-		unsigned int i;
-
-		install_path = GetRegistryString(&collectors_edition_value);
+		char* install_path = GetRegistryString(&collectors_edition_value);
 
 		if (install_path != NULL)
 		{
-			for (i = 0; i < ARRAY_LENGTH(collectors_edition_subdirs); ++i)
+			for (const auto& dir : collectors_edition_subdirs)
 			{
-				subpath = static_cast<char*>(malloc(strlen(install_path)
-				                             + strlen(collectors_edition_subdirs[i])
-				                             + 5));
-				sprintf(subpath, "%s\\%s", install_path, collectors_edition_subdirs[i]);
+				const std::string subpath = fmt::format("{}\\{}", install_path, dir);
 
-				const char* csubpath = subpath;
-				D_AddSearchDir(dirs, csubpath, separator);
+				D_AddSearchDir(dirs, subpath.c_str(), separator);
 			}
 
-			free(install_path);
+			M_Free(install_path);
 		}
 	}
 
 	// Doom on Steam
 	{
-		char* install_path;
-		char* subpath;
-		size_t i;
-
-		install_path = GetRegistryString(&steam_install_location);
+		char* install_path = GetRegistryString(&steam_install_location);
 
 		if (install_path != NULL)
 		{
-			for (i = 0; i < ARRAY_LENGTH(steam_install_subdirs); ++i)
+			for (const auto& dir : steam_install_subdirs)
 			{
-				subpath = static_cast<char*>(malloc(strlen(install_path)
-				                             + strlen(steam_install_subdirs[i]) + 5));
-				sprintf(subpath, "%s\\%s", install_path, steam_install_subdirs[i]);
+				const std::string subpath = fmt::format("{}\\{}", install_path, dir);
 
-				const char* csubpath = subpath;
-				D_AddSearchDir(dirs, csubpath, separator);
-
-				free(subpath);
+				D_AddSearchDir(dirs, subpath.c_str(), separator);
 			}
 
-			free(install_path);
+			M_Free(install_path);
+		}
+	}
+
+	// Doom on GOG
+	{
+		char* doom_plus_doom2_path = GetRegistryString(&gog_doom_plus_doom2);
+
+		if (doom_plus_doom2_path != nullptr)
+		{
+			D_AddSearchDir(dirs, doom_plus_doom2_path, separator);
+			M_Free(doom_plus_doom2_path);
+		}
+
+		char* doom_path = GetRegistryString(&gog_doom);
+
+		if (doom_path != nullptr)
+		{
+			D_AddSearchDir(dirs, doom_path, separator);
+			M_Free(doom_path);
+		}
+
+		char* doom2_path = GetRegistryString(&gog_doom2);
+
+		if (doom2_path != nullptr)
+		{
+			const std::string full_doom2_path = fmt::format("{}\\{}", doom2_path, "doom2");
+			const std::string master_levels_path = fmt::format("{}\\{}", doom2_path, "master\\wads");
+			D_AddSearchDir(dirs, full_doom2_path.c_str(), separator);
+			D_AddSearchDir(dirs, master_levels_path.c_str(), separator);
+			M_Free(doom2_path);
+		}
+
+		char* final_doom_path = GetRegistryString(&gog_final_doom);
+
+		if (final_doom_path != NULL)
+		{
+			const std::string plutonia_path = fmt::format("{}\\{}", final_doom_path, "Plutonia");
+			const std::string tnt_path = fmt::format("{}\\{}", final_doom_path, "TNT");
+			D_AddSearchDir(dirs, plutonia_path.c_str(), separator);
+			D_AddSearchDir(dirs, tnt_path.c_str(), separator);
+			M_Free(final_doom_path);
 		}
 	}
 
@@ -359,11 +406,21 @@ void D_AddPlatformSearchDirs(std::vector<std::string> &dirs)
 	D_AddSearchDir(dirs, INSTALL_PREFIX "/" INSTALL_DATADIR "/odamex", separator);
 	D_AddSearchDir(dirs, INSTALL_PREFIX "/" INSTALL_DATADIR "/games/odamex", separator);
 	#endif
+	// Search the maintainer-directed data directory for WADs
+	#if defined(ODAMEX_INSTALL_DATADIR)
+	D_AddSearchDir(dirs, ODAMEX_INSTALL_DATADIR, separator);
+	#endif
 
 	D_AddSearchDir(dirs, "/usr/share/doom", separator);
 	D_AddSearchDir(dirs, "/usr/share/games/doom", separator);
 	D_AddSearchDir(dirs, "/usr/local/share/games/doom", separator);
 	D_AddSearchDir(dirs, "/usr/local/share/doom", separator);
+	// Flatpak sandbox default directories
+	// (Since you need to pass envvars to a Flatpak)
+	D_AddSearchDir(dirs, "/run/host/usr/share/doom", separator);
+	D_AddSearchDir(dirs, "/run/host/usr/share/games/doom", separator);
+	D_AddSearchDir(dirs, "/run/host/usr/local/share/games/doom", separator);
+	D_AddSearchDir(dirs, "/run/host/usr/local/share/doom", separator);
 
 	#endif
 }
@@ -391,16 +448,16 @@ static void D_PrintIWADIdentity()
     	                   "\36\36\36\36\36\36\36\36\36\36\36\36\37\n");
 
 		if (gamemode == undetermined)
-			Printf_Bold("Game mode indeterminate, no standard wad found.\n\n");
+			PrintFmt_Bold("Game mode indeterminate, no standard wad found.\n\n");
 		else
-			Printf_Bold("%s\n\n", D_GetTitleString().c_str());
+			PrintFmt_Bold("{}\n\n", D_GetTitleString());
 	}
 	else
 	{
 		if (gamemode == undetermined)
 			Printf(PRINT_HIGH, "Game mode indeterminate, no standard wad found.\n");
 		else
-			Printf(PRINT_HIGH, "%s\n", D_GetTitleString().c_str());
+			Printf(PRINT_HIGH, "%s\n", D_GetTitleString());
 	}
 }
 
@@ -412,14 +469,13 @@ void D_LoadResolvedPatches()
 {
 	// Load external patch files first.
 	bool chexLoaded = false;
-	for (OResFiles::const_iterator it = ::patchfiles.begin(); it != ::patchfiles.end();
-	     ++it)
+	for (const auto& file : ::patchfiles)
 	{
-		if (StdStringToUpper(it->getBasename()) == "CHEX.DEH")
+		if (StdStringToUpper(file.getBasename()) == "CHEX.DEH")
 		{
 			chexLoaded = true;
 		}
-		D_DoDehPatch(&*it, -1);
+		D_DoDehPatch(&file, -1);
 	}
 
 	// Check WAD files for lumps.
@@ -474,12 +530,10 @@ static bool FindIWAD(OResFile& out)
 {
 	// Search for a pre-defined IWAD from the list above
 	std::vector<OString> filenames = W_GetIWADFilenames();
-	for (std::vector<OString>::const_iterator it = filenames.begin();
-	     it != filenames.end(); ++it)
+	for (const auto& filename : filenames)
 	{
 		// Construct a file.
 		OWantFile wantfile;
-		std::string filename = it->c_str();
 		if (!OWantFile::make(wantfile, filename, OFILE_WAD))
 		{
 			continue;
@@ -574,7 +628,7 @@ static bool CommercialIWADWarning(const OWantFile& wanted)
 		return false;
 	}
 
-	Printf("Odamex attempted to load\n> %s.\n\n", info->mIdName.c_str());
+	Printf("Odamex attempted to load\n> %s.\n\n", info->mIdName);
 
 	// Try to find an IWAD file with a matching name in the user's directories.
 	OWantFile sameNameWant;
@@ -587,7 +641,7 @@ static bool CommercialIWADWarning(const OWantFile& wanted)
 		    "Odamex could not find the data file for this game in any of the locations "
 		    "it searches for WAD files.  If you know you have %s on your hard drive, you "
 		    "can add that path to the 'waddirs' cvar so Odamex can find it.\n\n",
-		    wanted.getBasename().c_str());
+		    wanted.getBasename());
 	}
 	else
 	{
@@ -597,14 +651,14 @@ static bool CommercialIWADWarning(const OWantFile& wanted)
 			// Found a file, but it's the wrong version.
 			Printf("Odamex found a possible data file, but it's the wrong version.\n> "
 			       "%s\n> %s\n\n",
-			       curInfo->mIdName.c_str(), sameNameRes.getFullpath().c_str());
+			       curInfo->mIdName, sameNameRes.getFullpath());
 		}
 		else
 		{
 			// Found a file, but it's not recognized at all.
 			Printf("Odamex found a possible data file, but Odamex does not recognize "
 			       "it.\n> %s\n\n",
-			       sameNameRes.getFullpath().c_str());
+			       sameNameRes.getFullpath());
 		}
 
 #ifdef _WIN32
@@ -642,22 +696,21 @@ void D_LoadResourceFiles(const OWantFiles& newwadfiles, const OWantFiles& newpat
 	// Resolve wanted wads.
 	OResFiles resolved_wads;
 	resolved_wads.reserve(newwadfiles.size());
-	for (OWantFiles::const_iterator it = newwadfiles.begin(); it != newwadfiles.end();
-	     ++it)
+	for (const auto& wantfile : newwadfiles)
 	{
 		OResFile file;
-		if (!M_ResolveWantedFile(file, *it))
+		if (!M_ResolveWantedFile(file, wantfile))
 		{
 			// Give more useful information when trying to load an IWAD.
-			const bool isCommercial = CommercialIWADWarning(*it);
+			const bool isCommercial = CommercialIWADWarning(wantfile);
 			if (isCommercial && !::missingCommercialIWAD)
 			{
 				::missingCommercialIWAD = true;
 			}
 
-			::missingfiles.push_back(*it);
+			::missingfiles.push_back(wantfile);
 			Printf(PRINT_WARNING, "Could not resolve resource file \"%s\".",
-			       it->getWantedPath().c_str());
+			       wantfile.getWantedPath());
 			continue;
 		}
 		resolved_wads.push_back(file);
@@ -666,15 +719,14 @@ void D_LoadResourceFiles(const OWantFiles& newwadfiles, const OWantFiles& newpat
 	// Resolve wanted patches.
 	OResFiles resolved_patches;
 	resolved_patches.reserve(newpatchfiles.size());
-	for (OWantFiles::const_iterator it = newpatchfiles.begin(); it != newpatchfiles.end();
-	     ++it)
+	for (const auto& wantfile : newpatchfiles)
 	{
 		OResFile file;
-		if (!M_ResolveWantedFile(file, *it))
+		if (!M_ResolveWantedFile(file, wantfile))
 		{
-			::missingfiles.push_back(*it);
+			::missingfiles.push_back(wantfile);
 			Printf(PRINT_WARNING, "Could not resolve patch file \"%s\".",
-			       it->getWantedPath().c_str());
+			       wantfile.getWantedPath());
 			continue;
 		}
 		resolved_patches.push_back(file);
@@ -689,9 +741,9 @@ void D_LoadResourceFiles(const OWantFiles& newwadfiles, const OWantFiles& newpat
 		OWantFile::make(want_odamex, "odamex.wad", OFILE_WAD);
 		if (!M_ResolveWantedFile(odamex_wad, want_odamex))
 		{
-			I_FatalError("Could not resolve \"%s\".  Please ensure this file is "
+			I_FatalError("Could not resolve \"{}\".  Please ensure this file is "
 			             "someplace where Odamex can find it.\n",
-			             want_odamex.getBasename().c_str());
+			             want_odamex.getBasename());
 		}
 	}
 	else
@@ -714,9 +766,9 @@ void D_LoadResourceFiles(const OWantFiles& newwadfiles, const OWantFiles& newpat
 			resolved_wads.erase(resolved_wads.begin());
 			if (W_IsIWADDeprecated(next_iwad))
 			{
-				Printf_Bold("WARNING: IWAD %s is outdated. Please update it to the "
-				            "latest version.\n",
-				            next_iwad.getBasename().c_str());
+				PrintFmt_Bold("WARNING: IWAD {} is outdated. Please update it to the "
+				              "latest version.\n",
+				              next_iwad.getBasename());
 			}
 		}
 	}
@@ -849,7 +901,7 @@ bool D_DoomWadReboot(const OWantFiles& newwadfiles, const OWantFiles& newpatchfi
 		Printf(PRINT_WARNING,
 		       "Could not load new resource files.\n%s\nReloading previous resource "
 		       "set...\n",
-		       failmsg.c_str());
+		       failmsg);
 
 		D_Shutdown();
 
@@ -871,8 +923,8 @@ bool D_DoomWadReboot(const OWantFiles& newwadfiles, const OWantFiles& newpatchfi
 		if (!fatalmsg.empty())
 		{
 			I_FatalError("Failed to load new resource files, then ran into error when "
-			             "loading original resource files:\n%s\n",
-			             fatalmsg.c_str());
+			             "loading original resource files:\n{}\n",
+			             fatalmsg);
 		}
 	}
 
@@ -1131,4 +1183,4 @@ void D_RunTics(void (*sim_func)(), void(*display_func)())
 	}
 }
 
-VERSION_CONTROL (d_main_cpp, "$Id: 2eebef3455e4969233264ae31a78a58c1421c77b $")
+VERSION_CONTROL (d_main_cpp, "$Id: fb83213af98759f1abbadfce6c5e463589319c82 $")
