@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: fd4100d373ba58e77511d464c0d152055dab282b $
+// $Id: 86b736e776253e3fa79950839f5c37f132220bb7 $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -31,6 +31,12 @@
 #include "g_levelstate.h"
 #include "m_wdlstats.h"
 #include "svc_message.h"
+#include "v_textcolors.h"
+#include "s_sound.h"
+
+#ifdef SERVER_APP
+#include "sv_main.h"
+#endif
 
 EXTERN_CVAR(g_gametypename)
 EXTERN_CVAR(g_lives)
@@ -549,11 +555,11 @@ static void GiveTeamWins(team_t team, int wins)
 		return;
 
 	// Send information about the new team round wins to all players.
-	for (Players::iterator it = ::players.begin(); it != ::players.end(); ++it)
+	for (auto& player : ::players)
 	{
-		if (!it->ingame())
+		if (!player.ingame())
 			continue;
-		MSG_WriteSVC(&it->client.netbuf, SVC_TeamMembers(team));
+		MSG_WriteSVC(&player.client.netbuf, SVC_TeamMembers(team));
 	}
 }
 
@@ -595,14 +601,14 @@ void G_TimeCheckEndGame()
 			}
 			else if (pr.count >= 2)
 			{
-				SV_BroadcastPrintf(
+				SV_BroadcastPrintFmt(
 				    "Time limit hit. Game is a draw on tied lives left!\n");
 				::levelstate.setWinner(WinInfo::WIN_DRAW, 0);
 			}
 			else
 			{
-				SV_BroadcastPrintf("Time limit hit. Game won by %s on lives left!\n",
-				                   pr.players.front()->userinfo.netname.c_str());
+				SV_BroadcastPrintFmt("Time limit hit. Game won by {} on lives left!\n",
+				                     pr.players.front()->userinfo.netname);
 				::levelstate.setWinner(WinInfo::WIN_PLAYER, pr.players.front()->id);
 			}
 		}
@@ -619,13 +625,13 @@ void G_TimeCheckEndGame()
 			}
 			else if (pr.count >= 2)
 			{
-				SV_BroadcastPrintf("Time limit hit. Game is a draw on tied frags!\n");
+				SV_BroadcastPrintFmt("Time limit hit. Game is a draw on tied frags!\n");
 				::levelstate.setWinner(WinInfo::WIN_DRAW, 0);
 			}
 			else
 			{
-				SV_BroadcastPrintf("Time limit hit. Game won by %s on frags!\n",
-				                   pr.players.front()->userinfo.netname.c_str());
+				SV_BroadcastPrintFmt("Time limit hit. Game won by {} on frags!\n",
+				                     pr.players.front()->userinfo.netname);
 				::levelstate.setWinner(WinInfo::WIN_PLAYER, pr.players.front()->id);
 			}
 		}
@@ -637,9 +643,9 @@ void G_TimeCheckEndGame()
 			// Defense always wins in the event of a timeout.
 			TeamInfo& ti = *GetTeamInfo(::levelstate.getDefendingTeam());
 			GiveTeamWins(ti.Team, 1);
-			SV_BroadcastPrintf(
-			    "Time limit hit. %s team wins on successful defense!\n",
-			    ti.ColorizedTeamName().c_str());
+			SV_BroadcastPrintFmt(
+			    "Time limit hit. {} team wins on successful defense!\n",
+			    ti.ColorizedTeamName());
 			::levelstate.setWinner(WinInfo::WIN_TEAM, ti.Team);
 		}
 		else
@@ -655,14 +661,14 @@ void G_TimeCheckEndGame()
 
 				if (tv.size() != 1)
 				{
-					SV_BroadcastPrintf("Time limit hit. Game is a draw on tied %s!\n",
+					SV_BroadcastPrintFmt("Time limit hit. Game is a draw on tied {}!\n",
 					                   limittype);
 					::levelstate.setWinner(WinInfo::WIN_DRAW, 0);
 				}
 				else
 				{
-					SV_BroadcastPrintf("Time limit hit. %s team wins on %s!\n",
-					                   tv.front()->ColorizedTeamName().c_str(),
+					SV_BroadcastPrintFmt("Time limit hit. {} team wins on {}!\n",
+					                   tv.front()->ColorizedTeamName(),
 					                   limittype);
 					::levelstate.setWinner(WinInfo::WIN_TEAM, tv.front()->Team);
 				}
@@ -674,15 +680,15 @@ void G_TimeCheckEndGame()
 
 				if (tv.size() != 1)
 				{
-					SV_BroadcastPrintf("Time limit hit. Game is a draw on tied %s!\n",
-					                   limittype);
+					SV_BroadcastPrintFmt("Time limit hit. Game is a draw on tied {}!\n",
+					                     limittype);
 					::levelstate.setWinner(WinInfo::WIN_DRAW, 0);
 				}
 				else
 				{
-					SV_BroadcastPrintf("Time limit hit. %s team wins on %s!\n",
-					                   tv.front()->ColorizedTeamName().c_str(),
-					                   limittype);
+					SV_BroadcastPrintFmt("Time limit hit. {} team wins on {}!\n",
+					                     tv.front()->ColorizedTeamName(),
+					                     limittype);
 					::levelstate.setWinner(WinInfo::WIN_TEAM, tv.front()->Team);
 				}
 			}
@@ -713,8 +719,8 @@ void G_FragsCheckEndGame()
 			GiveWins(*top, 1);
 
 			// [ML] 04/4/06: Added !sv_fragexitswitch
-			SV_BroadcastPrintf("Frag limit hit. Game won by %s!\n",
-			                   top->userinfo.netname.c_str());
+			SV_BroadcastPrintFmt("Frag limit hit. Game won by {}!\n",
+			                     top->userinfo.netname);
 			::levelstate.setWinner(WinInfo::WIN_PLAYER, top->id);
 			M_CommitWDLLog();
 			::levelstate.endRound();
@@ -740,8 +746,8 @@ void G_TeamFragsCheckEndGame()
 		if (team->Points >= sv_fraglimit)
 		{
 			GiveTeamWins(team->Team, 1);
-			SV_BroadcastPrintf("Frag limit hit. %s team wins!\n",
-			                   team->ColorString.c_str());
+			SV_BroadcastPrintFmt("Frag limit hit. {} team wins!\n",
+			                     team->ColorString);
 			::levelstate.setWinner(WinInfo::WIN_TEAM, team->Team);
 			M_CommitWDLLog();
 			::levelstate.endRound();
@@ -768,8 +774,8 @@ void G_TeamScoreCheckEndGame()
 		if (team->Points >= sv_scorelimit)
 		{
 			GiveTeamWins(team->Team, 1);
-			SV_BroadcastPrintf("Score limit hit. %s team wins!\n",
-			                   team->ColorizedTeamName().c_str());
+			SV_BroadcastPrintFmt("Score limit hit. {} team wins!\n",
+			                     team->ColorizedTeamName());
 			::levelstate.setWinner(WinInfo::WIN_TEAM, team->Team);
 			M_CommitWDLLog();
 			::levelstate.endRound();
@@ -778,6 +784,25 @@ void G_TeamScoreCheckEndGame()
 	}
 }
 
+// [Acts 19 quiz] We keep track of whether or not the last player hype message
+// has been displayed in a given Horde wave or Survival Co-op map.
+bool lastplayerhype = false;
+bool lastblueplayerhype = false;
+bool lastredplayerhype = false;
+bool lastgreenplayerhype = false;
+
+void G_ResetLastPlayer()
+{
+	lastplayerhype = false;
+}
+
+void G_ResetTeamLastPlayer()
+{
+	lastblueplayerhype = false;
+	lastredplayerhype = false;
+	lastgreenplayerhype = false;
+}
+
 /**
  * @brief Check to see if we should end the game on lives.
  */
@@ -793,9 +818,29 @@ void G_LivesCheckEndGame()
 	{
 		// Everybody losing their lives in coop is a failure.
 		PlayerResults pr = PlayerQuery().hasLives().execute();
-		if (pr.count == 0)
+		if (pr.count == 1 && P_NumPlayersInGame() > 1 && !lastplayerhype)
 		{
-			SV_BroadcastPrintf("All players have run out of lives.\n");
+			lastplayerhype = true;
+			SERVER_ONLY(
+			SV_BroadcastPrintFmtButPlayer(PRINT_HIGH, pr.players.front()->id,
+			                              "{} is the last player alive!\n",
+			                              pr.players.front()->userinfo.netname);
+			SV_MidPrint(TEXTCOLOR_RED "!! LAST PLAYER ALIVE !!\n" TEXTCOLOR_WHITE
+			            "You're the" TEXTCOLOR_YELLOW " last resort" TEXTCOLOR_WHITE
+			            ".\nGood luck!\n", pr.players.front(), 5);
+			S_PlayerSound(pr.players.front(), NULL, CHAN_GAMEINFO, "misc/lastplayer", ATTN_NONE);
+    		)
+		}
+		// [Acts 19 quiz] If new players join or a new map starts, we want to
+		// be able to display the hype message again.
+		else if (pr.count > 1)
+		{
+			G_ResetLastPlayer();
+		}
+		else if (pr.count == 0)
+		{
+			G_ResetLastPlayer();
+			SV_BroadcastPrintFmt("All players have run out of lives.\n");
 			::levelstate.setWinner(WinInfo::WIN_NOBODY, 0);
 			M_CommitWDLLog();
 			::levelstate.endRound();
@@ -807,7 +852,7 @@ void G_LivesCheckEndGame()
 		PlayerResults pr = PlayerQuery().hasLives().execute();
 		if (pr.count == 0)
 		{
-			SV_BroadcastPrintf("All players have run out of lives.\n");
+			SV_BroadcastPrintFmt("All players have run out of lives.\n");
 			::levelstate.setWinner(WinInfo::WIN_DRAW, 0);
 			M_CommitWDLLog();
 			::levelstate.endRound();
@@ -815,8 +860,8 @@ void G_LivesCheckEndGame()
 		else if (pr.count == 1)
 		{
 			GiveWins(*pr.players.front(), 1);
-			SV_BroadcastPrintf("%s wins as the last player standing!\n",
-			                   pr.players.front()->userinfo.netname.c_str());
+			SV_BroadcastPrintFmt("{} wins as the last player standing!\n",
+			                     pr.players.front()->userinfo.netname);
 			::levelstate.setWinner(WinInfo::WIN_PLAYER, pr.players.front()->id);
 			M_CommitWDLLog();
 			::levelstate.endRound();
@@ -835,6 +880,39 @@ void G_LivesCheckEndGame()
 				aliveteams += 1;
 		}
 
+		SERVER_ONLY (
+		if (aliveteams > 1)
+		{
+			PlayerResults blueplayers = PlayerQuery().onTeam(TEAM_BLUE).execute();
+			PlayerResults redplayers = PlayerQuery().onTeam(TEAM_RED).execute();
+			PlayerResults greenplayers = PlayerQuery().onTeam(TEAM_GREEN).execute();
+			PlayerResults bluelivingplayers = PlayerQuery().onTeam(TEAM_BLUE).hasLives().execute();
+			PlayerResults redlivingplayers = PlayerQuery().onTeam(TEAM_RED).hasLives().execute();
+			PlayerResults greenlivingplayers = PlayerQuery().onTeam(TEAM_GREEN).hasLives().execute();
+			if (bluelivingplayers.count == 1 && blueplayers.count > 1 && !lastblueplayerhype)
+			{
+				SV_TeamPrintFmt(PRINT_WARNING, bluelivingplayers.players.front()->id,
+				                "{} is the last BLUE player alive!\n",
+				                bluelivingplayers.players.front()->userinfo.netname);
+				lastblueplayerhype = true;
+			}
+			if (redlivingplayers.count == 1 && redplayers.count > 1 && !lastredplayerhype)
+			{
+				SV_TeamPrintFmt(PRINT_WARNING, redlivingplayers.players.front()->id,
+				                "{} is the last RED player alive!\n",
+				                redlivingplayers.players.front()->userinfo.netname);
+				lastredplayerhype = true;
+			}
+			if (greenlivingplayers.count == 1 && greenplayers.count > 1 && !lastgreenplayerhype)
+			{
+				SV_TeamPrintFmt(PRINT_WARNING, greenlivingplayers.players.front()->id,
+				                "{} is the last GREEN player alive!\n",
+				                greenlivingplayers.players.front()->userinfo.netname);
+				lastgreenplayerhype = true;
+			}
+		}
+		)
+
 		// [AM] This end-of-game logic branch is necessary becuase otherwise
 		//      going for objectives in CTF would never be worth it.  However,
 		//      side-mode needs a special-case because otherwise in games
@@ -848,39 +926,42 @@ void G_LivesCheckEndGame()
 			if (tv.size() == 1)
 			{
 				GiveTeamWins(tv.front()->Team, 1);
-				SV_BroadcastPrintf(
-				    "%s team wins for having the highest score with %s left!\n",
-				    tv.front()->ColorizedTeamName().c_str(), teams);
+				SV_BroadcastPrintFmt(
+				    "{} team wins for having the highest score with {} left!\n",
+				    tv.front()->ColorizedTeamName(), teams);
 				::levelstate.setWinner(WinInfo::WIN_TEAM, tv.front()->Team);
 				M_CommitWDLLog();
 				::levelstate.endRound();
 			}
 			else
 			{
-				SV_BroadcastPrintf("Score is tied with with %s left. Game is a draw!\n",
-				                   teams);
+				SV_BroadcastPrintFmt("Score is tied with with {} left. Game is a draw!\n",
+				                     teams);
 				::levelstate.setWinner(WinInfo::WIN_DRAW, 0);
 				M_CommitWDLLog();
 				::levelstate.endRound();
 			}
+			G_ResetTeamLastPlayer();
 		}
 
 		if (aliveteams == 0 || pr.count == 0)
 		{
-			SV_BroadcastPrintf("All teams have run out of lives.\n");
+			SV_BroadcastPrintFmt("All teams have run out of lives.\n");
 			::levelstate.setWinner(WinInfo::WIN_DRAW, 0);
 			M_CommitWDLLog();
 			::levelstate.endRound();
+			G_ResetTeamLastPlayer();
 		}
 		else if (aliveteams == 1)
 		{
 			team_t team = pr.players.front()->userinfo.team;
 			GiveTeamWins(team, 1);
-			SV_BroadcastPrintf("%s team wins as the last team standing!\n",
-			                   GetTeamInfo(team)->ColorizedTeamName().c_str());
+			SV_BroadcastPrintFmt("{} team wins as the last team standing!\n",
+			                     GetTeamInfo(team)->ColorizedTeamName());
 			::levelstate.setWinner(WinInfo::WIN_TEAM, team);
 			M_CommitWDLLog();
 			::levelstate.endRound();
+			G_ResetTeamLastPlayer();
 		}
 
 		// Nobody won the game yet - keep going.
@@ -906,7 +987,7 @@ bool G_RoundsShouldEndGame()
 	{
 		if (g_roundlimit && ::levelstate.getRound() >= g_roundlimit)
 		{
-			SV_BroadcastPrintf(
+			SV_BroadcastPrintFmt(
 			    "Round limit hit. Players were unable to finish the level.\n");
 			::levelstate.setWinner(WinInfo::WIN_NOBODY, 0);
 			return true;
@@ -917,21 +998,21 @@ bool G_RoundsShouldEndGame()
 		PlayerResults pr = PlayerQuery().sortWins().filterSortMax().execute();
 		if (pr.count == 1 && g_winlimit && pr.players.front()->roundwins >= g_winlimit)
 		{
-			SV_BroadcastPrintf("Win limit hit. Match won by %s!\n",
-			                   pr.players.front()->userinfo.netname.c_str());
+			SV_BroadcastPrintFmt("Win limit hit. Match won by {}!\n",
+			                     pr.players.front()->userinfo.netname);
 			::levelstate.setWinner(WinInfo::WIN_PLAYER, pr.players.front()->id);
 			return true;
 		}
 		else if (pr.count == 1 && g_roundlimit && ::levelstate.getRound() >= g_roundlimit)
 		{
-			SV_BroadcastPrintf("Round limit hit. Match won by %s!\n",
-			                   pr.players.front()->userinfo.netname.c_str());
+			SV_BroadcastPrintFmt("Round limit hit. Match won by {}!\n",
+			                     pr.players.front()->userinfo.netname);
 			::levelstate.setWinner(WinInfo::WIN_PLAYER, pr.players.front()->id);
 			return true;
 		}
 		else if (g_roundlimit && ::levelstate.getRound() >= g_roundlimit)
 		{
-			SV_BroadcastPrintf("Round limit hit. Game is a draw!\n");
+			SV_BroadcastPrintFmt("Round limit hit. Game is a draw!\n");
 			::levelstate.setWinner(WinInfo::WIN_DRAW, 0);
 			return true;
 		}
@@ -941,22 +1022,22 @@ bool G_RoundsShouldEndGame()
 		TeamsView tv = TeamQuery().sortWins().filterSortMax().execute();
 		if (tv.size() == 1 && ::g_winlimit && tv.front()->RoundWins >= ::g_winlimit)
 		{
-			SV_BroadcastPrintf("Win limit hit. %s team wins!\n",
-			                   tv.front()->ColorizedTeamName().c_str());
+			SV_BroadcastPrintFmt("Win limit hit. {} team wins!\n",
+			                     tv.front()->ColorizedTeamName());
 			::levelstate.setWinner(WinInfo::WIN_TEAM, tv.front()->Team);
 			return true;
 		}
 		else if (tv.size() == 1 && ::g_roundlimit &&
 		         ::levelstate.getRound() >= ::g_roundlimit)
 		{
-			SV_BroadcastPrintf("Round limit hit. %s team wins!\n",
-			                   tv.front()->ColorizedTeamName().c_str());
+			SV_BroadcastPrintFmt("Round limit hit. {} team wins!\n",
+			                     tv.front()->ColorizedTeamName());
 			::levelstate.setWinner(WinInfo::WIN_TEAM, tv.front()->Team);
 			return true;
 		}
 		else if (::g_roundlimit && ::levelstate.getRound() >= ::g_roundlimit)
 		{
-			SV_BroadcastPrintf("Round limit hit. Game is a draw!\n");
+			SV_BroadcastPrintFmt("Round limit hit. Game is a draw!\n");
 			::levelstate.setWinner(WinInfo::WIN_DRAW, 0);
 			return true;
 		}
