@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: ff6fe62b370322260df57afa60fa674189cd058b $
+// $Id: 906157b2789fc394f6b9c5f1c7737416b4ab90fe $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -287,7 +287,7 @@ void LevelState::readyToggle()
 		if (m_state == LevelState::WARMUP_COUNTDOWN)
 		{
 			setState(LevelState::WARMUP);
-			SV_BroadcastPrintf("Countdown aborted: Player unreadied.\n");
+			SV_BroadcastPrintFmt("Countdown aborted: Player unreadied.\n");
 		}
 	}
 }
@@ -371,7 +371,7 @@ void LevelState::tic()
 				G_DeferedReset();
 
 			setState(LevelState::INGAME);
-			SV_BroadcastPrintf("FIGHT!\n");
+			SV_BroadcastPrintFmt("FIGHT!\n");
 			return;
 		}
 		break;
@@ -465,8 +465,8 @@ void LevelState::tic()
 				printRoundStart();
 			else
 			{
-				SV_BroadcastPrintf("The %s has started.\n",
-				                   G_IsCoopGame() ? "game" : "match");
+				SV_BroadcastPrintFmt("The {} has started.\n",
+				                     G_IsCoopGame() ? "game" : "match");
 			}
 			return;
 		}
@@ -615,16 +615,16 @@ void LevelState::printRoundStart() const
 	else if (def != TEAM_NONE)
 	{
 		TeamInfo& teaminfo = *GetTeamInfo(def);
-		right = fmt::sprintf("%s is on defense", teaminfo.ColorizedTeamName().c_str());
+		right = fmt::sprintf("%s is on defense", teaminfo.ColorizedTeamName());
 	}
 
 	if (!right.empty())
 	{
-		SV_BroadcastPrintf("%s - %s.\n", left.c_str(), right.c_str());
+		SV_BroadcastPrintFmt("{} - {}.\n", left, right);
 	}
 	else
 	{
-		SV_BroadcastPrintf("%s.\n", left.c_str());
+		SV_BroadcastPrintFmt("{}.\n", left);
 	}
 }
 
@@ -689,4 +689,4 @@ BEGIN_COMMAND(levelstateinfo)
 }
 END_COMMAND(levelstateinfo)
 
-VERSION_CONTROL(g_levelstate, "$Id: ff6fe62b370322260df57afa60fa674189cd058b $")
+VERSION_CONTROL(g_levelstate, "$Id: 906157b2789fc394f6b9c5f1c7737416b4ab90fe $")
