@@ -156,7 +156,7 @@ void MustGetStringName(OScanner& os, const char* name)
 	os.mustScan();
 	if (os.compareTokenNoCase(name) == false)
 	{
-		os.error("Expected '%s', got '%s'.", name, os.getToken().c_str());
+		os.error("Expected '{}', got '{}'.", name, os.getToken());
 	}
 }
 
@@ -166,6 +166,7 @@ void MustGetStringName(OScanner& os, const char* name)
 bool ContainsMapInfoTopLevel(const OScanner& os)
 {
 	return os.compareTokenNoCase("map") || os.compareTokenNoCase("defaultmap") ||
+	       os.compareTokenNoCase("adddefaultmap") ||
 	       os.compareTokenNoCase("cluster") || os.compareTokenNoCase("clusterdef") ||
 	       os.compareTokenNoCase("episode") || os.compareTokenNoCase("clearepisodes") ||
 	       os.compareTokenNoCase("skill") || os.compareTokenNoCase("clearskills") ||
@@ -243,8 +244,8 @@ void MIType_BoolString(OScanner& os, bool doEquals, void* data, unsigned int fla
 	else if (os.compareTokenNoCase("false"))
 		*static_cast<bool*>(data) = false;
 	else
-		os.error("Expected \"true\" or \"false\" in boolean statement, got \"%s\"",
-		         os.getToken().c_str());
+		os.error("Expected \"true\" or \"false\" in boolean statement, got \"{}\"",
+		         os.getToken());
 }
 
 // Sets the inputted data as a bool (that is, if flags != 0, set to true; else false)
@@ -479,13 +480,12 @@ void MIType_MapName(OScanner& os, bool newStyleMapInfo, void* data, unsigned int
 	}
 	else // Must be map lump
 	{
-		char map_name[9];
-		strncpy(map_name, os.getToken().c_str(), 8);
+		OLumpName map_name = os.getToken();
 
-		if (IsNum(map_name))
+		if (IsNum(map_name.c_str()))
 		{
-			const int map = std::atoi(map_name);
-			snprintf(map_name, 9, "MAP%02d", map);
+			const int map = std::atoi(map_name.c_str());
+			map_name = fmt::format("MAP{:02d}", map);
 		}
 
 		*static_cast<OLumpName*>(data) = map_name;
@@ -529,7 +529,7 @@ void MIType_$LumpName(OScanner& os, bool newStyleMapInfo, void* data, unsigned i
 		const OString& s = GStrings(StdStringToUpper(os.getToken()).c_str() + 1);
 		if (s.empty())
 		{
-			os.error("Unknown lookup string \"%s\".", os.getToken().c_str());
+			os.error("Unknown lookup string \"{}\".", os.getToken());
 		}
 		*static_cast<OLumpName*>(data) = s;
 	}
@@ -554,7 +554,7 @@ void MIType_MusicLumpName(OScanner& os, bool newStyleMapInfo, void* data, unsign
 		const OString& s = GStrings(StdStringToUpper(musicname.c_str() + 1));
 		if (s.empty())
 		{
-			os.error("Unknown lookup string \"%s\".", os.getToken().c_str());
+			os.error("Unknown lookup string \"{}\".", os.getToken());
 		}
 
 		// Music lumps in the stringtable do not begin
@@ -691,7 +691,7 @@ void MIType_ClusterString(OScanner& os, bool newStyleMapInfo, void* data, unsign
 {
 	ParseMapInfoHelper<std::string>(os, newStyleMapInfo);
 
-	char** text = static_cast<char**>(data);
+	std::string* text = static_cast<std::string*>(data);
 
 	if (newStyleMapInfo)
 	{
@@ -707,10 +707,9 @@ void MIType_ClusterString(OScanner& os, bool newStyleMapInfo, void* data, unsign
 			const OString& s = GStrings(StdStringToUpper(os.getToken()));
 			if (s.empty())
 			{
-				os.error("Unknown lookup string \"%s\".", os.getToken().c_str());
+				os.error("Unknown lookup string \"{}\".", os.getToken());
 			}
-			free(*text);
-			*text = strdup(s.c_str());
+			*text = s;
 		}
 		else
 		{
@@ -732,8 +731,7 @@ void MIType_ClusterString(OScanner& os, bool newStyleMapInfo, void* data, unsign
 				ctext.resize(ctext.length() - 1);
 			}
 
-			free(*text);
-			*text = strdup(ctext.c_str());
+			*text = ctext;
 		}
 	}
 	else
@@ -744,16 +742,14 @@ void MIType_ClusterString(OScanner& os, bool newStyleMapInfo, void* data, unsign
 			const OString& s = GStrings(StdStringToUpper(os.getToken()));
 			if (s.empty())
 			{
-				os.error("Unknown lookup string \"%s\".", os.getToken().c_str());
+				os.error("Unknown lookup string \"{}\".", os.getToken());
 			}
 
-			free(*text);
-			*text = strdup(s.c_str());
+			*text = s;
 		}
 		else
 		{
-			free(*text);
-			*text = strdup(os.getToken().c_str());
+			*text = os.getToken();
 		}
 	}
 }
@@ -882,20 +878,20 @@ void MIType_Map07Special(OScanner& os, bool newStyleMapInfo, void* data, unsigne
 	    *static_cast<std::vector<bossaction_t>*>(data);
 
 	// mancubus
-	bossactionvector.push_back(bossaction_t());
-	std::vector<bossaction_t>::iterator it = (bossactionvector.end() - 1);
+	bossactionvector.emplace_back();
+	bossaction_t& mancaction = bossactionvector.back();
 
-	it->type = MT_FATSO;
-	it->special = 23;
-	it->tag = 666;
+	mancaction.type = MT_FATSO;
+	mancaction.special = 23;
+	mancaction.tag = 666;
 
 	// arachnotron
-	bossactionvector.push_back(bossaction_t());
-	it = (bossactionvector.end() - 1);
+	bossactionvector.emplace_back();
+	bossaction_t& arachnoaction = bossactionvector.back();
 
-	it->type = MT_BABY;
-	it->special = 30;
-	it->tag = 667;
+	arachnoaction.type = MT_BABY;
+	arachnoaction.special = 30;
+	arachnoaction.tag = 667;
 }
 
 // Sets the map to use the baron bossaction
@@ -905,12 +901,11 @@ void MIType_BaronSpecial(OScanner& os, bool newStyleMapInfo, void* data, unsigne
 	std::vector<bossaction_t>& bossactionvector = *static_cast<std::vector<bossaction_t>*>(data);
 
 	if (bossactionvector.size() == 0)
-		bossactionvector.push_back(bossaction_t());
+		bossactionvector.emplace_back();
 
-	for (std::vector<bossaction_t>::iterator it = bossactionvector.begin();
-	     it != bossactionvector.end(); ++it)
+	for (auto& bossaction : bossactionvector)
 	{
-		it->type = MT_BRUISER;
+		bossaction.type = MT_BRUISER;
 	}
 }
 
@@ -922,12 +917,11 @@ void MIType_CyberdemonSpecial(OScanner& os, bool newStyleMapInfo, void* data, un
 	    *static_cast<std::vector<bossaction_t>*>(data);
 
 	if (bossactionvector.size() == 0)
-		bossactionvector.push_back(bossaction_t());
+		bossactionvector.emplace_back();
 
-	for (std::vector<bossaction_t>::iterator it = bossactionvector.begin();
-	     it != bossactionvector.end(); ++it)
+	for (auto& bossaction : bossactionvector)
 	{
-		it->type = MT_CYBORG;
+		bossaction.type = MT_CYBORG;
 	}
 }
 
@@ -939,12 +933,11 @@ void MIType_SpiderMastermindSpecial(OScanner& os, bool newStyleMapInfo, void* da
 	    *static_cast<std::vector<bossaction_t>*>(data);
 
 	if (bossactionvector.size() == 0)
-		bossactionvector.push_back(bossaction_t());
+		bossactionvector.emplace_back();
 
-	for (std::vector<bossaction_t>::iterator it = bossactionvector.begin();
-	     it != bossactionvector.end(); ++it)
+	for (auto& bossaction : bossactionvector)
 	{
-		it->type = MT_SPIDER;
+		bossaction.type = MT_SPIDER;
 	}
 }
 
@@ -954,21 +947,20 @@ void MIType_SpecialAction_ExitLevel(OScanner& os, bool newStyleMapInfo, void* da
 {
 	std::vector<bossaction_t>& bossactionvector = *static_cast<std::vector<bossaction_t>*>(data);
 
-	std::vector<bossaction_t>::iterator it;
-	for (it = bossactionvector.begin(); it != bossactionvector.end(); ++it)
+	for (auto& bossaction : bossactionvector)
 	{
-		if (it->type != MT_NULL)
+		if (bossaction.type != MT_NULL)
 		{
-			it->special = 11;
-			it->tag = 0;
+			bossaction.special = 11;
+			bossaction.tag = 0;
 			return;
 		}
 	}
 
-	bossactionvector.push_back(bossaction_t());
-	it = bossactionvector.end() - 1;
-	it->special = 11;
-	it->tag = 0;
+	bossactionvector.emplace_back();
+	bossaction_t& action = bossactionvector.back();
+	action.special = 11;
+	action.tag = 0;
 }
 
 //
@@ -977,21 +969,20 @@ void MIType_SpecialAction_OpenDoor(OScanner& os, bool newStyleMapInfo, void* dat
 {
 	std::vector<bossaction_t>& bossactionvector = *static_cast<std::vector<bossaction_t>*>(data);
 
-	std::vector<bossaction_t>::iterator it;
-	for (it = bossactionvector.begin(); it != bossactionvector.end(); ++it)
+	for (auto& bossaction : bossactionvector)
 	{
-		if (it->type != MT_NULL)
+		if (bossaction.type != MT_NULL)
 		{
-			it->special = 29;
-			it->tag = 666;
+			bossaction.special = 29;
+			bossaction.tag = 666;
 			return;
 		}
 	}
 
-	bossactionvector.push_back(bossaction_t());
-	it = bossactionvector.end() - 1;
-	it->special = 29;
-	it->tag = 666;
+	bossactionvector.emplace_back();
+	bossaction_t& action = bossactionvector.back();
+	action.special = 29;
+	action.tag = 666;
 }
 
 //
@@ -1000,21 +991,20 @@ void MIType_SpecialAction_LowerFloor(OScanner& os, bool newStyleMapInfo, void* d
 {
 	std::vector<bossaction_t>& bossactionvector = *static_cast<std::vector<bossaction_t>*>(data);
 
-	std::vector<bossaction_t>::iterator it;
-	for (it = bossactionvector.begin(); it != bossactionvector.end(); ++it)
+	for (auto& bossaction : bossactionvector)
 	{
-		if (it->type != MT_NULL)
+		if (bossaction.type != MT_NULL)
 		{
-			it->special = 23;
-			it->tag = 666;
+			bossaction.special = 23;
+			bossaction.tag = 666;
 			return;
 		}
 	}
 
-	bossactionvector.push_back(bossaction_t());
-	it = (bossactionvector.end() - 1);
-	it->special = 23;
-	it->tag = 666;
+	bossactionvector.emplace_back();
+	bossaction_t& action = bossactionvector.back();
+	action.special = 23;
+	action.tag = 666;
 }
 
 //
@@ -1105,7 +1095,7 @@ void MIType_AutomapBase(OScanner& os, bool newStyleMapInfo, void* data, unsigned
 	else if (os.compareTokenNoCase("strife"))
 		AM_SetBaseColorStrife();
 	else
-		os.warning("base expected \"doom\", \"heretic\", or \"strife\"; got %s", os.getToken().c_str());
+		os.warning("base expected \"doom\", \"heretic\", or \"strife\"; got {}", os.getToken());
 }
 
 //
@@ -1114,7 +1104,7 @@ bool ScanAndCompareString(OScanner& os, std::string cmp)
 	os.scan();
 	if (!os.compareToken(cmp.c_str()))
 	{
-		os.warning("Expected \"%s\", got \"%s\". Aborting parsing", cmp.c_str(), os.getToken().c_str());
+		os.warning("Expected \"{}\", got \"{}\". Aborting parsing", cmp, os.getToken());
 		return false;
 	}
 
@@ -1127,7 +1117,7 @@ bool ScanAndSetRealNum(OScanner& os, fixed64_t& num)
 	os.scan();
 	if (!IsRealNum(os.getToken().c_str()))
 	{
-		os.warning("Expected number, got \"%s\". Aborting parsing", os.getToken().c_str());
+		os.warning("Expected number, got \"{}\". Aborting parsing", os.getToken());
 		return false;
 	}
 	num = FLOAT2FIXED64(os.getTokenFloat());
@@ -1187,7 +1177,7 @@ void MIType_MapArrows(OScanner& os, bool newStyleMapInfo, void* data, unsigned i
 	std::string maparrow = os.getToken();
 
 	if (!InterpretLines(maparrow, gameinfo.mapArrow))
-		os.warning("Map arrow lump \"%s\" could not be found", maparrow.c_str());
+		os.warning("Map arrow lump \"{}\" could not be found", maparrow);
 
 	os.scan();
 	if (os.compareToken(","))
@@ -1196,7 +1186,7 @@ void MIType_MapArrows(OScanner& os, bool newStyleMapInfo, void* data, unsigned i
 		maparrow = os.getToken();
 
 		if (!InterpretLines(maparrow, gameinfo.mapArrowCheat))
-			os.warning("Map arrow lump \"%s\" could not be found", maparrow.c_str());
+			os.warning("Map arrow lump \"{}\" could not be found", maparrow);
 	}
 	else
 	{
@@ -1329,7 +1319,10 @@ struct MapInfoDataSetter<level_pwad_info_t>
 			{ "compat_sectorsounds", &MIType_CompatFlag, &ref.flags }, // todo: not implemented
 			{ "compat_nopassover", &MIType_CompatFlag, &ref.flags, LEVEL_COMPAT_NOPASSOVER },
 			{ "compat_invisibility", &MIType_CompatFlag, &ref.flags},  // todo: not implemented
-			{ "author", &MIType_String, &ref.author }
+			{ "author", &MIType_String, &ref.author },
+			{ "normalinfighting", &MIType_SCFlags, &ref.flags2, LEVEL2_NORMALINFIGHTING, ~LEVEL2_INFIGHTINGMASK },
+			{ "noinfighting", &MIType_SCFlags, &ref.flags2, LEVEL2_NOINFIGHTING, ~LEVEL2_INFIGHTINGMASK },
+			{ "totalinfighting", &MIType_SCFlags, &ref.flags2, LEVEL2_TOTALINFIGHTING, ~LEVEL2_INFIGHTINGMASK }
 		};
 	}
 };
@@ -1464,7 +1457,7 @@ void ParseMapInfoLower(OScanner& os, MapInfoDataSetter<T>& mapInfoDataSetter)
 				// able to parse all types even if we can't
 				// do anything with them.
 				//
-				os.error("Unknown MAPINFO token \"%s\"", os.getToken().c_str());
+				os.error("Unknown MAPINFO token \"{}\"", os.getToken());
 			}
 
 			// New MAPINFO is capable of skipping past unknown
@@ -1479,7 +1472,7 @@ void ParseEpisodeInfo(OScanner& os)
 {
 	int new_mapinfo = false; // is int instead of bool for template purposes
 	OLumpName map;
-	std::string pic;
+	OLumpName pic;
 	std::string name;
 	bool picisgfx = false;
 	bool remove = false;
@@ -1585,7 +1578,7 @@ void ParseEpisodeInfo(OScanner& os)
 			break;
 	}
 
-	if (remove || (optional && W_CheckNumForName(map.c_str()) == -1) ||
+	if (remove || (optional && W_CheckNumForName(map) == -1) ||
 	    (extended && W_CheckNumForName("EXTENDED") == -1))
 	{
 		// If the remove property is given for an episode, remove it.
@@ -1616,7 +1609,7 @@ void ParseEpisodeInfo(OScanner& os)
 	{
 		if (pic.empty())
 		{
-			pic = map.c_str();
+			pic = map;
 			picisgfx = false;
 		}
 
@@ -1670,7 +1663,7 @@ struct MapInfoDataSetter<SkillInfo>
 			{ "instantreaction", &MIType_Bool, &ref.instant_reaction, true },
 			{ "acsreturn", &MIType_Int, &ref.ACS_return },
 			{ "name", &MIType_String, &ref.menu_name },
-			{ "picname", &MIType_String, &ref.pic_name },
+			{ "picname", &MIType_LumpName, &ref.pic_name },
 			// { "playerclassname", &???, &ref.menu_names_for_player_class } // todo - requires special MIType to work properly
 			{ "mustconfirm", &MIType_MustConfirm, &ref, true },
 			{ "key", &MIType_Char, &ref.shortcut },
@@ -1679,7 +1672,8 @@ struct MapInfoDataSetter<SkillInfo>
 			{ "monsterhealth", &MIType_Float, &ref.monster_health },
 			{ "friendlyhealth", &MIType_Float, &ref.friendly_health },
 			{ "nopain", &MIType_Bool, &ref.no_pain, true },
-			{ "infighting", &MIType_Int, &ref.infighting },
+			{ "noinfighting", &MIType_SCFlags, &ref.flags, SKILL_NOINFIGHTING, ~SKILL_TOTALINFIGHTING },
+			{ "totalinfighting", &MIType_SCFlags, &ref.flags, SKILL_TOTALINFIGHTING, ~SKILL_NOINFIGHTING },
 			{ "playerrespawn", &MIType_Bool, &ref.player_respawn, true }
 		};
 	}
@@ -1752,6 +1746,14 @@ void G_MapNameToLevelNum(level_pwad_info_t& info)
 	}
 }
 
+void G_MapNameToID24LevelNum(level_pwad_info_t& info)
+{
+	int ep, map;
+	ValidateMapName(info.mapname, &ep, &map);
+	info.mapnum = map;
+	info.episodenum = ep;
+}
+
 namespace
 {
 
@@ -1760,7 +1762,7 @@ void ParseMapInfoLump(int lump, const OLumpName& lumpname)
 	LevelInfos& levels = getLevelInfos();
 	ClusterInfos& clusters = getClusterInfos();
 
-	level_pwad_info_t defaultinfo;
+	level_pwad_info_t defaultinfo{};
 
 	const char* buffer = static_cast<char*>(W_CacheLumpNum(lump, PU_STATIC));
 
@@ -1780,20 +1782,22 @@ void ParseMapInfoLump(int lump, const OLumpName& lumpname)
 			MapInfoDataSetter<level_pwad_info_t> defaultsetter(defaultinfo);
 			ParseMapInfoLower<level_pwad_info_t>(os, defaultsetter);
 		}
+		else if (os.compareTokenNoCase("adddefaultmap"))
+		{
+			MapInfoDataSetter<level_pwad_info_t> defaultsetter(defaultinfo);
+			ParseMapInfoLower<level_pwad_info_t>(os, defaultsetter);
+		}
 		else if (os.compareTokenNoCase("map"))
 		{
 			uint32_t& levelflags = defaultinfo.flags;
 			os.mustScan();
 
-			char map_name[9];
-			strncpy(map_name, os.getToken().c_str(), 8);
+			OLumpName map_name = os.getToken();
 
-			if (IsNum(map_name))
+			if (IsNum(map_name.c_str()))
 			{
-				// MAPNAME is a number, assume a Hexen wad
-				const int map = std::atoi(map_name);
-
-				snprintf(map_name, 9, "MAP%02d", map);
+				const int map = std::atoi(map_name.c_str());
+				map_name = fmt::format("MAP{:02d}", map);
 				HexenHack = true;
 				// Hexen levels are automatically nointermission
 				// and even lighting and no auto sound sequences
@@ -1849,6 +1853,7 @@ void ParseMapInfoLump(int lump, const OLumpName& lumpname)
 			{
 				G_MapNameToLevelNum(info);
 			}
+			G_MapNameToID24LevelNum(info);
 		}
 		else if (os.compareTokenNoCase("cluster") ||
 		         os.compareTokenNoCase("clusterdef"))
@@ -1928,7 +1933,7 @@ void ParseMapInfoLump(int lump, const OLumpName& lumpname)
 		}
 		else
 		{
-			os.error("Unimplemented top-level type \"%s\"", os.getToken().c_str());
+			os.error("Unimplemented top-level type \"{}\"", os.getToken());
 		}
 	}
 }
@@ -1986,7 +1991,7 @@ void G_ParseMapInfo()
 		break;
 	case none:
 	default:
-		I_Error("%s: This IWAD is unknown to Odamex", __FUNCTION__);
+		I_Error("{}: This IWAD is unknown to Odamex", __FUNCTION__);
 		break;
 	}
 
@@ -2007,14 +2012,14 @@ void G_ParseMapInfo()
 	}
 
 	if (episodenum == 0)
-		I_FatalError("%s: You cannot use clearepisodes in a MAPINFO if you do not define any "
+		I_FatalError("{}: You cannot use clearepisodes in a MAPINFO if you do not define any "
 		             "new episodes after it.", __FUNCTION__);
 
 	if (defaultskillmenu > skillnum - 1)
 		defaultskillmenu = skillnum - 1;
 
 	if (skillnum == 0)
-		I_FatalError("%s: You cannot use clearskills in a MAPINFO if you do not define any "
+		I_FatalError("{}: You cannot use clearskills in a MAPINFO if you do not define any "
 					"new skills after it.", __FUNCTION__);
 
 	// mark levels as secrets -- for ID24 intermissions
