@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: b83d615b1681139863b28fb5e4fb34bb945f9243 $
+// $Id: e3669678d9ac43d08cc653f733f201b08e1190ef $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -28,4 +28,4 @@
 mobjtype_t P_NameToMobj(const std::string& name);
 mobjtype_t P_INameToMobj(const std::string& name);
 weapontype_t P_NameToWeapon(const std::string& name);
-std::string P_MobjToName(const mobjtype_t name);
+std::string P_MobjToName(const mobjtype_t type);
