@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 8d19cad459aaf5eee5896865e7a8d4456de2e33c $
+// $Id: 1270418e2cc972a3f3654d4eaa5d1d63bd73d1a4 $
 //
 // Copyright (C) 2006-2025 by The Odamex Team.
 //
@@ -37,11 +37,11 @@
 class OString;
 
 // Forward declarations for non-member functions
-bool operator== (const OString& lhs, const OString& rhs);
-bool operator== (const OString& lhs, const std::string& rhs);
-bool operator== (const std::string& lhs, const OString& rhs);
-bool operator== (const OString& lhs, const char* rhs);
-bool operator== (const char* lhs, const OString& rhs);
+[[nodiscard]] bool operator== (const OString& lhs, const OString& rhs);
+[[nodiscard]] bool operator== (const OString& lhs, const std::string& rhs);
+[[nodiscard]] bool operator== (const std::string& lhs, const OString& rhs);
+[[nodiscard]] bool operator== (const OString& lhs, const char* rhs);
+[[nodiscard]] bool operator== (const char* lhs, const OString& rhs);
 bool operator!= (const OString& lhs, const OString& rhs);
 bool operator!= (const OString& lhs, const std::string& rhs);
 bool operator!= (const std::string& lhs, const OString& rhs);
@@ -601,7 +601,7 @@ private:
 			assert(mStrings->size() < OString::MAX_STRINGS);
 			const StringIdType id = mStrings->insert(StringRecord(str, 0, length));
 			rec = &mStrings->get(id);
-			mStringLookup->insert(std::pair<HashedStringType, StringIdType>(hash_value, id));
+			mStringLookup->emplace(hash_value, id);
 		}
 		return rec;
 	}
