@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 891eedc3fff92c16f1b29632539ae52531cc75b6 $
+// $Id: 6748ab6570542b3fc91e07246544c2e505429c3a $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -99,12 +99,12 @@ static void ClearInventory(AActor* activator)
 {
 	if (activator == NULL)
 	{
-		for (Players::iterator it = players.begin(); it != players.end(); ++it)
+		for (auto& player : players)
 		{
-			if (it->ingame() && !it->spectator)
+			if (player.ingame() && !player.spectator)
 			{
-				DoClearInv(&(*it));
-				SERVER_ONLY(SV_SendPlayerInfo(*it));
+				DoClearInv(&player);
+				SERVER_ONLY(SV_SendPlayerInfo(player));
 			}
 		}
 	}
@@ -228,7 +228,7 @@ static DoomEntity DoomDecorationNames[60] = {{"BurningBarrel", MT_MISC77},
                                              {"ExplosiveBarrel", MT_BARREL}};
 
 extern ItemEquipVal P_GiveAmmo(player_t *player, ammotype_t ammo, float num);
-extern ItemEquipVal P_GiveWeapon(player_t *player, weapontype_t weapon, BOOL dropped);
+extern ItemEquipVal P_GiveWeapon(player_t *player, weapontype_t weapon, bool dropped);
 extern ItemEquipVal P_GiveCard(player_t *player, card_t card);
 extern ItemEquipVal P_GivePower(player_t *player, int  power);
 
@@ -241,7 +241,7 @@ mobjtype_t FindWeaponEntity(const char* type)
 		{
 			if (DoomWeaponNames[i].Type == MT_NULL)
 			{
-				DPrintf("ACS: LOGIC ERROR - Cannot spawn default weapons!\n");
+				DPrintFmt("ACS: LOGIC ERROR - Cannot spawn default weapons!\n");
 				return MT_NULL;
 			}
 			return DoomWeaponNames[i].Type;
@@ -368,11 +368,10 @@ static void GiveInventory(AActor* activator, const char* type, int amount)
 	{
 		for (int i = 0; i < MAXPLAYERS; ++i)
 		{
-			Players::iterator it;
-			for (it = players.begin();it != players.end();++it)
+			for (auto& player : players)
 			{
-				if (it->ingame() && !it->spectator)
-					DoGiveInv(&(*it), type, amount);
+				if (player.ingame() && !player.spectator)
+					DoGiveInv(&player, type, amount);
 			}
 		}
 	}
@@ -407,7 +406,7 @@ static void TakeWeapon(player_t* player, int weapon)
 	SERVER_ONLY(SV_SendPlayerInfo(*player));
 }
 
-extern BOOL P_CheckAmmo (player_t *player);
+extern bool P_CheckAmmo (player_t *player);
 
 static void TakeAmmo(player_t* player, int ammo, int amount)
 {
@@ -512,11 +511,10 @@ static void TakeInventory(AActor* activator, const char* type, int amount)
 {
 	if (activator == NULL)
 	{
-		Players::iterator it;
-		for (it = players.begin();it != players.end();++it)
+		for (auto& player : players)
 		{
-			if (it->ingame() && !it->spectator)
-				DoTakeInv(&(*it), type, amount);
+			if (player.ingame() && !player.spectator)
+				DoTakeInv(&player, type, amount);
 		}
 	}
 	else if (activator->player != NULL)
@@ -730,7 +728,7 @@ FBehavior::FBehavior (BYTE *object, int len)
 		}
 	}
 
-	DPrintf ("Loaded %d scripts, %d Functions\n", NumScripts, NumFunctions);
+	DPrintFmt("Loaded {} scripts, {} Functions\n", NumScripts, NumFunctions);
 }
 
 FBehavior::~FBehavior ()
@@ -1031,7 +1029,7 @@ DACSThinker::DACSThinker ()
 {
 	if (ActiveThinker)
 	{
-		I_Error ("Only one ACSThinker is allowed to exist at a time.\nCheck your code.");
+		I_Error("Only one ACSThinker is allowed to exist at a time.\nCheck your code.");
 	}
 	else
 	{
@@ -1066,7 +1064,7 @@ void DACSThinker::Serialize (FArchive &arc)
 			if (RunningScripts[i])
 				arc << RunningScripts[i] << (WORD)i;
 		}
-		arc << (DLevelScript *)NULL;
+		arc << static_cast<DLevelScript*>(nullptr);
 	}
 	else
 	{
@@ -1354,7 +1352,7 @@ void DLevelScript::Serialize (FArchive &arc)
 
 		// [AM] We don't want player activators to be saved
 		if (arc.IsReset() && P_ThinkerIsPlayerType(activator))
-			arc << (AActor*)NULL;
+			arc << static_cast<AActor*>(nullptr);
 		else
 			arc << activator;
 
@@ -2035,7 +2033,7 @@ int DLevelScript::DoSpawnSpot(int type, int spot, int tid, int angle)
 
 void DLevelScript::DoFadeTo(AActor* who, int r, int g, int b, int a, fixed_t time)
 {
-    DPrintf("DoFadeRange now... \n");
+    DPrintFmt("DoFadeRange now... \n");
 	DoFadeRange(who, 0, 0, 0, -1, r, g, b, a, time);
 }
 
@@ -2186,7 +2184,7 @@ void DLevelScript::RunScript ()
 	{
 		if (++runaway > 500000)
 		{
-			DPrintf ("Runaway script %d terminated\n", script);
+			DPrintFmt("Runaway script {} terminated\n", script);
 			state = SCRIPT_PleaseRemove;
 			break;
 		}
@@ -2207,7 +2205,7 @@ void DLevelScript::RunScript ()
 		switch (pcd)
 		{
 		default:
-			DPrintf("Unknown P-Code %d in script %d\n", pcd, script);
+			DPrintFmt("Unknown P-Code {} in script {}\n", pcd, script);
 			continue;
 			// fall through
 		case PCD_TERMINATE:
@@ -3766,7 +3764,7 @@ void DLevelScript::RunScript ()
 			}
 			else
 			{
-				STACK(1) = (int)var->value();
+				STACK(1) = var->asInt();
 			}
 		}
 		break;
@@ -3862,12 +3860,12 @@ void DLevelScript::RunScript ()
 
 	if (state == SCRIPT_DivideBy0)
 	{
-		DPrintf("Divide by zero in script %d\n", script);
+		DPrintFmt("Divide by zero in script {}\n", script);
 		state = SCRIPT_PleaseRemove;
 	}
 	else if (state == SCRIPT_ModulusBy0)
 	{
-		DPrintf("Modulus by zero in script %d\n", script);
+		DPrintFmt("Modulus by zero in script {}\n", script);
 		state = SCRIPT_PleaseRemove;
 	}
 
@@ -3934,7 +3932,7 @@ DLevelScript::DLevelScript (AActor *who, line_t *where, int num, int *code, int
 
 	Link ();
 
-	DPrintf ("Script %d started.\n", num);
+	DPrintFmt("Script {} started.\n", num);
 }
 
 static void SetScriptState (int script, DLevelScript::EScriptState state)
@@ -3976,12 +3974,12 @@ void P_DoDeferedScripts (void)
 
 		case acsdefered_t::defsuspend:
 			SetScriptState (def->script, DLevelScript::SCRIPT_Suspended);
-			DPrintf ("Defered suspend of script %d\n", def->script);
+			DPrintFmt("Defered suspend of script {}\n", def->script);
 			break;
 
 		case acsdefered_t::defterminate:
 			SetScriptState (def->script, DLevelScript::SCRIPT_PleaseRemove);
-			DPrintf ("Defered terminate of script %d\n", def->script);
+			DPrintFmt("Defered terminate of script {}\n", def->script);
 			break;
 		}
 		delete def;
@@ -4011,7 +4009,7 @@ static void addDefered (level_pwad_info_t& i, acsdefered_t::EType type, int scri
 			def->playernum = -1;
 		}
 		i.defered = def;
-		DPrintf ("Script %d on map %s defered\n", script, i.mapname.c_str());
+		DPrintFmt("Script {} on map {} defered\n", script, i.mapname);
 	}
 }
 
@@ -4213,4 +4211,4 @@ void DACSThinker::DumpScriptStatus ()
 }
 
 
-VERSION_CONTROL (p_acs_cpp, "$Id: 891eedc3fff92c16f1b29632539ae52531cc75b6 $")
+VERSION_CONTROL (p_acs_cpp, "$Id: 6748ab6570542b3fc91e07246544c2e505429c3a $")
