@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: c4c63e972dce209cd2bb02d6331ad41905ba2352 $
+// $Id: 325544908070d59e7163373bb5f2f91e436024f2 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -201,7 +201,7 @@ static bool P_CheckRange(AActor* actor, fixed_t range)
 //
 // P_CheckMeleeRange
 //
-BOOL P_CheckMeleeRange (AActor *actor)
+bool P_CheckMeleeRange (AActor *actor)
 {
 	AActor *pl;
 	fixed_t dist;
@@ -239,7 +239,7 @@ BOOL P_CheckMeleeRange (AActor *actor)
 //
 // P_CheckMissileRange
 //
-BOOL P_CheckMissileRange (AActor *actor)
+bool P_CheckMissileRange (AActor *actor)
 {
 	fixed_t dist;
 
@@ -277,7 +277,6 @@ BOOL P_CheckMissileRange (AActor *actor)
 	{
 		if (dist < 196)
 			return false;		// close for fist attack
-		dist >>= 1;
 	}
 
 
@@ -304,10 +303,10 @@ BOOL P_CheckMissileRange (AActor *actor)
 //
 extern	std::vector<line_t*> spechit;
 
-BOOL P_Move (AActor *actor)
+bool P_Move (AActor *actor)
 {
 	fixed_t tryx, tryy, deltax, deltay, origx, origy;
-	BOOL try_ok;
+	bool try_ok;
 	int good;
 	int speed;
 	int movefactor = ORIG_FRICTION_FACTOR;
@@ -338,7 +337,7 @@ BOOL P_Move (AActor *actor)
 	}
 
 	if ((unsigned)actor->movedir >= 8)
-		I_Error ("Weird actor->movedir!");
+		I_Error("Weird actor->movedir!");
 
 	speed = actor->info->speed;
 
@@ -436,7 +435,7 @@ BOOL P_Move (AActor *actor)
 // If a door is in the way,
 // an OpenDoor call is made to start it opening.
 //
-BOOL P_TryWalk (AActor *actor)
+bool P_TryWalk (AActor *actor)
 {
 	if (!P_Move (actor))
 	{
@@ -526,7 +525,7 @@ void P_NewChaseDir (AActor *actor)
 	dirtype_t	turnaround;
 
 	if (!actor->target)
-		I_Error ("P_NewChaseDir: called with no target");
+		I_Error("P_NewChaseDir: called with no target");
 
 	olddir = (dirtype_t)actor->movedir;
 	turnaround = opposite[olddir];
@@ -697,12 +696,12 @@ bool P_LookForPlayers(AActor *actor, bool allaround)
 	memset(playeringame, 0, sizeof(player_t*) * MAXPLAYERS);
 
 	short maxid = 0;
-	for (Players::iterator it = players.begin();it != players.end();++it)
+	for (auto& player : players)
 	{
-		if (it->ingame() && !(it->spectator))
+		if (player.ingame() && !(player.spectator))
 		{
-			playeringame[(it->id) - 1] = &*it;
-			maxid = it->id;
+			playeringame[(player.id) - 1] = &player;
+			maxid = player.id;
 		}
 	}
 
@@ -894,13 +893,13 @@ void A_Look (AActor *actor)
 	{
 		char sound[MAX_SNDNAME];
 
-		strcpy (sound, actor->info->seesound);
+		M_StringCopy(sound, actor->info->seesound, MAX_SNDNAME);
 
-		if (sound[strlen(sound)-1] == '1')
+		if (sound[strlen(sound) - 1] == '1')
 		{
-			sound[strlen(sound)-1] = P_Random(actor)%3 + '1';
+			sound[strlen(sound) - 1] = P_Random(actor)%3 + '1';
 			if (S_FindSound (sound) == -1)
-				sound[strlen(sound)-1] = '1';
+				sound[strlen(sound) - 1] = '1';
 		}
 
 		if (!co_zdoomsound && (actor->flags2 & MF2_BOSS || actor->flags3 & MF3_FULLVOLSOUNDS))
@@ -1184,6 +1183,7 @@ void A_CPosRefire (AActor *actor)
 		return;
 
 	if (!actor->target
+		|| (actor->target->player && actor->target->player->spectator)
 		|| actor->target->health <= 0
 		|| !P_CheckSight(actor, actor->target)
         )
@@ -1202,6 +1202,7 @@ void A_SpidRefire (AActor *actor)
 		return;
 
 	if (!actor->target
+		|| (actor->target->player && actor->target->player->spectator)
 		|| actor->target->health <= 0
 		|| !P_CheckSight(actor, actor->target)
         )
@@ -1452,10 +1453,10 @@ fixed_t 		viletryx;
 fixed_t 		viletryy;
 int				viletryradius;
 
-BOOL PIT_VileCheck (AActor *thing)
+bool PIT_VileCheck (AActor *thing)
 {
 	int 	maxdist;
-	BOOL 	check;
+	bool 	check;
 
 	if (thing->oflags & MFO_NORAISE)
 		return true;	// [AM] Can't raise
@@ -1477,9 +1478,33 @@ BOOL PIT_VileCheck (AActor *thing)
 
 	corpsehit = thing;
 	corpsehit->momx = corpsehit->momy = 0;
-	corpsehit->height <<= 2;
-	check = P_CheckPosition (corpsehit, corpsehit->x, corpsehit->y);
-	corpsehit->height >>= 2;
+
+	if (P_AllowPassover())
+		corpsehit->flags |= MF_SOLID;
+
+	if (co_novileghosts)
+	{
+		int height, radius;
+
+		corpsehit->flags |= MF_SOLID;
+		height = corpsehit->height; // save temporarily
+		radius = corpsehit->radius; // save temporarily
+		corpsehit->height = P_ThingInfoHeight(corpsehit->info);
+		corpsehit->radius = corpsehit->info->radius;
+		check = P_CheckPosition(corpsehit, corpsehit->x, corpsehit->y);
+		corpsehit->height = height; // restore
+		corpsehit->radius = radius; // restore
+		corpsehit->flags &= ~MF_SOLID;
+	}
+	else
+	{
+		corpsehit->height <<= 2;
+		check = P_CheckPosition(corpsehit, corpsehit->x, corpsehit->y);
+		corpsehit->height >>= 2;
+	}
+
+	if (P_AllowPassover())
+		corpsehit->flags &= ~MF_SOLID;
 
 	return !check;
 }
@@ -1940,6 +1965,8 @@ void A_SpawnObject(AActor* actor)
 		}
 	}
 
+	SV_UpdateMobj(mo);
+
 	// [XA] don't bother with the dont-inherit-friendliness hack
 	// that exists in A_Spawn, 'cause WTF is that about anyway?
 }
@@ -1997,6 +2024,8 @@ void A_MonsterProjectile(AActor* actor)
 	// always set the 'tracer' field, so this pointer
 	// can be used to fire seeker missiles at will.
 	mo->tracer = actor->target;
+
+	SV_UpdateMobj(mo);
 }
 
 //
@@ -2436,13 +2465,14 @@ void A_JumpIfFlagsSet(AActor* actor)
 //
 void A_AddFlags(AActor* actor)
 {
-	int flags, flags2;
-
 	if (!actor)
 		return;
 
-	flags = actor->state->args[0];
-	flags2 = actor->state->args[1];
+	const int flags = actor->state->args[0];
+	const int flags2 = actor->state->args[1];
+
+	if (flags & MF_TRANSLUCENT)
+		actor->translucency = TRANSLUC66;
 
 	actor->flags |= flags;
 	actor->flags2 |= flags2;
@@ -2456,13 +2486,14 @@ void A_AddFlags(AActor* actor)
 //
 void A_RemoveFlags(AActor* actor)
 {
-	int flags, flags2;
-
 	if (!actor)
 		return;
 
-	flags = actor->state->args[0];
-	flags2 = actor->state->args[1];
+	const int flags = actor->state->args[0];
+	const int flags2 = actor->state->args[1];
+
+	if (flags & MF_TRANSLUCENT)
+		actor->translucency = FRACUNIT;
 
 	actor->flags &= ~flags;
 	actor->flags2 &= ~flags2;
@@ -2601,19 +2632,19 @@ void A_Scream (AActor *actor)
         return;
 
 
-	strcpy (sound, actor->info->deathsound);
+	M_StringCopy(sound, actor->info->deathsound, MAX_SNDNAME);
 
     if (stricmp(sound, "grunt/death1") == 0 ||
         stricmp(sound, "shotguy/death1") == 0 ||
         stricmp(sound, "chainguy/death1") == 0)
     {
-        sound[strlen(sound)-1] = P_Random(actor) % 3 + '1';
+        sound[strlen(sound) - 1] = P_Random(actor) % 3 + '1';
     }
 
     if (stricmp(sound, "imp/death1") == 0 ||
         stricmp(sound, "imp/death2") == 0)
     {
-        sound[strlen(sound)-1] = P_Random(actor) % 2 + '1';
+        sound[strlen(sound) - 1] = P_Random(actor) % 2 + '1';
     }
 
 	if (!co_zdoomsound && (actor->flags2 & MF2_BOSS || actor->flags3 & MF3_FULLVOLSOUNDS))
@@ -2821,7 +2852,7 @@ void P_SpawnBrainTargets (void)	// killough 3/26/98: renamed old function
 		{	// killough 2/7/98: remove limit on icon landings:
 			if (numbraintargets >= numbraintargets_alloc)
 			{
-				braintargets = (AActor **)Realloc (braintargets,
+				braintargets = (AActor **)M_Realloc (braintargets,
 					(numbraintargets_alloc = numbraintargets_alloc ?
 					 numbraintargets_alloc*2 : 32) *sizeof *braintargets);
 			}
@@ -3112,7 +3143,7 @@ void A_PlaySound(AActor* mo)
 
 	if (sndmap >= static_cast<int>(ARRAY_LENGTH(SoundMap)))
 	{
-		DPrintf("Warning: Sound ID is beyond the array of the Sound Map!\n");
+		DPrintFmt("Warning: Sound ID is beyond the array of the Sound Map!\n");
 		sndmap = 0;
 	}
 
@@ -3154,4 +3185,4 @@ void A_LineEffect(AActor* mo)
 	*/
 }
 
-VERSION_CONTROL (p_enemy_cpp, "$Id: c4c63e972dce209cd2bb02d6331ad41905ba2352 $")
+VERSION_CONTROL (p_enemy_cpp, "$Id: 325544908070d59e7163373bb5f2f91e436024f2 $")
