@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 9f84d56fb0fb4dd817def2c6ed57c1109317d71b $
+// $Id: c9f6e330bae3aa231cd03193abc4a4d5450b4ecf $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -133,10 +133,8 @@ class corpseCollector_t
  */
 static void ActivateMonsters(AActors& mobjs)
 {
-	for (AActors::iterator it = mobjs.begin(); it != mobjs.end(); ++it)
+	for (auto& mo : mobjs)
 	{
-		AActor* mo = *it;
-
 		// Add them health pool now, since the function to do this is
 		// in this TU anyway.
 		P_AddHealthPool(mo);
@@ -155,7 +153,7 @@ static void ActivateMonsters(AActors& mobjs)
 		{
 			char sound[MAX_SNDNAME];
 
-			strcpy(sound, mo->info->seesound);
+			M_StringCopy(sound, mo->info->seesound, MAX_SNDNAME);
 
 			if (sound[strlen(sound) - 1] == '1')
 			{
@@ -214,7 +212,7 @@ class HordeState
 		if (m_state == HS_WANTBOSS)
 		{
 			// Do the boss intro fanfare.
-			SV_BroadcastPrintf("The floor trembles as the boss of the wave arrives.\n");
+			SV_BroadcastPrintFmt("The floor trembles as the boss of the wave arrives.\n");
 			S_NetSound(NULL, CHAN_GAMEINFO, "misc/horde/boss", ATTN_NONE);
 			m_bossTime = ::level.time;
 		}
@@ -253,8 +251,8 @@ class HordeState
 		// Avoid printing wave name on boot and map switch.
 		if (printWave)
 		{
-			SV_BroadcastPrintf("Wave %d: \"%s\"\n", m_wave,
-			                   G_HordeDefine(m_defineID).name.c_str());
+			SV_BroadcastPrintFmt("Wave {}: \"{}\"\n", m_wave,
+			                     G_HordeDefine(m_defineID).name);
 		}
 	}
 
@@ -269,27 +267,28 @@ class HordeState
 		{
 			// Give all ingame players an extra life for beating the wave.
 			PlayersView ingame = PlayerQuery().execute().players;
-			for (PlayersView::iterator it = ingame.begin(); it != ingame.end(); ++it)
+			for (const auto& player : ingame)
 			{
 				// Dead players are reborn with a message.
-				if ((*it)->lives <= 0)
+				if (player->lives <= 0)
 				{
-					(*it)->playerstate = PST_REBORN;
-					SV_BroadcastPrintf("%s gets a new lease on life.\n",
-					                   (*it)->userinfo.netname.c_str());
+					G_ResetLastPlayer();
+					player->playerstate = PST_REBORN;
+					SV_BroadcastPrintFmt("{} gets a new lease on life.\n",
+					                     player->userinfo.netname);
 
 					// Send a res sound directly to this player.
-					S_PlayerSound(*it, NULL, CHAN_INTERFACE, "misc/plraise",
+					S_PlayerSound(player, NULL, CHAN_INTERFACE, "misc/plraise",
 					              ATTN_NONE);
 				}
 				// Give everyone an extra life.
-				if ((*it)->lives < g_lives)
+				if (player->lives < g_lives)
 				{
-					(*it)->lives += 1;
-					MSG_WriteSVC(&(*it)->client.reliablebuf, SVC_PlayerInfo(**it));
+					player->lives += 1;
+					MSG_WriteSVC(&player->client.reliablebuf, SVC_PlayerInfo(*player));
 					MSG_BroadcastSVC(CLBUF_RELIABLE,
-					                 SVC_PlayerMembers(**it, SVC_PM_LIVES),
-					                 (*it)->id);
+					                 SVC_PlayerMembers(*player, SVC_PM_LIVES),
+					                 player->id);
 				}
 			}
 
@@ -298,12 +297,12 @@ class HordeState
 			// players a single life to start with.
 			PlayersView queued = SpecQuery().onlyInQueue().execute();
 			SV_UpdatePlayerQueuePositions(G_CanJoinGameStart, NULL);
-			for (PlayersView::iterator it = queued.begin(); it != queued.end(); ++it)
+			for (const auto& player : queued)
 			{
-				(*it)->lives = 1;
-				MSG_WriteSVC(&(*it)->client.reliablebuf, SVC_PlayerInfo(**it));
+				player->lives = 1;
+				MSG_WriteSVC(&player->client.reliablebuf, SVC_PlayerInfo(*player));
 				MSG_BroadcastSVC(CLBUF_RELIABLE,
-				                 SVC_PlayerMembers(**it, SVC_PM_LIVES), (*it)->id);
+				                 SVC_PlayerMembers(*player, SVC_PM_LIVES), player->id);
 			}
 		#endif
 		}
@@ -347,8 +346,8 @@ class HordeState
 		m_bossRecipe.clear();
 		m_corpses.startWave();
 
-		SV_BroadcastPrintf("Wave %d: \"%s\"\n", m_wave,
-		                   G_HordeDefine(m_defineID).name.c_str());
+		SV_BroadcastPrintFmt("Wave {}: \"{}\"\n", m_wave,
+		                     G_HordeDefine(m_defineID).name);
 	}
 
 	/**
@@ -359,7 +358,7 @@ class HordeState
 	 */
 	bool forceWave(const std::string& name)
 	{
-		int defineID;
+		size_t defineID;
 		if (!P_HordeDefineNamed(defineID, name))
 			return false;
 
@@ -374,8 +373,8 @@ class HordeState
 		m_bossRecipe.clear();
 		m_corpses.startWave();
 
-		SV_BroadcastPrintf("Wave %d: \"%s\"\n", m_wave,
-		                   G_HordeDefine(m_defineID).name.c_str());
+		SV_BroadcastPrintFmt("Wave {}: \"{}\"\n", m_wave,
+		                     G_HordeDefine(m_defineID).name);
 		return true;
 	}
 
@@ -397,6 +396,7 @@ class HordeState
 	/**
 	 * @brief Serialize horde data into POD struct.
 	 */
+	[[nodiscard]]
 	hordeInfo_t serialize() const
 	{
 		hordeInfo_t info;
@@ -600,9 +600,9 @@ void HordeState::tick()
 	if (m_state != HS_WANTBOSS && m_bossRecipe.isValid())
 	{
 		size_t alive = 0;
-		for (AActors::iterator it = m_bosses.begin(); it != m_bosses.end(); ++it)
+		for (auto& boss : m_bosses)
 		{
-			if (*it && (*it)->health > 0)
+			if (boss && boss->health > 0)
 				alive += 1;
 		}
 		if (!alive)
@@ -648,8 +648,8 @@ void HordeState::tick()
 			}
 
 			const int hp = ::mobjinfo[recipe.type].spawnhealth * recipe.count;
-			DPrintf("Spawning %d %s (%d hp) at a %s spawn\n", recipe.count,
-			        ::mobjinfo[recipe.type].name, hp, HordeThingStr(spawn->type));
+			DPrintFmt("Spawning {} {} ({} hp) at a {} spawn\n", recipe.count,
+			          ::mobjinfo[recipe.type].name, hp, HordeThingStr(spawn->type));
 
 			AActors mobjs = P_HordeSpawn(*spawn, recipe);
 			ActivateMonsters(mobjs);
@@ -1012,21 +1012,21 @@ BEGIN_COMMAND(hordeinfo)
 
 	const hordeDefine_t& define = G_HordeDefine(::g_HordeDirector.getDefineID());
 
-	Printf("[Define: %s]\n", define.name.c_str());
-	Printf("Weapons: %s\n", JoinStrings(define.weaponStrings(NULL), " ").c_str());
+	Printf("[Define: %s]\n", define.name);
+	Printf("Weapons: %s\n", JoinStrings(define.weaponStrings(NULL), " "));
 	Printf("Min Group Health: %d\n", define.minGroupHealth);
 	Printf("Max Group Health: %d (Difficulty: %s)\n", define.maxGroupHealth,
 	       define.difficulty(false));
 	Printf("Min Total Health: %d = waveMaxGroup:%d * g_horde_mintotalhp:%s * "
 	       "skillLevel:%0.2f\n",
-	       define.minTotalHealth(), define.maxGroupHealth, ::g_horde_mintotalhp.cstring(),
+	       define.minTotalHealth(), define.maxGroupHealth, ::g_horde_mintotalhp.str(),
 	       skillScaler);
 	Printf("Max Total Health: %d = waveMaxGroup:%d * g_horde_maxtotalhp:%s * "
 	       "skillLevel:%0.2f\n",
-	       define.maxTotalHealth(), define.maxGroupHealth, ::g_horde_maxtotalhp.cstring(),
+	       define.maxTotalHealth(), define.maxGroupHealth, ::g_horde_maxtotalhp.str(),
 	       skillScaler);
 	Printf("Goal Health: %d = waveMaxGroup:%d * g_horde_goalhp:%s * skillLevel:%0.2f\n",
-	       define.goalHealth(), define.maxGroupHealth, ::g_horde_goalhp.cstring(),
+	       define.goalHealth(), define.maxGroupHealth, ::g_horde_goalhp.str(),
 	       skillScaler);
 
 	const char* stateStr = NULL;
