@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: af90d2805224fb09de05de4bc2ad26482054e96a $
+// $Id: 55ce9b6b6e5780354c7bc2ab6a13f3104f1b05ca $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -33,7 +33,7 @@
 #include "m_wdlstats.h"
 #include "p_mapformat.h"
 
-#define FUNC(a) static BOOL a (line_t *ln, AActor *it, int arg0, int arg1, \
+#define FUNC(a) static bool a (line_t *ln, AActor *it, int arg0, int arg1, \
 							   int arg2, int arg3, int arg4)
 
 // Used by the teleporters to know if they were
@@ -42,15 +42,15 @@ int TeleportSide;
 extern bool s_SpecialFromServer;
 
 // Set true if this special was activated from inside a script.
-BOOL InScript;
+bool InScript;
 
 // 9/11/10: Add poly action definitions here, even though they're in p_local...
 // Why are these needed here?  Linux won't compile without these definitions??
 //
-BOOL EV_MovePoly (line_t *line, int polyNum, int speed, angle_t angle, fixed_t dist, BOOL overRide);
-BOOL EV_OpenPolyDoor (line_t *line, int polyNum, int speed, angle_t angle, int delay, int distance, podoortype_t type);
-BOOL EV_RotatePoly (line_t *line, int polyNum, int speed, int byteAngle, int direction, BOOL overRide);
-BOOL EV_DoZDoomCeiling(DCeiling::ECeiling type, line_t* line, byte tag, fixed_t speed,
+bool EV_MovePoly (line_t *line, int polyNum, int speed, angle_t angle, fixed_t dist, bool overRide);
+bool EV_OpenPolyDoor (line_t *line, int polyNum, int speed, angle_t angle, int delay, int distance, podoortype_t type);
+bool EV_RotatePoly (line_t *line, int polyNum, int speed, int byteAngle, int direction, bool overRide);
+bool EV_DoZDoomCeiling(DCeiling::ECeiling type, line_t* line, byte tag, fixed_t speed,
                        fixed_t speed2, fixed_t height, int crush, byte silent, int change,
                        crushmode_e crushmode);
 
@@ -432,7 +432,7 @@ FUNC(LS_NOP)
 
 FUNC(LS_NOTIMP)
 {
-	Printf(PRINT_HIGH, "Line special not implemented yet.");
+	PrintFmt(PRINT_HIGH, "Line special not implemented yet.\n");
 	return false;
 }
 
@@ -950,7 +950,7 @@ FUNC(LS_Generic_Stairs)
 // Generic_Stairs (tag, speed, step, dir/igntxt, reset)
 {
 	DFloor::EStair type = (arg3 & 1) ? DFloor::buildUp : DFloor::buildDown;
-	BOOL res = EV_BuildStairs (arg0, type, ln,
+	bool res = EV_BuildStairs (arg0, type, ln,
 							   arg2 * FRACUNIT, SPEED(arg1), 0, arg4, arg3 & 2, 0);
 
 	if (res && ln && (ln->flags & ML_REPEATSPECIAL) && ln->special == Generic_Stairs)
@@ -1435,8 +1435,8 @@ FUNC(LS_Scroll_Wall)
 {
 	if (arg4)
 	{
-		Printf(PRINT_HIGH,
-		       "Warning: Odamex can only scroll entire sidedefs (special 52)");
+		PrintFmt(PRINT_HIGH,
+		       "Warning: Odamex can only scroll entire sidedefs (special 52)\n");
 	}
 	if (arg0)
 	{
@@ -1458,8 +1458,8 @@ FUNC(LS_Line_SetTextureOffset)
 {
 	if (arg4 & 7)
 	{
-		Printf(PRINT_HIGH,
-		       "Warning: Odamex can only offset entire sidedefs (special 53)");
+		PrintFmt(PRINT_HIGH,
+		       "Warning: Odamex can only offset entire sidedefs (special 53)\n");
 	}
 	if (arg0 && arg3 <= 1)
 	{
@@ -1596,7 +1596,7 @@ FUNC(LS_Teleport)
 // Teleport (tid, tag, nosourcefog)
 {
 	if(!it) return false;
-	BOOL result;
+	bool result;
 
 	if (map_format.getZDoom())
 		// [AM] Use ZDoom-style teleport for Hexen-format maps
@@ -2509,10 +2509,10 @@ FUNC(LS_Line_AlignCeiling)
 // Line_AlignCeiling (lineid, side)
 {
 	int line = P_FindLineFromID (arg0, -1);
-	BOOL ret = 0;
+	bool ret = 0;
 
 	if (line < 0)
-		I_Error ("Sector_AlignCeiling: Lineid %d is undefined", arg0);
+		I_Error("Sector_AlignCeiling: Lineid {} is undefined", arg0);
 	do
 	{
 		ret |= R_AlignFlat (line, !!arg1, 1);
@@ -2524,10 +2524,10 @@ FUNC(LS_Line_AlignFloor)
 // Line_AlignFloor (lineid, side)
 {
 	int line = P_FindLineFromID (arg0, -1);
-	BOOL ret = 0;
+	bool ret = 0;
 
 	if (line < 0)
-		I_Error ("Sector_AlignFloor: Lineid %d is undefined", arg0);
+		I_Error("Sector_AlignFloor: Lineid {} is undefined", arg0);
 	do
 	{
 		ret |= R_AlignFlat (line, !!arg1, 0);
@@ -2542,21 +2542,21 @@ FUNC(LS_ChangeCamera)
 
 	if (!it || !it->player || arg1)
 	{
-		for (Players::iterator itr = players.begin();itr != players.end();++itr)
+		for (auto& player : players)
 		{
-			if (!(itr->ingame()))
+			if (!(player.ingame()))
 				continue;
 
 			if (camera)
 			{
-				itr->camera = camera->ptr();
+				player.camera = camera->ptr();
 				if (arg2)
-					itr->cheats |= CF_REVERTPLEASE;
+					player.cheats |= CF_REVERTPLEASE;
 			}
 			else
 			{
-				itr->camera = itr->mo;
-				itr->cheats &= ~CF_REVERTPLEASE;
+				player.camera = player.mo;
+				player.cheats &= ~CF_REVERTPLEASE;
 			}
 		}
 	}
@@ -2607,15 +2607,15 @@ FUNC(LS_SetPlayerProperty)
 	}
 	else
 	{
-		for (Players::iterator itr = players.begin();itr != players.end();++itr)
+		for (auto& player : players)
 		{
-			if (!(itr->ingame()))
+			if (!(player.ingame()))
 				continue;
 
 			if (arg1)
-				itr->cheats |= mask;
+				player.cheats |= mask;
 			else
-				itr->cheats &= ~mask;
+				player.cheats &= ~mask;
 		}
 	}
 
@@ -2931,7 +2931,7 @@ EXTERN_CVAR (sv_fraglimit)
 EXTERN_CVAR (sv_allowexit)
 EXTERN_CVAR (sv_fragexitswitch)
 
-BOOL CheckIfExitIsGood (AActor *self)
+bool CheckIfExitIsGood (AActor *self)
 {
 	if (self == NULL || !serverside)
 		return false;
@@ -2968,12 +2968,12 @@ BOOL CheckIfExitIsGood (AActor *self)
 			tstr = fmt::sprintf("%02d:%02d.%02d", tspan.minutes, tspan.seconds, tspan.csecs);
 		}
 
-		SV_BroadcastPrintf("%s exited the level in %s.\n",
-		                   self->player->userinfo.netname.c_str(), tstr.c_str());
+		SV_BroadcastPrintFmt("{} exited the level in {}.\n",
+		                     self->player->userinfo.netname, tstr);
 	}
 
 	M_CommitWDLLog();
 	return true;
 }
 
-VERSION_CONTROL (p_lnspec_cpp, "$Id: af90d2805224fb09de05de4bc2ad26482054e96a $")
+VERSION_CONTROL (p_lnspec_cpp, "$Id: 55ce9b6b6e5780354c7bc2ab6a13f3104f1b05ca $")
