@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 9d49a43ff0e1926d20286121dbcd358b2eb6b539 $
+// $Id: 25ddb3e63ff19f8300b9eb3c09329ddda6752682 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -57,6 +57,7 @@ EXTERN_CVAR(sv_infiniteammo)
 EXTERN_CVAR(sv_freelook)
 EXTERN_CVAR(sv_allowpwo)
 EXTERN_CVAR(co_fineautoaim)
+EXTERN_CVAR(co_zdoomammo)
 EXTERN_CVAR(cl_centerbobonfire)
 
 const char *weaponnames[] =
@@ -264,8 +265,11 @@ bool P_EnoughAmmo(player_t *player, weapontype_t weapon, bool switching = false)
 	ammotype_t		ammotype = weaponinfo[weapon].ammotype;
 	int				count = 1;	// default amount of ammo for most weapons
 
-	// [SL] Fix for when DeHackEd doesn't patch minammo
-	count = MAX(weaponinfo[weapon].minammo, weaponinfo[weapon].ammouse);
+	if (co_zdoomammo || deh.ZDAmmo)
+		// [SL] Fix for when DeHackEd doesn't patch minammo
+		count = MAX(weaponinfo[weapon].minammo, weaponinfo[weapon].ammouse);
+	else
+		count = weaponinfo[weapon].ammopershot;
 
 	// Vanilla Doom requires > 40 cells to switch to BFG and > 2 shells to
 	// switch to SSG when current weapon is out of ammo due to a bug.
@@ -417,7 +421,7 @@ bool P_CheckSwitchWeapon(player_t *player, weapontype_t weapon)
 // Returns true if there is enough ammo to shoot.
 // If not, selects the next weapon to use.
 //
-BOOL P_CheckAmmo (player_t *player)
+bool P_CheckAmmo (player_t *player)
 {
 	if (P_EnoughAmmo(player, player->readyweapon))
 		return true;
@@ -434,7 +438,7 @@ BOOL P_CheckAmmo (player_t *player)
 // example, it is possible to make a weapon that decreases the max
 // number of ammo for another weapon.  Emulate this.
 
-static void DecreaseAmmo(player_t *player)
+static void DecreaseAmmo(player_t *player, int amount = 1)
 {
 	// [SL] 2012-06-17 - Don't decrease ammo for players we are viewing
 	// The server will send the correct ammo
@@ -444,7 +448,11 @@ static void DecreaseAmmo(player_t *player)
 	if (!sv_infiniteammo)
 	{
 		ammotype_t ammonum = weaponinfo[player->readyweapon].ammotype;
-		int amount = weaponinfo[player->readyweapon].ammouse;
+		if (co_zdoomammo || deh.ZDAmmo)
+			amount = weaponinfo[player->readyweapon].ammouse;
+		else if (weaponinfo[player->readyweapon].internalflags & WIF_ENABLEAPS)
+			amount = weaponinfo[player->readyweapon].ammopershot;
+
 
 		if (ammonum < NUMAMMO)
 			player->ammo[ammonum] -= amount;
@@ -776,7 +784,7 @@ void A_FireBFG(AActor* mo)
 	angle_t storedpitch = player->mo->pitch;
 	int storedaimdist = player->userinfo.aimdist;
 
-	DecreaseAmmo(player);
+	DecreaseAmmo(player, deh.BFGCells);
 
 	player->mo->pitch = 0;
 	player->userinfo.aimdist = 81920000;
@@ -896,7 +904,7 @@ void A_CheckAmmo(AActor* mo)
 	if (psp->state->args[1] != 0)
 		amount = psp->state->args[1];
 	else
-		amount = weaponinfo[player->readyweapon].ammouse;
+		amount = weaponinfo[player->readyweapon].ammopershot;
 
 	if (player->ammo[type] < amount)
 		P_SetPspritePtr(player, psp, (statenum_t)psp->state->args[0]);
@@ -929,7 +937,7 @@ void A_ConsumeAmmo(AActor* mo)
 	if (psp->state->args[0] != 0)
 		amount = psp->state->args[0];
 	else
-		amount = weaponinfo[player->readyweapon].ammouse;
+		amount = weaponinfo[player->readyweapon].ammopershot;
 
 	// subtract ammo, but don't let it get below zero
 	if (player->ammo[type] >= amount)
@@ -1045,6 +1053,8 @@ void A_WeaponBulletAttack(AActor* mo)
 	damagebase = psp->state->args[3];
 	damagemod = psp->state->args[4];
 
+	Unlag::getInstance().reconcile(player->id);
+
 	bool refire = player->refire ? true : false;
 
 	angle = 0;
@@ -1063,6 +1073,8 @@ void A_WeaponBulletAttack(AActor* mo)
 
 		P_LineAttack(player->mo, bangle, MISSILERANGE, slope, damage);
 	}
+
+	Unlag::getInstance().restore(player->id);
 }
 
 //
@@ -1094,7 +1106,7 @@ void A_WeaponMeleeAttack(AActor* mo)
 
 	if (hitsound >= static_cast<int>(ARRAY_LENGTH(SoundMap)))
 	{
-		DPrintf("Warning: Weapon Melee Hitsound ID is beyond the array of the Sound Map!\n");
+		DPrintFmt("Warning: Weapon Melee Hitsound ID is beyond the array of the Sound Map!\n");
 		hitsound = 0;
 	}
 
@@ -1105,6 +1117,8 @@ void A_WeaponMeleeAttack(AActor* mo)
 	if (player->powers[pw_strength])
 		damage = (damage * zerkfactor) >> FRACBITS;
 
+	Unlag::getInstance().reconcile(player->id);
+
 	// slight randomization; weird vanillaism here. :P
 	angle = player->mo->angle;
 
@@ -1119,6 +1133,8 @@ void A_WeaponMeleeAttack(AActor* mo)
 	// attack, dammit!
 	P_LineAttack(player->mo, angle, range, slope, damage);
 
+	Unlag::getInstance().restore(player->id);
+
 	// missed? ah, welp.
 	if (!linetarget)
 		return;
@@ -1150,7 +1166,7 @@ void A_WeaponSound(AActor *mo)
 
 	if (sndmap >= static_cast<int>(ARRAY_LENGTH(SoundMap)))
 	{
-		DPrintf("Warning: Weapon Sound ID is beyond the array of the Sound Map!\n");
+		DPrintFmt("Warning: Weapon Sound ID is beyond the array of the Sound Map!\n");
 		sndmap = 0;
 	}
 
@@ -1199,7 +1215,7 @@ void A_FireRailgun(AActor* mo)
 	int damage;
 
     player_t *player = mo->player;
-	DecreaseAmmo(player);
+	DecreaseAmmo(player, 10);
 
 	P_SetPsprite (player,
 				  ps_flash,
@@ -1409,7 +1425,7 @@ void A_FireShotgun2(AActor* mo)
 	A_FireSound (player, "weapons/sshotf");
 	P_SetMobjState (player->mo, S_PLAY_ATK2);
 
-	DecreaseAmmo(player);
+	DecreaseAmmo(player, 2);
 
 	P_SetPsprite (player,
 				  ps_flash,
@@ -1633,4 +1649,4 @@ FArchive &operator>> (FArchive &arc, pspdef_t &def)
 	return arc >> def.state >> def.tics >> def.sx >> def.sy;
 }
 
-VERSION_CONTROL (p_pspr_cpp, "$Id: 9d49a43ff0e1926d20286121dbcd358b2eb6b539 $")
+VERSION_CONTROL (p_pspr_cpp, "$Id: 25ddb3e63ff19f8300b9eb3c09329ddda6752682 $")
