@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 6d691a63ad0db0198df59af74885e1055e7c5518 $
+// $Id: ec18dbd8dd5bb289802d1d2a77b63e5a3cba83e2 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -29,6 +29,7 @@
 #include <math.h>
 #include <set>
 #include <zlib.h>
+#include <nonstd/scope.hpp>
 
 #include "m_alloc.h"
 #include "m_vectors.h"
@@ -51,6 +52,7 @@
 #include "p_setup.h"
 #include "p_hordespawn.h"
 #include "p_mapformat.h"
+#include "r_sky.h"
 
 void SV_PreservePlayer(player_t &player);
 void P_SpawnMapThing (mapthing2_t *mthing, int position);
@@ -134,7 +136,7 @@ AActor**		blocklinks;		// for thing chains
 //	used as a PVS lookup as well.
 //
 byte*			rejectmatrix;
-BOOL			rejectempty;
+bool			rejectempty;
 
 
 // Maintain single and multi player starting spots.
@@ -184,7 +186,7 @@ void P_LoadSegsHelper(int side, short angle, int linedef, seg_t *li)
 	li->angle = (angle)<<16;
 
 	if(linedef < 0 || linedef >= numlines)
-		I_Error("P_LoadSegsHelper: invalid linedef %d", linedef);
+		I_Error("P_LoadSegsHelper: invalid linedef {}", linedef);
 
 	ldef = &lines[linedef];
 	li->linedef = ldef;
@@ -252,14 +254,14 @@ void P_LoadSegs (int lump, bool isdeepbsp = false)
 			v = LELONG(ml->v1);
 
 			if(v >= numvertexes)
-				I_Error("P_LoadSegs: invalid vertex %d", v);
+				I_Error("P_LoadSegs: invalid vertex {}", v);
 			else
 				li->v1 = &vertexes[v];
 
 			v = LELONG(ml->v2);
 
 			if(v >= numvertexes)
-				I_Error("P_LoadSegs: invalid vertex %d", v);
+				I_Error("P_LoadSegs: invalid vertex {}", v);
 			else
 				li->v2 = &vertexes[v];
 
@@ -273,14 +275,14 @@ void P_LoadSegs (int lump, bool isdeepbsp = false)
 			v = LESHORT(ml->v1);
 
 			if(v >= numvertexes)
-				I_Error("P_LoadSegs: invalid vertex %d", v);
+				I_Error("P_LoadSegs: invalid vertex {}", v);
 			else
 				li->v1 = &vertexes[v];
 
 			v = LESHORT(ml->v2);
 
 			if(v >= numvertexes)
-				I_Error("P_LoadSegs: invalid vertex %d", v);
+				I_Error("P_LoadSegs: invalid vertex {}", v);
 			else
 				li->v2 = &vertexes[v];
 
@@ -416,7 +418,7 @@ void P_LoadSectors (int lump)
 		bool fog = level.outsidefog_color[0] != 0xFF || level.outsidefog_color[1] != 0 ||
 					level.outsidefog_color[2] != 0 || level.outsidefog_color[3] != 0;
 
-		if (fog && ss->ceilingpic == skyflatnum)
+		if (fog && R_IsSkyFlat(ss->ceilingpic))
 			ss->colormap = GetSpecialLights(255, 255, 255,
 									level.outsidefog_color[1], level.outsidefog_color[2], level.outsidefog_color[3]);
 		else
@@ -581,8 +583,8 @@ bool P_LoadXNOD(int lump)
 		if (err != Z_STREAM_END)
 			I_Error("P_LoadXNOD: Error during ZDBSP nodes decompression!");
 
-		fprintf(stderr, "P_LoadXNOD: ZDBSP nodes compression ratio %.3f\n",
-				(float)zstream->total_out/zstream->total_in);
+		fmt::print(stderr, "P_LoadXNOD: ZDBSP nodes compression ratio {:.3f}\n",
+		           (float)zstream->total_out/zstream->total_in);
 
 		len = zstream->total_out;
 
@@ -726,22 +728,20 @@ enum nodetype_t {
 
 nodetype_t P_CheckNodeType(int lump) {
 	byte *data = (byte *) W_CacheLumpNum(lump, PU_STATIC);
+	nonstd::make_scope_exit([&]{ Z_ChangeTag(data, PU_CACHE); });
 
 	if (memcmp(data, "xNd4\0\0\0\0", 8) == 0)
 	{
-		Z_Free(data);
 		return NT_DEEP;
 	}
 
 	if (memcmp(data, "XNOD", 4) == 0)
 	{
-		Z_Free(data);
 		return NT_XNOD;
 	}
 
 	if (memcmp(data, "ZNOD", 4) == 0)
 	{
-		Z_Free(data);
 		return NT_ZNOD;
 	}
 
@@ -1087,14 +1087,14 @@ void P_LoadLineDefs (const int lump)
 		unsigned short v = LESHORT(mld->v1);
 
 		if(v >= numvertexes)
-			I_Error("P_LoadLineDefs: invalid vertex %d", v);
+			I_Error("P_LoadLineDefs: invalid vertex {}", v);
 		else
 			ld->v1 = &vertexes[v];
 
 		v = LESHORT(mld->v2);
 
 		if(v >= numvertexes)
-			I_Error("P_LoadLineDefs: invalid vertex %d", v);
+			I_Error("P_LoadLineDefs: invalid vertex {}", v);
 		else
 			ld->v2 = &vertexes[v];
 
@@ -1142,14 +1142,14 @@ void P_LoadLineDefs2 (int lump)
 		unsigned short v = LESHORT(mld->v1);
 
 		if(v >= numvertexes)
-			I_Error("P_LoadLineDefs2: invalid vertex %d", v);
+			I_Error("P_LoadLineDefs2: invalid vertex {}", v);
 		else
 			ld->v1 = &vertexes[v];
 
 		v = LESHORT(mld->v2);
 
 		if(v >= numvertexes)
-			I_Error("P_LoadLineDefs2: invalid vertex %d", v);
+			I_Error("P_LoadLineDefs2: invalid vertex {}", v);
 		else
 			ld->v2 = &vertexes[v];
 
@@ -1695,13 +1695,13 @@ void P_GenerateUniqueMapFingerPrint(int maplumpnum)
 	typedef std::vector<byte> LevelLumps;
 	LevelLumps levellumps;
 
-	const byte* thingbytes = const_cast<const byte*>((const byte*)W_CacheLumpNum(maplumpnum+ML_THINGS, PU_STATIC));
-	const byte* lindefbytes = const_cast<const byte*>((const byte*)W_CacheLumpNum(maplumpnum+ML_LINEDEFS, PU_STATIC));
-	const byte* sidedefbytes = const_cast<const byte*>((const byte*)W_CacheLumpNum(maplumpnum+ML_SIDEDEFS, PU_STATIC));
-	const byte* vertexbytes = const_cast<const byte*>((const byte*)W_CacheLumpNum(maplumpnum+ML_VERTEXES, PU_STATIC));
-	const byte* segsbytes = const_cast<const byte*>((const byte*)W_CacheLumpNum(maplumpnum+ML_SEGS, PU_STATIC));
-	const byte* ssectorsbytes = const_cast<const byte*>((const byte*)W_CacheLumpNum(maplumpnum+ML_SSECTORS, PU_STATIC));
-	const byte* sectorsbytes = const_cast<const byte*>((const byte*)W_CacheLumpNum(maplumpnum+ML_SECTORS, PU_STATIC));
+	const byte* thingbytes = static_cast<const byte*>(W_CacheLumpNum(maplumpnum+ML_THINGS, PU_STATIC));
+	const byte* lindefbytes = static_cast<const byte*>(W_CacheLumpNum(maplumpnum+ML_LINEDEFS, PU_STATIC));
+	const byte* sidedefbytes = static_cast<const byte*>(W_CacheLumpNum(maplumpnum+ML_SIDEDEFS, PU_STATIC));
+	const byte* vertexbytes = static_cast<const byte*>(W_CacheLumpNum(maplumpnum+ML_VERTEXES, PU_STATIC));
+	const byte* segsbytes = static_cast<const byte*>(W_CacheLumpNum(maplumpnum+ML_SEGS, PU_STATIC));
+	const byte* ssectorsbytes = static_cast<const byte*>(W_CacheLumpNum(maplumpnum+ML_SSECTORS, PU_STATIC));
+	const byte* sectorsbytes = static_cast<const byte*>(W_CacheLumpNum(maplumpnum+ML_SECTORS, PU_STATIC));
 
 	levellumps.insert(levellumps.end(), W_LumpLength(maplumpnum+ML_THINGS), *thingbytes);
 	levellumps.insert(levellumps.end(), W_LumpLength(maplumpnum+ML_LINEDEFS), *lindefbytes);
@@ -1740,7 +1740,7 @@ void P_GroupLines (void)
 	for (i = 0; i < numsubsectors; i++)
 	{
 		if (subsectors[i].firstline >= (unsigned int)numsegs)
-			I_Error("subsector[%d].firstline exceeds numsegs (%u)", i, numsegs);
+			I_Error("subsector[{}].firstline exceeds numsegs (%u)", i, numsegs);
 		subsectors[i].sector = segs[subsectors[i].firstline].sidedef->sector;
 	}
 
@@ -1786,7 +1786,7 @@ void P_GroupLines (void)
 			}
 		}
 		if (linebuffer - sector->lines != sector->linecount)
-			I_Error ("P_GroupLines: miscounted");
+			I_Error("P_GroupLines: miscounted");
 
 		// set the soundorg to the middle of the bounding box
 		sector->soundorg[0] = (bbox.Right()+bbox.Left())/2;
@@ -1955,9 +1955,9 @@ void P_SetupLevel (const char *lumpname, int position)
 
 	if (!savegamerestore)
 	{
-		for (Players::iterator it = players.begin();it != players.end();++it)
+		for (auto& player : players)
 		{
-			it->killcount = it->secretcount = it->itemcount = 0;
+			player.killcount = player.secretcount = player.itemcount = 0;
 		}
 	}
 
@@ -2059,7 +2059,7 @@ void P_SetupLevel (const char *lumpname, int position)
 		// calling P_CheckSight
 		if (W_LumpLength(lumpnum + ML_REJECT) < ((unsigned int)ceil((float)(numsectors * numsectors / 8))))
 		{
-			DPrintf("Reject matrix is not valid and will be ignored.\n");
+			DPrintFmt("Reject matrix is not valid and will be ignored.\n");
 			rejectempty = true;
 		}
 	}
@@ -2087,15 +2087,15 @@ void P_SetupLevel (const char *lumpname, int position)
 
     if (serverside)
     {
-		for (Players::iterator it = players.begin();it != players.end();++it)
+		for (auto& player : players)
 		{
-			SV_PreservePlayer(*it);
+			SV_PreservePlayer(player);
 
-			if (it->ingame())
+			if (player.ingame())
 			{
 				// if deathmatch, randomly spawn the active players
 				// denis - this function checks for deathmatch internally
-				G_DeathMatchSpawnPlayer(*it);
+				G_DeathMatchSpawnPlayer(player);
 			}
 		}
     }
@@ -2276,4 +2276,4 @@ static void P_SetupSlopes()
 }
 
 
-VERSION_CONTROL (p_setup_cpp, "$Id: 6d691a63ad0db0198df59af74885e1055e7c5518 $")
+VERSION_CONTROL (p_setup_cpp, "$Id: ec18dbd8dd5bb289802d1d2a77b63e5a3cba83e2 $")
