@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 72cf05c0d3a3ba0fdc051c7ce45f078804069cee $
+// $Id: 198bb98e8834b439899453a72dc5514885eecb97 $
 //
 // Copyright (C) 2000-2006 by Sergey Makovkin (CSDoom .62).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -57,7 +57,7 @@ public:
 	Snapshot(int time = -1);
 	virtual ~Snapshot() {};
 
-	bool operator==(const Snapshot &other) const;
+	[[nodiscard]] bool operator==(const Snapshot &other) const;
 
 	bool isValid() const { return mValid; }
 	bool isAuthoritative() const { return mAuthoritative; }
@@ -98,7 +98,7 @@ public:
 	ActorSnapshot(int time, const AActor *mo);
 	~ActorSnapshot() override {};
 
-	bool operator==(const ActorSnapshot &other) const;
+	[[nodiscard]] bool operator==(const ActorSnapshot &other) const;
 
 	void merge(const ActorSnapshot& other);
 
@@ -283,7 +283,7 @@ public:
 	PlayerSnapshot(int time, player_t *player);
 	~PlayerSnapshot() override {};
 
-	bool operator==(const PlayerSnapshot &other) const;
+	[[nodiscard]] bool operator==(const PlayerSnapshot &other) const;
 
 	void merge(const PlayerSnapshot& other);
 
