@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: d76151e854adb9e8958c8f18ee07a353926f9398 $
+// $Id: 414a6a488ba87fe57dd1d5140b64621379724581 $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -153,9 +153,9 @@ void Unlag::moveSector(sector_t *sector, fixed_t ceilingheight,
 
 void Unlag::reconcilePlayerPositions(byte shooter_id, size_t ticsago)
 {
-	for (size_t i=0; i<player_history.size(); i++)
+	for (auto& record : player_history)
 	{
-		player_t *player = player_history[i].player;
+		player_t *player = record.player;
 
 		// skip over the player shooting and any spectators
 		if (player->id == shooter_id || player->spectator || !player->mo)
@@ -167,27 +167,27 @@ void Unlag::reconcilePlayerPositions(byte shooter_id, size_t ticsago)
 		{
 			// record the player's current position, which hasn't yet
 			// been saved to the history arrays
-			player_history[i].backup_x = player->mo->x;
-			player_history[i].backup_y = player->mo->y;
-			player_history[i].backup_z = player->mo->z;
+			record.backup_x = player->mo->x;
+			record.backup_y = player->mo->y;
+			record.backup_z = player->mo->z;
 
   			size_t cur = (gametic - ticsago) % Unlag::MAX_HISTORY_TICS;
 
-			dest_x = player_history[i].history_x[cur];
-			dest_y = player_history[i].history_y[cur];
-			dest_z = player_history[i].history_z[cur];
+			dest_x = record.history_x[cur];
+			dest_y = record.history_y[cur];
+			dest_z = record.history_z[cur];
 
-			player_history[i].offset_x = player_history[i].backup_x - dest_x;
-			player_history[i].offset_y = player_history[i].backup_y - dest_y;
-			player_history[i].offset_z = player_history[i].backup_z - dest_z;
+			record.offset_x = record.backup_x - dest_x;
+			record.offset_y = record.backup_y - dest_y;
+			record.offset_z = record.backup_z - dest_z;
 
-			if (player_history[i].history_size < ticsago)
+			if (record.history_size < ticsago)
 			{
 				// make the player temporarily unshootable since this player
 				// was not alive when the shot was fired.  Kind of a hack.
-				player_history[i].backup_flags = player->mo->flags;
+				record.backup_flags = player->mo->flags;
 				player->mo->flags &= ~(MF_SHOOTABLE | MF_SOLID);
-				player_history[i].changed_flags = true;
+				record.changed_flags = true;
 			}
 
 			#ifdef _UNLAG_DEBUG_
@@ -200,15 +200,15 @@ void Unlag::reconcilePlayerPositions(byte shooter_id, size_t ticsago)
 		}
 		else
 		{   // we're moving the player back to proper position
-			dest_x = player_history[i].backup_x;
-			dest_y = player_history[i].backup_y;
-			dest_z = player_history[i].backup_z;
+			dest_x = record.backup_x;
+			dest_y = record.backup_y;
+			dest_z = record.backup_z;
 
 			// restore a player's shootability if we removed it previously
-			if (player_history[i].changed_flags)
+			if (record.changed_flags)
 			{
-				player->mo->flags = player_history[i].backup_flags;
-				player_history[i].changed_flags = false;
+				player->mo->flags = record.backup_flags;
+				record.changed_flags = false;
 			}
 		}
 
@@ -230,27 +230,27 @@ void Unlag::reconcilePlayerPositions(byte shooter_id, size_t ticsago)
 
 void Unlag::reconcileSectorPositions(size_t ticsago)
 {
-	for (size_t i=0; i<sector_history.size(); i++)
+	for (auto& record : sector_history)
 	{
-		sector_t *sector = sector_history[i].sector;
+		sector_t *sector = record.sector;
 
 		fixed_t dest_ceilingheight, dest_floorheight;
 		if (!reconciled)
 		{
 			// record the player's current position, which hasn't yet
 			// been saved to the history arrays
-			sector_history[i].backup_ceilingheight = P_CeilingHeight(sector);
-			sector_history[i].backup_floorheight = P_FloorHeight(sector);
+			record.backup_ceilingheight = P_CeilingHeight(sector);
+			record.backup_floorheight = P_FloorHeight(sector);
 
-			size_t cur = (sector_history[i].history_size - 1 - ticsago)
+			size_t cur = (record.history_size - 1 - ticsago)
 						  % Unlag::MAX_HISTORY_TICS;
-			dest_ceilingheight = sector_history[i].history_ceilingheight[cur];
-			dest_floorheight = sector_history[i].history_floorheight[cur];
+			dest_ceilingheight = record.history_ceilingheight[cur];
+			dest_floorheight = record.history_floorheight[cur];
 		}
 		else	// restore to original positions
 		{
-			dest_ceilingheight = sector_history[i].backup_ceilingheight;
-			dest_floorheight = sector_history[i].backup_floorheight;
+			dest_ceilingheight = record.backup_ceilingheight;
+			dest_floorheight = record.backup_floorheight;
 		}
 		moveSector(sector, dest_ceilingheight, dest_floorheight);
 	}
@@ -284,22 +284,22 @@ void Unlag::recordPlayerPositions()
 	if (!Unlag::enabled())
 		return;
 
-	for (size_t i=0; i<player_history.size(); i++)
+	for (auto& record : player_history)
 	{
-		player_t *player = player_history[i].player;
+		player_t *player = record.player;
 
 		if (player->playerstate == PST_LIVE &&
 			!player->spectator && player->mo)
 		{
-			player_history[i].history_size++;
+			record.history_size++;
 
 			size_t cur = gametic % Unlag::MAX_HISTORY_TICS;
-			player_history[i].history_x[cur] = player->mo->x;
-			player_history[i].history_y[cur] = player->mo->y;
-			player_history[i].history_z[cur] = player->mo->z;
+			record.history_x[cur] = player->mo->x;
+			record.history_y[cur] = player->mo->y;
+			record.history_z[cur] = player->mo->z;
 
 			#ifdef _UNLAG_DEBUG_
-			DPrintf("Unlag (%03d): recording player %d position (%d, %d)\n",
+			DPrintFmt("Unlag ({:03d}): recording player {} position ({}, {})\n",
 					gametic & 0xFF, player->id,
 					player->mo->x >> FRACBITS,
 					player->mo->y >> FRACBITS,
@@ -308,7 +308,7 @@ void Unlag::recordPlayerPositions()
 		}
 		else
 		{   // reset history for dead, spectating, etc players
-			player_history[i].history_size = 0;
+			record.history_size = 0;
 		}
 	}
 }
@@ -325,14 +325,14 @@ void Unlag::recordSectorPositions()
 	if (!Unlag::enabled())
 		return;
 
-	for (size_t i=0; i<sector_history.size(); i++)
+	for (auto& record : sector_history)
 	{
-		sector_t *sector = sector_history[i].sector;
+		sector_t *sector = record.sector;
 
-		size_t cur = sector_history[i].history_size++
+		size_t cur = record.history_size++
 					 % Unlag::MAX_HISTORY_TICS;
-		sector_history[i].history_ceilingheight[cur] = P_CeilingHeight(sector);
-		sector_history[i].history_floorheight[cur] = P_FloorHeight(sector);
+		record.history_ceilingheight[cur] = P_CeilingHeight(sector);
+		record.history_floorheight[cur] = P_FloorHeight(sector);
 	}
 }
 
@@ -420,10 +420,10 @@ void Unlag::registerSector(sector_t *sector)
 		return;
 
 	// Check if this sector already is in sector_history
-	for (size_t i=0; i<sector_history.size(); i++)
+	for (const auto& record : sector_history)
 	{
 		// note: comparing the pointers to the sector_t objects
-		if (sector_history[i].sector == sector)
+		if (record.sector == sector)
 			return;
 	}
 
@@ -474,7 +474,7 @@ void Unlag::reconcile(byte shooter_id)
 	size_t lag = player_history[player_index].current_lag;
 
 	#ifdef _UNLAG_DEBUG_
-	DPrintf("Unlag (%03d): moving players to their positions at gametic %d (%d tics ago)\n",
+	DPrintFmt("Unlag ({:03d}): moving players to their positions at gametic {} ({} tics ago)\n",
 			gametic & 0xFF, (gametic - lag) & 0xFF, lag);
 
 	// remove any other debugging player markers
@@ -496,7 +496,7 @@ void Unlag::reconcile(byte shooter_id)
 	}
 
 	if (lag > Unlag::MAX_HISTORY_TICS)
-		DPrintf("Unlag (%03d): player %d has too great of lag (%d tics)\n",
+		DPrintFmt("Unlag ({:03d}): player {} has too great of lag ({} tics)\n",
 				gametic & 0xFF, shooter_id, lag);
 	#endif	// _UNLAG_DEBUG_
 
@@ -560,7 +560,7 @@ void Unlag::setRoundtripDelay(byte player_id, byte svgametic)
 	player_history[player_index].current_lag = MIN(delay, maxdelay);
 
 	#ifdef _UNLAG_DEBUG_
-	DPrintf("Unlag (%03d): received gametic %d from player %d, lag = %d\n",
+	DPrintFmt("Unlag ({:03d}): received gametic {} from player {}, lag = {}\n",
 					gametic & 0xFF, svgametic, player_id, delay);
 	#endif	// _UNLAG_DEBUG
 }
@@ -630,20 +630,20 @@ void Unlag::debugReconciliation(byte shooter_id)
 {
 	player_t *shooter = &(idplayer(shooter_id));
 
-	for (size_t i = 0; i < player_history.size(); i++)
+	for (auto& record : player_history)
 	{
-		if (player_history[i].player->id == shooter_id)
+		if (record.player->id == shooter_id)
 			continue;
 
 		for (size_t n = 0; n < MAX_HISTORY_TICS; n++)
 		{
-			if (n > player_history[i].history_size)
+			if (n > record.history_size)
 				break;
 
 			size_t cur = (gametic - n) % Unlag::MAX_HISTORY_TICS;
 
-			fixed_t x = player_history[i].history_x[cur];
-			fixed_t y = player_history[i].history_y[cur];
+			fixed_t x = record.history_x[cur];
+			fixed_t y = record.history_y[cur];
 
 			angle_t angle = P_PointToAngle(shooter->mo->x,	shooter->mo->y, x, y);
 			angle_t deltaangle = 	angle - shooter->mo->angle < ANG180 ?
@@ -652,9 +652,29 @@ void Unlag::debugReconciliation(byte shooter_id)
 
 			if (deltaangle < 3 * FRACUNIT)
 			{
-				DPrintf("Unlag (%03d): would have hit player %d at gametic %d (%" "zu" " tics ago)\n",
-						gametic & 0xFF, player_history[i].player->id, (gametic - static_cast<int>(n)) & 0xFF, n);
+				DPrintFmt("Unlag ({:03d}): would have hit player {} at gametic {} ({} tics ago)\n",
+						gametic & 0xFF, record.player->id, (gametic - static_cast<int>(n)) & 0xFF, n);
 			}
 		}
 	}
 }
+
+//
+// Unlag::clearPlayerHistory
+//
+// If the player has died, clear their previous positions
+//
+void Unlag::clearPlayerHistory(byte player_id)
+{
+	if (!Unlag::enabled())
+		return;
+
+	size_t cur = player_id_map[player_id];
+
+	if (cur >= player_history.size())
+		return;
+
+	PlayerHistoryRecord& record = player_history[cur];
+
+	record.history_size = 0;
+}
