@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: d03fc2a6afebee0d74a1fb4858c62749416dfa12 $
+// $Id: 9f0ec6ae3e4d1a11f6b873219fee4e79b0dd01c4 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -75,11 +75,11 @@ player_t &idplayer(byte id)
 	// Put a cached lookup mechanism in here.
 
 	// full search
-	for (Players::iterator it = players.begin();it != players.end();++it)
+	for (auto& player : players)
 	{
 		// Add to the cache while we search
-		if (it->id == id)
-			return *it;
+		if (player.id == id)
+			return player;
 	}
 
 	return nullplayer;
@@ -93,16 +93,16 @@ player_t &idplayer(byte id)
  */
 player_t &nameplayer(const std::string &netname)
 {
-	for (Players::iterator it = players.begin();it != players.end();++it)
+	for (auto& player : players)
 	{
-		if (iequals(netname, it->userinfo.netname))
-			return *it;
+		if (iequals(netname, player.userinfo.netname))
+			return player;
 	}
 
 	return nullplayer;
 }
 
-bool validplayer(player_t &ref)
+bool validplayer(const player_t &ref)
 {
 	if (&ref == &nullplayer)
 		return false;
@@ -191,33 +191,33 @@ PlayerResults PlayerQuery::execute()
 	PlayerResults results;
 
 	// Construct a base result set from all ingame players, possibly filtered.
-	for (Players::iterator it = ::players.begin(); it != players.end(); ++it)
+	for (auto& player : ::players)
 	{
-		if (!it->ingame() || it->spectator)
+		if (!player.ingame() || player.spectator)
 			continue;
 
 		results.total += 1;
-		if (it->userinfo.team != TEAM_NONE)
+		if (player.userinfo.team != TEAM_NONE)
 		{
-			results.teamTotal[it->userinfo.team] += 1;
+			results.teamTotal[player.userinfo.team] += 1;
 		}
 
-		if (m_ready && !it->ready)
+		if (m_ready && !player.ready)
 			continue;
 
-		if (m_health && it->health <= 0)
+		if (m_health && player.health <= 0)
 			continue;
 
-		if (m_lives && it->lives <= 0)
+		if (m_lives && player.lives <= 0)
 			continue;
 
-		if (m_notLives && it->lives > 0)
+		if (m_notLives && player.lives > 0)
 			continue;
 
-		if (m_team != TEAM_NONE && it->userinfo.team != m_team)
+		if (m_team != TEAM_NONE && player.userinfo.team != m_team)
 			continue;
 
-		results.players.push_back(&*it);
+		results.players.push_back(&player);
 	}
 
 	// We have no filtered players, we have our totals, there is no more
@@ -301,11 +301,10 @@ PlayerResults PlayerQuery::execute()
 	}
 
 	// Get the final totals.
-	for (PlayersView::iterator it = results.players.begin(); it != results.players.end();
-	     ++it)
+	for (const auto& player : results.players)
 	{
 		results.count += 1;
-		results.teamCount[(*it)->userinfo.team] += 1;
+		results.teamCount[player->userinfo.team] += 1;
 	}
 
 	return results;
@@ -320,15 +319,15 @@ PlayersView SpecQuery::execute()
 {
 	PlayersView rvo;
 
-	for (Players::iterator it = ::players.begin(); it != ::players.end(); ++it)
+	for (auto& player : ::players)
 	{
-		if (!it->ingame() || !it->spectator)
+		if (!player.ingame() || !player.spectator)
 			continue;
 
-		if (m_onlyInQueue && it->QueuePosition == 0)
+		if (m_onlyInQueue && player.QueuePosition == 0)
 			continue;
 
-		rvo.push_back(&*it);
+		rvo.push_back(&player);
 	}
 
 	return rvo;
@@ -802,22 +801,9 @@ void P_DeathThink (player_t *player)
 			player->playerstate = PST_REBORN;
 		}
 	}
-
-	if (clientside)
-	{
-		// [AM] If the player runs out of lives in an LMS gamemode, having
-		//      them spectate another player after a beat is expected.
-		if (::g_lives && player->lives < 1 && &consoleplayer() == &displayplayer() &&
-		    level.time >= player->death_time + (TICRATE * 2))
-		{
-			// CL_SpyCycle is located in cl and templated, so we use this
-			// instead.
-			AddCommandString("spynext");
-		}
-	}
 }
 
-bool P_AreTeammates(player_t &a, player_t &b)
+bool P_AreTeammates(const player_t &a, const player_t &b)
 {
 	// not your own teammate (at least for friendly fire, etc)
 	if (a.id == b.id)
@@ -899,6 +885,24 @@ void P_SetPlayerInvulnBleed(player_t* player, int powers[NUMPOWERS])
 	}
 }
 
+void P_SwitchSpyOnNoLives(player_t* player)
+{
+	if (clientside)
+	{
+		// [AM] If the player runs out of lives in an LMS gamemode, having
+		//      them spectate another player after a beat is expected.
+		if (::g_lives && player->lives < 1 &&
+		    player->id == displayplayer_id &&
+		    level.time >= player->death_time + (TICRATE * 2) &&
+		    ::levelstate.getState() == LevelState::INGAME)
+		{
+			// CL_SpyCycle is located in cl and templated, so we use this
+			// instead.
+			AddCommandString("spynext");
+		}
+	}
+}
+
 void P_SetPlayerPowerupStatuses(player_t* player, int powers[NUMPOWERS])
 {
 	if (powers[pw_strength])
@@ -950,12 +954,12 @@ void P_PlayerThink (player_t *player)
 	// hope the client receives the spawn message at a later time.
 	if (!player->mo && clientside && multiplayer)
 	{
-		DPrintf("Warning: P_PlayerThink called for player %s without a valid Actor.\n",
-				player->userinfo.netname.c_str());
+		DPrintFmt("Warning: P_PlayerThink called for player {} without a valid Actor.\n",
+				  player->userinfo.netname);
 		return;
 	}
 	else if (!player->mo)
-		I_Error ("No player %d start\n", player->id);
+		I_Error("No player {} start\n", player->id);
 
 	player->xviewshift = 0;		// [RH] Make sure view is in right place
 	player->prevviewz = player->viewz;
@@ -985,6 +989,7 @@ void P_PlayerThink (player_t *player)
 	if (player->playerstate == PST_DEAD)
 	{
 		P_DeathThink(player);
+		P_SwitchSpyOnNoLives(player);
 		return;
 	}
 
@@ -1225,7 +1230,7 @@ BEGIN_COMMAND(cheat_players)
 			if (mo->player)
 			{
 				Printf("%.3u: %s\n", mo->player->id,
-				       mo->player->userinfo.netname.c_str());
+				       mo->player->userinfo.netname);
 			}
 			else
 			{
@@ -1557,4 +1562,4 @@ player_s::~player_s()
 {
 }
 
-VERSION_CONTROL (p_user_cpp, "$Id: d03fc2a6afebee0d74a1fb4858c62749416dfa12 $")
+VERSION_CONTROL (p_user_cpp, "$Id: 9f0ec6ae3e4d1a11f6b873219fee4e79b0dd01c4 $")
