@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: ec9bee58007815701ab752bc3fddfc90ce1e2602 $
+// $Id: fd87e0ae5b423f713104b231699c28ba91b14b86 $
 //
 // Copyright (C) 1998-2006 by Randy Heit (ZDoom).
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -235,6 +235,10 @@ void P_PlayerInZDoomSector(player_t* player)
 
 	if (sector->damageamount > 0)
 	{
+		// Some maps, like rjspace9f, abuse the fact that "end sector damage" will actually
+		// not damage the player beyond 1hp, but won't trigger the exit because they're not damaged.
+		short oldhealth = player->health;
+
 		if (sector->flags & SECF_ENDGODMODE)
 		{
 			player->cheats &= ~CF_GODMODE;
@@ -271,7 +275,7 @@ void P_PlayerInZDoomSector(player_t* player)
 				P_DamageMobj(player->mo, NULL, NULL, sector->damageamount);
 			}
 
-			if (sector->flags & SECF_ENDLEVEL && player->health <= 10)
+			if (sector->flags & SECF_ENDLEVEL && player->health <= 10 && oldhealth != player->health)
 			{
 				if (serverside && sv_allowexit)
 				{
@@ -554,7 +558,7 @@ void P_SpawnZDoomSectorSpecial(sector_t* sector)
 			break;
 		P_SetupSectorDamage(sector, 20, 32, 0,
 		                    SECF_ENDGODMODE | SECF_ENDLEVEL | SECF_DMGUNBLOCKABLE);
-		sector->special = 0;
+		//sector->special = 0;
 		break;
 	case Damage_InstantDeath:
 		if (IgnoreSpecial)
@@ -671,7 +675,7 @@ void P_SpawnZDoomExtra(int i)
 	// support for drawn heights coming from different sector
 	case Transfer_Heights:
 		sec = sides[*lines[i].sidenum].sector;
-		DPrintf("Sector tagged %d: TransferHeights \n", sec->tag);
+		DPrintFmt("Sector tagged {}: TransferHeights \n", sec->tag);
 		if (sv_forcewater)
 		{
 			sec->waterzone = 2;
@@ -683,29 +687,29 @@ void P_SpawnZDoomExtra(int i)
 		if (lines[i].args[1] & 4)
 		{
 			sec->MoreFlags |= SECF_CLIPFAKEPLANES;
-			DPrintf("Sector tagged %d: CLIPFAKEPLANES \n", sec->tag);
+			DPrintFmt("Sector tagged {}: CLIPFAKEPLANES \n", sec->tag);
 		}
 		if (lines[i].args[1] & 8)
 		{
 			sec->waterzone = 1;
-			DPrintf("Sector tagged %d: Sets waterzone=1 \n", sec->tag);
+			DPrintFmt("Sector tagged {}: Sets waterzone=1 \n", sec->tag);
 		}
 		if (lines[i].args[1] & 16)
 		{
 			sec->MoreFlags |= SECF_IGNOREHEIGHTSEC;
-			DPrintf("Sector tagged %d: IGNOREHEIGHTSEC \n", sec->tag);
+			DPrintFmt("Sector tagged {}: IGNOREHEIGHTSEC \n", sec->tag);
 		}
 		if (lines[i].args[1] & 32)
 		{
 			sec->MoreFlags |= SECF_NOFAKELIGHT;
-			DPrintf("Sector tagged %d: NOFAKELIGHTS \n", sec->tag);
+			DPrintFmt("Sector tagged {}: NOFAKELIGHTS \n", sec->tag);
 		}
 		for (s = -1; (s = P_FindSectorFromTag(lines[i].args[0], s)) >= 0;)
 		{
 			sectors[s].heightsec = sec;
 		}
 
-		DPrintf("Sector tagged %d: MoreFlags: %u \n", sec->tag, sec->MoreFlags);
+		DPrintFmt("Sector tagged {}: MoreFlags: {} \n", sec->tag, sec->MoreFlags);
 		break;
 
 	// killough 3/16/98: Add support for setting
@@ -1072,14 +1076,14 @@ unsigned int P_TranslateZDoomLineFlags(const unsigned int flags)
 {
 	unsigned int result = flags & 0x1ff;
 
-	constexpr unsigned int spac_to_flags[8] = {ML_SPAC_CROSS,
-	                                           ML_SPAC_USE,
-	                                           ML_SPAC_MCROSS,
-	                                           ML_SPAC_IMPACT,
-	                                           ML_SPAC_PUSH,
-	                                           ML_SPAC_PCROSS,
-	                                           ML_SPAC_USE | ML_PASSUSE,
-	                                           ML_SPAC_IMPACT | ML_SPAC_PCROSS};
+	static constexpr unsigned int spac_to_flags[8] = {ML_SPAC_CROSS,
+	                                                  ML_SPAC_USE,
+	                                                  ML_SPAC_MCROSS,
+	                                                  ML_SPAC_IMPACT,
+	                                                  ML_SPAC_PUSH,
+	                                                  ML_SPAC_PCROSS,
+	                                                  ML_SPAC_USE | ML_PASSUSE,
+	                                                  ML_SPAC_IMPACT | ML_SPAC_PCROSS};
 
 	// from zdoom-in-hexen to Odamex
 
