@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: d9e0972fb273a1de873792e933738856d6bfee7b $
+// $Id: 7263bab05baac89328218de259f90c8cff6dc903 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -261,7 +261,7 @@ void DSeqNode::Serialize (FArchive &arc)
 			}
 		}
 		if (i == NumSequences)
-			I_Error ("Unknown sound sequence '%s'\n", seqName.c_str());
+			I_Error("Unknown sound sequence '{}'\n", seqName);
 
 		ChangeData (seqOffset, delayTics, volume, S_FindSound (soundName.c_str()));
 	}
@@ -321,7 +321,7 @@ static void VerifySeqPtr (int pos, int need)
 	if (pos + need > ScriptTempSize)
 	{
 		ScriptTempSize *= 2;
-		ScriptTemp = (unsigned int *)Realloc (ScriptTemp, ScriptTempSize * sizeof(*ScriptTemp));
+		ScriptTemp = (unsigned int *) M_Realloc(ScriptTemp, ScriptTempSize * sizeof(*ScriptTemp));
 	}
 }
 
@@ -415,8 +415,7 @@ void S_ParseSndSeq()
 	// denis - reboot safe
 	if(Sequences)
 	{
-		free(Sequences);
-		Sequences = 0;
+		M_Free(Sequences);
 		MaxSequences = 0;
 	}
 
@@ -426,7 +425,7 @@ void S_ParseSndSeq()
 
 	memset (SeqTrans, -1, sizeof(SeqTrans));
 	name[MAX_SNDNAME] = 0;
-	ScriptTemp = (unsigned int *)Malloc (MAX_SEQSIZE * sizeof(*ScriptTemp));
+	ScriptTemp = (unsigned int *)M_Malloc (MAX_SEQSIZE * sizeof(*ScriptTemp));
 	ScriptTempSize = MAX_SEQSIZE;
 
 	int lump = -1;
@@ -466,7 +465,7 @@ void S_ParseSndSeq()
 				if (NumSequences > MaxSequences)
 				{
 					MaxSequences = MaxSequences ? MaxSequences * 2 : 64;
-					Sequences = (sndseq_t **)Realloc (Sequences, MaxSequences * sizeof(*Sequences));
+					Sequences = (sndseq_t **)M_Realloc (Sequences, MaxSequences * sizeof(*Sequences));
 				}
 				memset (ScriptTemp, 0, sizeof(*ScriptTemp) * ScriptTempSize);
 				stopsound = -1;
@@ -557,9 +556,9 @@ void S_ParseSndSeq()
 					break;
 
 				case SS_STRING_END:
-					Sequences[curseq] = (sndseq_t *)Z_Malloc (sizeof(sndseq_t) + sizeof(int)*cursize, PU_STATIC, 0);
-					strcpy (Sequences[curseq]->name, name);
-					memcpy (Sequences[curseq]->script, ScriptTemp, sizeof(int)*cursize);
+					Sequences[curseq] = (sndseq_t *) Z_Malloc(sizeof(sndseq_t) + sizeof(int)*cursize, PU_STATIC, 0);
+					M_StringCopy(Sequences[curseq]->name, name, MAX_SNDNAME + 1);
+					memcpy(Sequences[curseq]->script, ScriptTemp, sizeof(int)*cursize);
 					Sequences[curseq]->script[cursize] = SS_CMD_END;
 					Sequences[curseq]->stopsound = stopsound;
 					curseq = -1;
@@ -970,4 +969,4 @@ void DSeqNode::ChangeData (int seqOffset, int delayTics, float volume, int curre
 	m_CurrentSoundID = currentSoundID;
 }
 
-VERSION_CONTROL (s_sndseq_cpp, "$Id: d9e0972fb273a1de873792e933738856d6bfee7b $")
+VERSION_CONTROL (s_sndseq_cpp, "$Id: 7263bab05baac89328218de259f90c8cff6dc903 $")
