@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 52f5b3c5f53e585282e79657270045f30a1c55e4 $
+// $Id: 1505bc6ade772a9be852c7165c59a41a5ff95898 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -1137,12 +1137,12 @@ public:
 
 		if (!crc32Hash.empty())
 		{
-			mCRC32SumLookup.insert(std::make_pair(file->mCRC32Sum, id));
+			mCRC32SumLookup.emplace(file->mCRC32Sum, id);
 		}
 
 		if (!md5Hash.empty())
 		{
-			mMd5SumLookup.insert(std::make_pair(file->mMd5Sum, id));
+			mMd5SumLookup.emplace(file->mMd5Sum, id);
 		}
 
         if (iwad)
@@ -1161,9 +1161,9 @@ public:
 	bool isCommercialFilename(const std::string& filename) const
 	{
 		OString upper = StdStringToUpper(filename);
-		for (IdentifierTable::const_iterator it = mIdentifiers.begin(); it != mIdentifiers.end(); ++it)
+		for (const auto& id : mIdentifiers)
 		{
-			if (it->mIsCommercial && it->mFilename == upper)
+			if (id.mIsCommercial && id.mFilename == upper)
 				return true;
 		}
 		return false;
@@ -1172,10 +1172,9 @@ public:
 	bool isKnownIWADFilename(const std::string& filename) const
 	{
 		OString upper = StdStringToUpper(filename);
-		for (IdentifierTable::const_iterator it = mIdentifiers.begin();
-		     it != mIdentifiers.end(); ++it)
+		for (const auto& id : mIdentifiers)
 		{
-			if (it->mIsIWAD && it->mFilename == upper)
+			if (id.mIsIWAD && id.mFilename == upper)
 				return true;
 		}
 		return false;
@@ -1334,11 +1333,9 @@ public:
 
 	void dump() const
 	{
-		for (IdentifierTable::const_iterator it = mIdentifiers.begin();
-		     it != mIdentifiers.end(); ++it)
+		for (const auto& id : mIdentifiers)
 		{
-			Printf(PRINT_HIGH, "%s %s %s\n", it->mGroupName.c_str(),
-			       it->mFilename.c_str(), it->mMd5Sum.getHexCStr());
+			PrintFmt(PRINT_HIGH, "{} {} {}\n", id.mGroupName, id.mFilename, id.mMd5Sum.getHexStr());
 		}
 	}
 
@@ -1638,4 +1635,4 @@ std::vector<OString> W_GetIWADFilenames()
 	return identtab.getFilenames();
 }
 
-VERSION_CONTROL (w_ident_cpp, "$Id: 52f5b3c5f53e585282e79657270045f30a1c55e4 $")
+VERSION_CONTROL (w_ident_cpp, "$Id: 1505bc6ade772a9be852c7165c59a41a5ff95898 $")
