@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: 0c48a2fb0788e02b5fc1f04ec849481155b3b1a1 $
+// $Id: d7ce7851c6e497c1308cfc66292f33081328e1d9 $
 //
 // Copyright (C) 1993-1996 by id Software, Inc.
 // Copyright (C) 2006-2025 by The Odamex Team.
@@ -261,7 +261,7 @@ fhfprint_s W_FarmHash128(const byte* lumpdata, int length)
 //
 void W_AddLumps(FILE* handle, filelump_t* fileinfo, size_t newlumps, bool clientonly)
 {
-	lumpinfo = (lumpinfo_t*)Realloc(lumpinfo, (numlumps + newlumps) * sizeof(lumpinfo_t));
+	lumpinfo = (lumpinfo_t*) M_Realloc(lumpinfo, (numlumps + newlumps) * sizeof(lumpinfo_t));
 	if (!lumpinfo)
 		I_Error("Couldn't realloc lumpinfo");
 
@@ -301,11 +301,11 @@ void AddFile(const OResFile& file)
 
 	if ( (handle = fopen(filename.c_str(), "rb")) == NULL)
 	{
-		Printf(PRINT_WARNING, "couldn't open %s\n", filename.c_str());
+		Printf(PRINT_WARNING, "couldn't open %s\n", filename);
 		return;
 	}
 
-	Printf(PRINT_HIGH, "adding %s", filename.c_str());
+	Printf(PRINT_HIGH, "adding %s", filename);
 
 	size_t newlumps;
 
@@ -313,7 +313,7 @@ void AddFile(const OResFile& file)
 	size_t readlen = fread(&header, sizeof(header), 1, handle);
 	if ( readlen < 1 )
 	{
-		Printf(PRINT_HIGH, "failed to read %s.\n", filename.c_str());
+		Printf(PRINT_HIGH, "failed to read %s.\n", filename);
 		fclose(handle);
 		return;
 	}
@@ -342,7 +342,7 @@ void AddFile(const OResFile& file)
 
 		if (length > (unsigned)M_FileLength(handle))
 		{
-			Printf(PRINT_WARNING, "\nbad number of lumps for %s\n", filename.c_str());
+			Printf(PRINT_WARNING, "\nbad number of lumps for %s\n", filename);
 			fclose(handle);
 			return;
 		}
@@ -352,7 +352,7 @@ void AddFile(const OResFile& file)
 		readlen = fread(fileinfo, length, 1, handle);
 		if (readlen < 1)
 		{
-			Printf(PRINT_HIGH, "failed to read file info in %s\n", filename.c_str());
+			Printf(PRINT_HIGH, "failed to read file info in %s\n", filename);
 			fclose(handle);
 			return;
 		}
@@ -385,7 +385,7 @@ void AddFile(const OResFile& file)
 //
 //
 
-static BOOL IsMarker (const lumpinfo_t *lump, const char *marker)
+static bool IsMarker (const lumpinfo_t *lump, const char *marker)
 {
 	return (lump->namespc == ns_global) && (!strncmp (lump->name, marker, 8) ||
 			(*(lump->name) == *marker && !strncmp (lump->name + 1, marker, 7)));
@@ -403,7 +403,7 @@ void W_MergeLumps (const char *start, const char *end, int space)
 	char ustart[8], uend[8];
 	lumpinfo_t *newlumpinfos;
 	unsigned newlumps, oldlumps;
-	BOOL insideBlock;
+	bool insideBlock;
 	unsigned flatHack, i;
 
 	strncpy(ustart, start, 8);
@@ -513,7 +513,7 @@ void W_MergeLumps (const char *start, const char *end, int space)
 	if (newlumps)
 	{
 		if (oldlumps + newlumps > numlumps)
-			lumpinfo = (lumpinfo_t *)Realloc (lumpinfo, oldlumps + newlumps);
+			lumpinfo = (lumpinfo_t*) M_Realloc(lumpinfo, oldlumps + newlumps);
 
 		memcpy (lumpinfo + oldlumps, newlumpinfos, sizeof(lumpinfo_t) * newlumps);
 
@@ -565,7 +565,7 @@ void W_InitMultipleFiles(const OResFiles& files)
 	}
 
 	if (!numlumps)
-		I_Error ("W_InitFiles: no files found");
+		I_Error("W_InitFiles: no files found");
 
 	// [RH] Set namespace markers to global for everything
 	for (size_t i = 0; i < numlumps; i++)
@@ -574,6 +574,7 @@ void W_InitMultipleFiles(const OResFiles& files)
 	// [RH] Merge sprite and flat groups.
 	//		(We don't need to bother with patches, since
 	//		Doom doesn't use markers to identify them.)
+	W_MergeLumps ("TX_START", "TX_END", ns_textures);
 	W_MergeLumps ("S_START", "S_END", ns_sprites); // denis - fixme - security
 	W_MergeLumps ("F_START", "F_END", ns_flats);
 	W_MergeLumps ("C_START", "C_END", ns_colormaps);
@@ -582,10 +583,10 @@ void W_InitMultipleFiles(const OResFiles& files)
 	M_Free(lumpcache);
 
 	size_t size = numlumps * sizeof(*lumpcache);
-	lumpcache = (void **)Malloc (size);
+	lumpcache = (void **) M_Malloc(size);
 
 	if (!lumpcache)
-		I_Error ("Couldn't allocate lumpcache");
+		I_Error("Couldn't allocate lumpcache");
 
 	memset (lumpcache,0, size);
 
@@ -663,28 +664,6 @@ int W_CheckNumForName(const char *name, int namespc)
 	return i;
 }
 
-//
-// W_CheckNumForName
-// Returns -1 if name not found.
-//
-// Rewritten by Lee Killough to use hash table for performance. Significantly
-// cuts down on time -- increases Doom performance over 300%. This is the
-// single most important optimization of the original Doom sources, because
-// lump name lookup is used so often, and the original Doom used a sequential
-// search. For large wads with > 1000 lumps this meant an average of over
-// 500 were probed during every search. Now the average is under 2 probes per
-// search. There is no significant benefit to packing the names into longwords
-// with this new hashing algorithm, because the work to do the packing is
-// just as much work as simply doing the string comparisons with the new
-// algorithm, which minimizes the expected number of comparisons to under 2.
-//
-// [SL] taken from prboom-plus
-//
-int W_CheckNumForName(const OLumpName& name, int namespc)
-{
-	return W_CheckNumForName(name.c_str(), namespc);
-}
-
 //
 // W_GetNumForName
 // Calls W_CheckNumForName, but bombs out if not found.
@@ -695,22 +674,13 @@ int W_GetNumForName(const char* name, int namespc)
 
 	if (i == -1)
 	{
-		I_Error("W_GetNumForName: %s not found!\n(checked in: %s)", name,
-		        M_ResFilesToString(::wadfiles).c_str());
+		I_Error("W_GetNumForName: {} not found!\n(checked in: {})", name,
+		        M_ResFilesToString(::wadfiles));
 	}
 
 	return i;
 }
 
-//
-// W_GetNumForName
-// Calls W_CheckNumForName, but bombs out if not found.
-//
-int W_GetNumForName(const OLumpName& name, int namespc)
-{
-	return W_GetNumForName(name.c_str(), namespc);
-}
-
 /**
  * @brief Return the name of a lump number.
  *
@@ -720,7 +690,7 @@ int W_GetNumForName(const OLumpName& name, int namespc)
 std::string W_LumpName(unsigned lump)
 {
 	if (lump >= ::numlumps)
-		I_Error("%s: %i >= numlumps", __FUNCTION__, lump);
+		I_Error("{}: {} >= numlumps", __FUNCTION__, lump);
 
 	return std::string(::lumpinfo[lump].name, ARRAY_LENGTH(::lumpinfo[lump].name));
 }
@@ -732,7 +702,7 @@ std::string W_LumpName(unsigned lump)
 unsigned W_LumpLength (unsigned lump)
 {
 	if (lump >= numlumps)
-		I_Error ("W_LumpLength: %i >= numlumps",lump);
+		I_Error("W_LumpLength: {} >= numlumps", lump);
 
 	return lumpinfo[lump].size;
 }
@@ -750,7 +720,7 @@ void W_ReadLump(unsigned int lump, void* dest)
 	lumpinfo_t*	l;
 
 	if (lump >= numlumps)
-		I_Error ("W_ReadLump: %i >= numlumps",lump);
+		I_Error("W_ReadLump: {} >= numlumps", lump);
 
 	l = lumpinfo + lump;
 
@@ -761,7 +731,7 @@ void W_ReadLump(unsigned int lump, void* dest)
 	c = fread (dest, l->size, 1, l->handle);
 
 	if (feof(l->handle))
-		I_Error ("W_ReadLump: only read %i of %i on lump %i", c, l->size, lump);
+		I_Error("W_ReadLump: only read {} of {} on lump {}", c, l->size, lump);
 
 	if (lump != stdisk_lumpnum)
     	I_EndRead();
@@ -834,7 +804,7 @@ void W_GetOLumpName(OLumpName& to, unsigned lump)
 void* W_CacheLumpNum(unsigned int lump, const zoneTag_e tag)
 {
 	if ((unsigned)lump >= numlumps)
-		I_Error ("W_CacheLumpNum: %i >= numlumps",lump);
+		I_Error("W_CacheLumpNum: {} >= numlumps",lump);
 
 	if (!lumpcache[lump])
 	{
@@ -872,7 +842,7 @@ void* W_CacheLumpName(const char* name, const zoneTag_e tag)
 //
 void* W_CacheLumpName(const OLumpName& name, const zoneTag_e tag)
 {
-	return W_CacheLumpNum(W_GetNumForName(name.c_str()), tag);
+	return W_CacheLumpNum(W_GetNumForName(name), tag);
 }
 
 size_t R_CalculateNewPatchSize(patch_t *patch, size_t length);
@@ -888,7 +858,7 @@ void R_ConvertPatch(patch_t* rawpatch, patch_t* newpatch, const unsigned int lum
 patch_t* W_CachePatch(unsigned lumpnum, const zoneTag_e tag)
 {
 	if (lumpnum >= numlumps)
-		I_Error ("W_CachePatch: %u >= numlumps", lumpnum);
+		I_Error("W_CachePatch: {} >= numlumps", lumpnum);
 
 	if (!lumpcache[lumpnum])
 	{
@@ -1040,4 +1010,4 @@ void W_Close ()
 	}
 }
 
-VERSION_CONTROL (w_wad_cpp, "$Id: 0c48a2fb0788e02b5fc1f04ec849481155b3b1a1 $")
+VERSION_CONTROL (w_wad_cpp, "$Id: d7ce7851c6e497c1308cfc66292f33081328e1d9 $")
