@@ -227,6 +227,7 @@ int Fd_Project_Reader::read_quoted() {      // read whatever character is after
 Fl_Type *Fd_Project_Reader::read_children(Fl_Type *p, int merge, Strategy strategy, char skip_options) {
   Fl_Type::current = p;
   Fl_Type *last_child_read = NULL;
+  Fl_Type *t = NULL;
   for (;;) {
     const char *c = read_word();
   REUSE_C:
@@ -353,44 +354,43 @@ Fl_Type *Fd_Project_Reader::read_children(Fl_Type *p, int merge, Strategy strate
         goto CONTINUE;
       }
     }
-    {
-      Fl_Type *t = add_new_widget_from_file(c, strategy);
-      if (!t) {
-        read_error("Unknown word \"%s\"", c);
-        continue;
-      }
-      last_child_read = t;
-      // After reading the first widget, we no longer need to look for options
-      skip_options = 1;
+    t = add_new_widget_from_file(c, strategy);
+    if (!t) {
+      read_error("Unknown word \"%s\"", c);
+      continue;
+    }
+    last_child_read = t;
+    // After reading the first widget, we no longer need to look for options
+    skip_options = 1;
 
-      t->name(read_word());
+    t->name(read_word());
 
+    c = read_word(1);
+    if (strcmp(c,"{") && t->is_class()) {   // <prefix> <name>
+      ((Fl_Class_Type*)t)->prefix(t->name());
+      t->name(c);
       c = read_word(1);
-      if (strcmp(c,"{") && t->is_class()) {   // <prefix> <name>
-        ((Fl_Class_Type*)t)->prefix(t->name());
-        t->name(c);
-        c = read_word(1);
-      }
+    }
 
-      if (strcmp(c,"{")) {
-        read_error("Missing property list for %s\n",t->title());
-        goto REUSE_C;
-      }
+    if (strcmp(c,"{")) {
+      read_error("Missing property list for %s\n",t->title());
+      goto REUSE_C;
+    }
 
-      t->open_ = 0;
-      for (;;) {
-        const char *cc = read_word();
-        if (!cc || !strcmp(cc,"}")) break;
-        t->read_property(*this, cc);
-      }
+    t->folded_ = 1;
+    for (;;) {
+      const char *cc = read_word();
+      if (!cc || !strcmp(cc,"}")) break;
+      t->read_property(*this, cc);
+    }
 
-      if (!t->is_parent()) continue;
+    if (t->can_have_children()) {
       c = read_word(1);
       if (strcmp(c,"{")) {
         read_error("Missing child list for %s\n",t->title());
         goto REUSE_C;
       }
-      read_children(t, 0, strategy, skip_options);
+      read_children(t, 0, kAddAsLastChild, skip_options);
       t->postprocess_read();
       // FIXME: this has no business in the file reader!
       // TODO: this is called whenever something is pasted from the top level into a grid
@@ -406,7 +406,14 @@ Fl_Type *Fd_Project_Reader::read_children(Fl_Type *p, int merge, Strategy strate
       t->layout_widget();
     }
 
-    Fl_Type::current = p;
+    if (strategy == kAddAsFirstChild) {
+      strategy = kAddAfterCurrent;
+    }
+    if (strategy == kAddAfterCurrent) {
+      Fl_Type::current = t;
+    } else {
+      Fl_Type::current = p;
+    }
 
   CONTINUE:;
   }
