@@ -1,7 +1,7 @@
 // Emacs style mode select   -*- C++ -*-
 //-----------------------------------------------------------------------------
 //
-// $Id: afe6b29c3a312141ec1fce196b7fe4c02d63156c $
+// $Id: c7cbdfed44cbd6f8720f6f6ae217ebb3bb1a678e $
 //
 // Copyright (C) 2012 by Alex Mayfield.
 //
@@ -113,10 +113,9 @@ bool Maplist::insert(const size_t &position, maplist_entry_t &maplist_entry) {
 			// loaded WAD files.  Add one to the beginning of wadfiles, since
 			// position 0 stores odamex.wad.
 			maplist_entry.wads.clear();
-			for (OResFiles::const_iterator it = ::wadfiles.begin() + 1;
-			     it != ::wadfiles.end(); ++it)
+			for (const auto& file : OUtil::drop(::wadfiles, 1))
 			{
-				maplist_entry.wads.push_back(it->getBasename());
+				maplist_entry.wads.push_back(file.getBasename());
 			}
 		}
 		else
@@ -139,7 +138,7 @@ bool Maplist::insert(const size_t &position, maplist_entry_t &maplist_entry) {
 	// If we haven't actually entered the map rotation yet, don't increase
 	// indexes because this results in the initial map switch going to the end
 	// of the maplist, which probably isn't what we want.
-	if (!this->entered_once) {
+	if (this->entered_once) {
 		// If either of our indexes are after the inserted map, fix them
 		if (this->index >= position) {
 			this->index += 1;
@@ -187,7 +186,7 @@ bool Maplist::remove(const size_t &index) {
 	}
 
 	// Don't mess with indexes if we haven't actually entered the maplist.
-	if (!this->entered_once) {
+	if (this->entered_once) {
 		// If we delete our current map, we do not have a determined
 		// position in the maplist.
 		if (this->index == index) {
@@ -273,7 +272,7 @@ bool Maplist::get_this_index(size_t &index) {
 
 	// We're not in the maplist
 	if (!this->in_maplist) {
-		this->error = "This map is not in the maplist.";
+		this->error = "The maplist is not currently in use.";
 		return false;
 	}
 
@@ -290,14 +289,18 @@ bool Maplist::get_next_index(size_t &index) {
 	}
 
 	if (this->shuffled) {
-		if (this->s_index + 1 >= this->s_maplist.size() || !entered_once) {
+		if (this->s_index + 1 >= this->s_maplist.size()) {
 			index = this->s_maplist[0];
+		} else if (!this->entered_once) {
+			index = this->s_maplist[this->s_index];
 		} else {
 			index = this->s_maplist[this->s_index + 1];
 		}
 	} else {
-		if (this->index + 1 >= this->maplist.size() || !entered_once) {
+		if (this->index + 1 >= this->maplist.size()) {
 			index = 0;
+		} else if (!this->entered_once) {
+			index = this->index;
 		} else {
 			index = this->index + 1;
 		}
@@ -417,8 +420,8 @@ bool Maplist::set_index(const size_t &index) {
 		return false;
 	}
 
-	this->entered_once = true;
-	this->in_maplist = true;
+	this->entered_once = true && gamestate != GS_STARTUP;
+	this->in_maplist = true && gamestate != GS_STARTUP;
 	this->index = index;
 	this->update_shuffle_index();
 	return true;
@@ -498,7 +501,7 @@ void SV_Maplist(player_t &player, maplist_status_t status) {
 	case MAPLIST_OUTDATED:
 	case MAPLIST_OK:
 		// Valid statuses
-		DPrintf("SV_Maplist: Sending status %d to pid %d\n", status, player.id);
+		DPrintFmt("SV_Maplist: Sending status {} to pid {}\n", status, player.id);
 		MSG_WriteSVC(&cl->reliablebuf, SVC_Maplist(status));
 	default:
 		// Invalid statuses
@@ -535,12 +538,12 @@ void SV_MaplistUpdate(player_t &player, maplist_status_t status) {
 	case MAPLIST_EMPTY:
 	case MAPLIST_TIMEOUT:
 		// Valid statuses that don't require the packet logic
-		DPrintf("SV_MaplistUpdate: Sending status %d to pid %d\n", status, player.id);
+		DPrintFmt("SV_MaplistUpdate: Sending status {} to pid {}\n", status, player.id);
 		MSG_WriteSVC(&cl->reliablebuf, SVC_MaplistUpdate(status, NULL));
 		return;
 	case MAPLIST_OUTDATED:
 		// Valid statuses that need the packet logic
-		DPrintf("SV_MaplistUpdate: Sending status %d to pid %d\n", status, player.id);
+		DPrintFmt("SV_MaplistUpdate: Sending status {} to pid {}\n", status, player.id);
 		break;
 	default:
 		// Invalid statuses
@@ -597,7 +600,7 @@ void SV_Maplist(player_t &player) {
 		break;
 	default:
 		// We don't know what status they sent us.  Ignore it.
-		DPrintf("SV_Maplist: Unexpected status %d from player %d\n",
+		DPrintFmt("SV_Maplist: Unexpected status {} from player {}\n",
 				status, player.id);
 		return;
 	}
@@ -641,13 +644,32 @@ void Maplist_Disconnect(player_t &player) {
 
 //////// CONSOLE COMMANDS ////////
 
+nonstd::expected<maplist_lastmaps_t, std::string> maplist_lastmaps_t::parse(const std::string& lastmaps) {
+	StringTokens entries = TokenizeString(lastmaps, ",");
+	maplist_lastmaps_t result;
+	for (const auto& entry : entries) {
+		if (entry.empty()) {
+			return nonstd::make_unexpected(fmt::format("Empty lastmap entry found in {}", lastmaps));
+		}
+		StringTokens maps = TokenizeString(StdStringToUpper(entry), "->");
+		if (maps.size() == 1 && maps[0].find("->") == std::string::npos)
+			result.entries.push_back({ maps[0], "" });
+		else if (maps.size() == 2)
+			result.entries.push_back({ maps[0], maps[1] });
+		else {
+			return nonstd::make_unexpected(fmt::format("Invalid lastmap entry: {} in {}", entry, lastmaps));
+		}
+	}
+	return result;
+}
+
 BEGIN_COMMAND (maplist) {
 	std::vector<std::string> arguments = VectorArgs(argc, argv);
 
 	// Query the maplist
 	std::vector<std::pair<size_t, maplist_entry_t*> > result;
 	if (!Maplist::instance().query(arguments, result)) {
-		Printf(PRINT_HIGH, "%s\n", Maplist::instance().get_error().c_str());
+		PrintFmt(PRINT_HIGH, "{}\n", Maplist::instance().get_error());
 		return;
 	}
 
@@ -656,41 +678,44 @@ BEGIN_COMMAND (maplist) {
 	bool show_this_map = Maplist::instance().get_this_index(this_index);
 	Maplist::instance().get_next_index(next_index);
 	for (const auto& [index, entry] : result) {
-		const auto& [map, lastmap, wads] = *entry;
+		const auto& [map, _, lastmaps, wads] = *entry;
 		char flag = ' ';
 		if (show_this_map && index == this_index) {
 			flag = '*';
 		} else if (index == next_index) {
 			flag = '+';
 		}
-		Printf(PRINT_HIGH, "%c%lu. %s %s%s\n", flag, index + 1,
-			   JoinStrings(wads, " ").c_str(), map.c_str(),
-			   lastmap.empty() ? "" : fmt::sprintf(" lastmap=%s", lastmap));
+		PrintFmt(PRINT_HIGH, "{}{}. {} {}{}\n", flag, index + 1,
+			   JoinStrings(wads, " "), map,
+			   lastmaps.empty() ? "" : fmt::format(" lastmap={}", lastmaps));
 	}
 } END_COMMAND (maplist)
 
 BEGIN_COMMAND (addmap) {
+	if (argc < 2) {
+		PrintFmt(PRINT_HIGH, "Usage: addmap <map lump> [wad name] [...]\n");
+		PrintFmt(PRINT_HIGH, "If you don't specify a wad name, it'll load the IWAD by default.\n");
+		return;
+	}
+
+	maplist_entry_t maplist_entry;
+
 	std::string lastmap = argv[argc-1];
 	if (lastmap.rfind("lastmap=", 0) == 0)
 	{
-		lastmap = lastmap.substr(8);
+		auto lastmap_result = maplist_lastmaps_t::parse(lastmap.substr(8));
+		if (!lastmap_result) {
+			PrintFmt(PRINT_HIGH, "Failed to parse lastmap: {}\n", lastmap_result.error());
+			return;
+		}
+		maplist_entry.lastmaps = lastmap_result.value();
 		argc--;
 	}
-	else
-		lastmap = "";
-
-	if (argc < 2) {
-		Printf(PRINT_HIGH, "Usage: addmap <map lump> [wad name] [...]\n");
-		Printf(PRINT_HIGH, "If you don't specify a wad name, it'll load the IWAD by default.\n");
-		return;
-	}
 
 	std::vector<std::string> arguments = VectorArgs(argc, argv);
 
 	// Grab the map lump.
-	maplist_entry_t maplist_entry;
 	maplist_entry.map = arguments[0];
-	maplist_entry.lastmap = lastmap;
 
 	// If we specified any WAD files, grab them too.
 	if (arguments.size() > 1) {
@@ -699,27 +724,33 @@ BEGIN_COMMAND (addmap) {
 	}
 
 	if (!Maplist::instance().add(maplist_entry)) {
-		Printf(PRINT_HIGH, "%s\n", Maplist::instance().get_error().c_str());
+		PrintFmt(PRINT_HIGH, "{}\n", Maplist::instance().get_error());
 		return;
 	}
 
 	// Successfully warn the server a map has been added.
-	Printf(PRINT_HIGH, "Adding %s to maplist (WAD%s : %s)", arguments[0].c_str(), (arguments.size() > 2)?"s":"", JoinStrings(maplist_entry.wads, " ").c_str());
+	PrintFmt(PRINT_HIGH, "Adding {} to maplist (WAD{} : {})", arguments[0], (arguments.size() > 2)?"s":"", JoinStrings(maplist_entry.wads, " "));
 } END_COMMAND(addmap)
 
 BEGIN_COMMAND(insertmap) {
+	if (argc < 3) {
+		Printf(PRINT_HIGH, "Usage: insertmap <maplist position> <map lump> [wad name] [...]\n");
+	}
+
+	maplist_entry_t maplist_entry;
+
 	std::string lastmap = argv[argc-1];
 	if (lastmap.rfind("lastmap=", 0) == 0)
 	{
+		auto lastmap_result = maplist_lastmaps_t::parse(lastmap.substr(8));
+		if (!lastmap_result) {
+			PrintFmt(PRINT_HIGH, "Failed to parse lastmap: {}\n", lastmap_result.error());
+			return;
+		}
 		lastmap = lastmap.substr(8);
+		maplist_entry.lastmaps = lastmap_result.value();
 		argc--;
 	}
-	else
-		lastmap = "";
-
-	if (argc < 3) {
-		Printf(PRINT_HIGH, "Usage: insertmap <maplist position> <map lump> [wad name] [...]\n");
-	}
 
 	std::vector<std::string> arguments = VectorArgs(argc, argv);
 
@@ -728,14 +759,12 @@ BEGIN_COMMAND(insertmap) {
 	std::istringstream buffer(arguments[0]);
 	buffer >> maplist_position;
 	if (maplist_position == 0 || arguments[0][0] == '-') {
-		Printf(PRINT_HIGH, "Position must be a positive number.\n");
+		PrintFmt(PRINT_HIGH, "Position must be a positive number.\n");
 		return;
 	}
 
 	// Grab the map lump.
-	maplist_entry_t maplist_entry;
 	maplist_entry.map = arguments[1];
-	maplist_entry.lastmap = lastmap;
 
 	// If we specified any WAD files, grab them too.
 	if (arguments.size() > 2) {
@@ -744,12 +773,12 @@ BEGIN_COMMAND(insertmap) {
 	}
 
 	if (!Maplist::instance().insert(maplist_position - 1, maplist_entry)) {
-		Printf(PRINT_HIGH, "%s\n", Maplist::instance().get_error().c_str());
+		PrintFmt(PRINT_HIGH, "{}\n", Maplist::instance().get_error());
 		return;
 	}
 
 	// Successfully warn the server a map has been added.
-	Printf(PRINT_HIGH, "Successfully inserting %s to position #%s (WAD%s : %s)", arguments[1].c_str(), arguments[0].c_str(), (arguments.size() > 3) ? "s" : "", JoinStrings(maplist_entry.wads, " ").c_str());
+	PrintFmt(PRINT_HIGH, "Successfully inserting {} to position #{} (WAD{} : {})", arguments[1], arguments[0], (arguments.size() > 3) ? "s" : "", JoinStrings(maplist_entry.wads, " "));
 } END_COMMAND(insertmap)
 
 BEGIN_COMMAND(delmap) {
@@ -770,13 +799,13 @@ BEGIN_COMMAND(delmap) {
 	}
 
 	if (!Maplist::instance().remove(maplist_index - 1)) {
-		Printf(PRINT_HIGH, "%s\n", Maplist::instance().get_error().c_str());
+		Printf(PRINT_HIGH, "%s\n", Maplist::instance().get_error());
 	}
 } END_COMMAND(delmap)
 
 BEGIN_COMMAND(clearmaplist) {
 	if (!Maplist::instance().clear()) {
-		Printf(PRINT_HIGH, "%s\n", Maplist::instance().get_error().c_str());
+		Printf(PRINT_HIGH, "%s\n", Maplist::instance().get_error());
 	}
 	else {
 		Printf(PRINT_HIGH, "Maplist cleared.\n");
@@ -799,7 +828,7 @@ BEGIN_COMMAND (gotomap) {
 	// Query the maplist
 	maplist_qrows_t result;
 	if (!Maplist::instance().query(arguments, result)) {
-		Printf(PRINT_HIGH, "%s\n", Maplist::instance().get_error().c_str());
+		Printf(PRINT_HIGH, "%s\n", Maplist::instance().get_error());
 		return;
 	}
 
@@ -835,7 +864,7 @@ bool CMD_Randmap(std::string &error) {
 BEGIN_COMMAND (randmap) {
 	std::string error;
 	if (!CMD_Randmap(error)) {
-		Printf(PRINT_HIGH, "%s\n", error.c_str());
+		Printf(PRINT_HIGH, "%s\n", error);
 	}
 } END_COMMAND (randmap)
 
@@ -868,9 +897,9 @@ BEGIN_COMMAND(setlobbymap)
 	Maplist::instance().set_lobbymap(maplist_entry);
 
 	// Successfully warn the server a map has been added.
-	Printf(PRINT_HIGH, "Setting %s as the Lobby map (WAD%s : %s)\n", arguments[0].c_str(),
+	Printf(PRINT_HIGH, "Setting %s as the Lobby map (WAD%s : %s)\n", arguments[0],
 	       (arguments.size() > 2) ? "s" : "",
-	       JoinStrings(maplist_entry.wads, " ").c_str());
+	       JoinStrings(maplist_entry.wads, " "));
 }
 END_COMMAND(setlobbymap)
 
